﻿using System;
using System.Drawing;
using System.Drawing.Printing;
using System.IO;
using BarcodeLib;
using System.Xml;
using System.Linq;
using System.Xml.Linq;
using System.Xml.XPath;
using System.Text.RegularExpressions;
using NFeLib.NFE.BaseNF;
using NFeLib.NFE.Utils;
using NFeLib.NFE.BaseNF.Informacoes.Detalhes;
using NFeLib.NFE.BaseNF.Informacoes.PagCobranca;
using NFeLib.NFE.BaseNF.Informacoes.Destinatario;
using NFeLib.NFE.BaseNF.Informacoes.Emitente;
using NFeLib.Utils;


/**************************************************************/
/*  Classe Convetida de VB.Net para C#                        */
/*  FONTE SITE: http://vbmania.com.br - TÓPICO NFE VB.NET     */
/*  CLASSE PARA IMPRESSÃO DO DANFE SEM O USO DE GERADORES     */
/*  NOME: DANIEL COUTINHO DE MELO                             */
/*  EMAIL: DANIELCPAETE@GMAIL.COM                             */
/*  DATA: 24-02-2010 PORTO ALEGRE - RS                        */
/*  ATUALIZAÇÃO DELWOKO VBMANIA 06/01/2010                    */
/*  ATUALIZAÇÃO ELUCIMAR VBMANIA 06/01/2010                   */
/**************************************************************/

namespace NFeLib.Danfes
{

    public class DanfePaisagem : IDanfe
    {
        private int _contadorProdutos = 0;
        private int _pagina = 1;
        private int _totalPaginas;
        private NFe _nfe;
        private string _protocolo;
        private string _dhRecbto;

        //FONTES DA DANFE
        private Font _font12B = new Font("Times New Roman", 12, FontStyle.Bold);
        private Font _font12 = new Font("Times New Roman", 12, FontStyle.Regular);
        private Font _Font11 = new Font("Times New Roman", 11, FontStyle.Regular);
        private Font _font6 = new Font("Times New Roman", 6, FontStyle.Regular);
        private Font _font5 = new Font("Times New Roman", 5, FontStyle.Regular);
        private Font _font5B = new Font("Courier New", 5, FontStyle.Bold);
        private Font _font7 = new Font("Times New Roman", 7, FontStyle.Regular);
        private Font _font10 = new Font("Times New Roman", 10, FontStyle.Regular);
        private Font _font10B = new Font("Times New Roman", 10, FontStyle.Bold);
        private Font _font8B = new Font("Times New Roman", 8, FontStyle.Bold);
        private Font _fontArial7 = new Font("Arial", 7, FontStyle.Bold);

        private string _msgSoftWareHouse = string.Empty;
        
        public PrintDocument RptPrintDocument { get; set; }

        public DanfePaisagem(NFe nfeRef, string numProt, string dataProt, string msgSoftWareHouse)
        {
            this._msgSoftWareHouse = msgSoftWareHouse;
            PrintDocument printDoc = new PrintDocument();
            _nfe = nfeRef;
            _protocolo = numProt;
            _dhRecbto = Convert.ToDateTime(dataProt).ToString("dd/MM/yyyy HH:mm:ss");

            //ASSOCIA OS EVENTOS DE IMPRESSÃO COM MINHAS FUNÇÕES
            printDoc.BeginPrint += InicioImpressao;
            printDoc.PrintPage += ImprimirDanfe;

            printDoc.DefaultPageSettings.Landscape = true;
            printDoc.OriginAtMargins = false;

            //AS MARGENS PRECISAM SER AJUSTADAS PARA QUE A IMPRESSÃO INICIAL TENHA 5 MILIMETROS
            printDoc.DefaultPageSettings.Margins = new System.Drawing.Printing.Margins(11, 11, 11, 11);
            RptPrintDocument = printDoc;
        }

        public DanfePaisagem(XmlDocument xmlDoc, string msgSoftWareHouse)
        {
            this._msgSoftWareHouse = msgSoftWareHouse;
            PrintDocument printDoc = new PrintDocument();
            _nfe = new NFe();

            XDocument xDocTmp = XDocument.Parse(xmlDoc.OuterXml);
            XDocument xDoc = XDocument.Parse(Regex.Replace(xDocTmp.ToString(), "xmlns=\".+\"", String.Empty));
 

            // NFe já processada e com o protocolo
            if (xDoc.XPathSelectElements("nfeProc/protNFe/infProt/chNFe").Count() > 0)
            {
                _protocolo = xDoc.XPathSelectElements("nfeProc/protNFe/infProt/nProt").FirstOrDefault().Value;
                _dhRecbto = Convert.ToDateTime(xDoc.XPathSelectElements("nfeProc/protNFe/infProt/dhRecbto").FirstOrDefault().Value).ToString("dd/MM/yyyy HH:mm:ss");
                nfeProc procNFe = FunctionNFe.DeserializarNFe<nfeProc>(xmlDoc.OuterXml);
                _nfe = procNFe.NFe; 
            }
            else
            {
                _nfe = (FunctionNFe.DeserializarNFe<nfeProc>(xmlDoc.ToString())).NFe;
            }

            //ASSOCIA OS EVENTOS DE IMPRESSÃO COM MINHAS FUNÇÕES
            printDoc.BeginPrint += InicioImpressao;
            printDoc.PrintPage += ImprimirDanfe;

            printDoc.DefaultPageSettings.Landscape = true;
            printDoc.OriginAtMargins = false;

            //AS MARGENS PRECISAM SER AJUSTADAS PARA QUE A IMPRESSÃO INICIAL TENHA 5 MILIMETROS
            printDoc.DefaultPageSettings.Margins = new System.Drawing.Printing.Margins(11, 11, 11, 11);
            RptPrintDocument = printDoc;
        }
        #region " InicioImpressao - InicioImpressao - inicializa algumas variaves e arrays "

        private void InicioImpressao(object sender, PrintEventArgs e)
        {
            //ZERA VARIAVEIS DE CONTROLE DE IMPRESSÃO
            _pagina = 1;
            _contadorProdutos = 0;
        }

        #endregion

        #region " ImprimirDanfe - Efetua a chamada para as subs de impressão conforme a variavel pagina = 1 "

        private void ImprimirDanfe(object sender, PrintPageEventArgs e)
        {
            //VERIFICA SE É PRIMEIRA FOLHA OU DEMAIS PARA FORMATAR A IMPRESSÃO
            CalculaTotalPaginas();
            ImprimirCabecalho(e);
            if (_pagina == 1)
            {
                ImprimirDesenhoDeRetangulos(e);
                ImprimirTextos(e);
                ImprimirDados(e);
                ImprimirDetalhes(e);
            }
            else
            {
                ImprimirDetalhes(e);
                ImprimirCamposDemaisPaginas(e);
            }
        }

        #endregion

        #region " CalculaTotalPaginas - Calcula o total de paginas "

        private void CalculaTotalPaginas()
        {
            float alturaLinhaFinal = 0;
            float alturaLinha = 0;
            int contadorProdutosAuxiliar = 0;
            int preenchimentoLoteRastro = 0;
            string linhaLoteRastro = null;

            alturaLinha = 115;
            if (_pagina == 1)
            {
                //alturaLinhaFinal = 150;//Rotina Antiga
                alturaLinhaFinal = 160;
            }
            else
            {
                //alturaLinhaFinal = 150;//Rotina Antiga
                alturaLinhaFinal = 195;
            }

            _totalPaginas = 1;
            contadorProdutosAuxiliar = 0;

            foreach (det detInf in _nfe.infNFe.det)
            {
                contadorProdutosAuxiliar += 1;
                alturaLinha += 2.8f;

                preenchimentoLoteRastro = 0;
                linhaLoteRastro = string.Empty;
                foreach (rastro rastroInf in detInf.prod.rastro)
                {
                    preenchimentoLoteRastro += 1;
                    linhaLoteRastro += (string.IsNullOrEmpty(linhaLoteRastro) ? null : " ") + "Lote: " + rastroInf.nLote + " Qtd: " + rastroInf.qLote.ToString("#.##", FunctionNFe.CulturaPtBr);
                    if (preenchimentoLoteRastro == 3)
                    {
                        preenchimentoLoteRastro = 0;
                        linhaLoteRastro = string.Empty;
                        alturaLinha += 2.8f;
                    }
                }
                if (linhaLoteRastro != string.Empty)
                {
                    alturaLinha += 2.8f;
                }

                alturaLinha += 1.0f;

                if (alturaLinha > alturaLinhaFinal & contadorProdutosAuxiliar < _nfe.infNFe.det.Count)
                {
                    _totalPaginas += 1;
                    alturaLinha = 52;
                    if (_pagina == 1)
                    {
                        //alturaLinhaFinal = 150; //Rotina Antiga
                        alturaLinhaFinal = 160;
                    }
                    else
                    {
                        //alturaLinhaFinal = 150;//Rotina Antiga
                        alturaLinhaFinal = 195;
                    }
                }
            }
        }

        #endregion

        #region " ImprimirCabecalho - Imprime cabeçalho e guia do cliente "

        //GERA CABEÇALHO E GUIA DO CLIENTE
        private void ImprimirCabecalho(PrintPageEventArgs graphicsSaida)
        {
            Pen pen = new Pen(Brushes.Black, 0.2f);
            graphicsSaida.Graphics.PageUnit = GraphicsUnit.Millimeter;

            // instrução adicionada para evitar exception de elementos inexistentes no objeto nf (na deserialização caso não exista determinada tag o elemento correspondente também não é criado)

            //RETANGULOS ENTRADA E SAÍDA E FRETE POR CONTA
            graphicsSaida.Graphics.DrawRectangle(pen, 157, 14, 5, 5);

            //CONJUNTO DE LINHAS LATERAIS ESQUERDAS(SO IRA IMPRIMIR TODAS LINHAS NA PRIMEIRA PAGINA)
            graphicsSaida.Graphics.DrawLine(pen, 2, 201, 2, 2);
            graphicsSaida.Graphics.DrawLine(pen, 23, 201, 23, 2);
            graphicsSaida.Graphics.DrawLine(pen, 12, 201, 12, 36);
            graphicsSaida.Graphics.DrawLine(pen, 2, 36, 23, 36);
            graphicsSaida.Graphics.DrawLine(pen, 12, 137, 23, 137);

            //Ultima Linha Direita
            graphicsSaida.Graphics.DrawLine(pen, 287, 201, 287, 2);

            //CONJUNTO DE LINHAS HORIZONTAIS DADOS EMPRESA
            graphicsSaida.Graphics.DrawLine(pen, 23, 33, 287, 33);
            graphicsSaida.Graphics.DrawLine(pen, 23, 40, 287, 40);
            graphicsSaida.Graphics.DrawLine(pen, 23, 47, 287, 47);

            //CONJUNTO DE LINHAS ESQUADRAR A PAGINA
            graphicsSaida.Graphics.DrawLine(pen, 2, 2, 287, 2);
            graphicsSaida.Graphics.DrawLine(pen, 2, 201, 287, 201);

            //CONJUNTO DE LINHAS VERTICAIS DADOS DA NOTA
            graphicsSaida.Graphics.DrawLine(pen, 130, 2, 130, 33);
            graphicsSaida.Graphics.DrawLine(pen, 166, 2, 166, 40);

            //INSCRIÇÃO ESTADUAL / INSCR. SUBST / CNPJ
            graphicsSaida.Graphics.DrawLine(pen, 112, 40, 112, 47);
            graphicsSaida.Graphics.DrawLine(pen, 201, 40, 201, 47);

            //CONJUNTO DE LINHAS HORIZONTAIS CODIGO DE BARRAS
            graphicsSaida.Graphics.DrawLine(pen, 166, 15, 287, 15);
            graphicsSaida.Graphics.DrawLine(pen, 166, 22, 287, 22);

            //IDENTIFICAÇÃO DO DOCUMENTO(COMPROVANTE DO CLIENTE SÓ IRA SAIR NA PRIMEIRA PAGINA)
            graphicsSaida.Graphics.DrawString("NOTA", _font12, Brushes.Black, 6.3f, 2);
            graphicsSaida.Graphics.DrawString("FISCAL", _font12, Brushes.Black, 5.3f, 6);
            graphicsSaida.Graphics.DrawString("Nº", _font12B, Brushes.Black, 10.3f, 11);
            graphicsSaida.Graphics.DrawString(Int32.Parse(_nfe.infNFe.ide.cNF).ToString("000'.'000'.'000", FunctionNFe.CulturaPtBr), _font10B, Brushes.Black, 2.6f, 17);
            graphicsSaida.Graphics.DrawString("SÉRIE 1", _font12, Brushes.Black, 5, 24);

            //------------Logotipo Emitente--------------------
            string pathLogo = Directory.GetCurrentDirectory() + @"\logoEmpresa.jpg";
            if (File.Exists(pathLogo))
            {
                graphicsSaida.Graphics.DrawImage(Image.FromFile(pathLogo), 24, 3, 35, 28);
            }
            else
            {
                //Caso não exista imprime o Logo Padrão da NFe
                graphicsSaida.Graphics.DrawImage(NFeLib.Properties.Resources.LogoNFe, 24, 3, 35, 28);
            }
            //--------------------Imprime os Dados do Emitente ao lado do Logo--------------------
            string enderecoEmitente = string.Empty;
            string municipioEmitente = string.Empty;
            string ufEmitente = string.Empty;
            string cepEmitente = string.Empty;
            string foneEmitente = string.Empty;

            enderEmit enderEmitente = _nfe.infNFe.emit.enderEmit;
            enderecoEmitente = enderEmitente.xLgr;
            if (!string.IsNullOrEmpty(enderecoEmitente) && !string.IsNullOrEmpty(enderEmitente.nro))
            {
                enderecoEmitente += ", " + enderEmitente.nro;
            }
            municipioEmitente = enderEmitente.xMun;
            ufEmitente = enderEmitente.UF;
            cepEmitente = "CEP: " + Convert.ToInt32(enderEmitente.CEP).ToString("00000-000", FunctionNFe.CulturaPtBr);
            foneEmitente = "FONE: " + enderEmitente.fone;
            graphicsSaida.Graphics.DrawString(_nfe.infNFe.emit.xNome.QuebrarString(20), _font10B, Brushes.Black, 60, 2, new StringFormat());
            graphicsSaida.Graphics.DrawString(enderecoEmitente, _font7, Brushes.Black, 60, 15, new StringFormat());
            graphicsSaida.Graphics.DrawString(_nfe.infNFe.emit.enderEmit.xBairro + " - " + cepEmitente, _font7, Brushes.Black, 60, 19);
            graphicsSaida.Graphics.DrawString(municipioEmitente + (string.IsNullOrEmpty(ufEmitente) ? null : ", ") + ufEmitente, _font7, Brushes.Black, 60, 23);
            graphicsSaida.Graphics.DrawString(foneEmitente, _font7, Brushes.Black, 60, 27);

            graphicsSaida.Graphics.DrawString("DANFE", _font12B, Brushes.Black, 140, 2);
            graphicsSaida.Graphics.DrawString("DOCUMENTO AUXILIAR DA", _font7, Brushes.Black, 131.2f, 7);
            graphicsSaida.Graphics.DrawString("NOTA FISCAL ELETRÔNICA", _font7, Brushes.Black, 131.5f, 10);
            graphicsSaida.Graphics.DrawString("0 - ENTRADA", _font7, Brushes.Black, 134.5f, 13.5f);
            graphicsSaida.Graphics.DrawString("1 - SAÍDA", _font7, Brushes.Black, 134.5f, 17);
            graphicsSaida.Graphics.DrawString("N.º " + Int32.Parse(_nfe.infNFe.ide.nNF).ToString("000'.'000'.'000", FunctionNFe.CulturaPtBr), _font10B, Brushes.Black, 131.5f, 21);
            graphicsSaida.Graphics.DrawString("SÉRIE 1", _font10B, Brushes.Black, 131.5f, 25);

            Graphics graphics = graphicsSaida.Graphics;
            graphics.DrawString("FOLHA " + _pagina + "/" + _totalPaginas, _font10B, Brushes.Black, 131.5f, 29);

            //PRIMEIRA LINHA
            string chvAcesso = _nfe.infNFe.Id.Replace("NFe", "");

            //Imprime o Código de Barra
            Barcode codBarra = new Barcode();
            int widthBarCode = 280;
            int heightBarCode = 40;
            codBarra.Alignment = AlignmentPositions.LEFT;
            TYPE type = TYPE.CODE128C;
            Image imgCodBarra = codBarra.Encode(type, chvAcesso.Trim(), Color.Black, Color.White, widthBarCode, heightBarCode);
            graphics.DrawImage(imgCodBarra, 178, 3, 100, 11);

            //graphics.DrawImage(CodigoBarra.DrawBarCode(chvAcesso), 184, 3, 100, 11);
            graphics.DrawString("CHAVE DE ACESSO", _font6, Brushes.Black, 167, 15.2f);
            graphics.DrawString("Consulta de autenticidade no portal nacional da NF-e", _Font11, Brushes.Black, 167, 22);
            graphics.DrawString("www.nfe.fazenda.gov.br/portal", _Font11, Brushes.Black, 167, 26);
            graphics.DrawString("ou no site da Sefaz Autorizadora", _Font11, Brushes.Black, 220.9f, 26);

            graphics.DrawString("NATUREZA DA OPERAÇÃO", _font6, Brushes.Black, 25, 33.2f);
            graphics.DrawString("PROTOCOLO DE AUTORIZAÇÃO DE USO", _font6, Brushes.Black, 167, 33.2f);

            //SEGUNDA LINHA
            graphics.DrawString("INSCRIÇÃO ESTADUAL", _font6, Brushes.Black, 25, 40.2f);
            graphics.DrawString("INSCR. ESTADUAL DO SUBST. TRIBUT.", _font6, Brushes.Black, 113, 40.2f);
            graphics.DrawString("CNPJ", _font6, Brushes.Black, 202, 40.2f);

            string nchave = string.Empty;
            int contarS = 0;
            for (Int16 x = 0; x <= chvAcesso.Length - 1; x++)
            {
                contarS += 1;
                nchave += chvAcesso.Substring(x, 1);
                if (contarS == 4)
                {
                    contarS = 0;
                    nchave += " ";
                }
            }
            graphics.DrawString(nchave, _font8B, Brushes.Black, 167, 18);

            //NATUREZA, PROTOCOLO E TIPO DE NOTA
            graphics.DrawString(_nfe.infNFe.ide.tpNF, _font10, Brushes.Black, 158, 14.5f);
            graphics.DrawString(_nfe.infNFe.ide.natOp, _font10, Brushes.Black, 25, 36.2f);
            if (!string.IsNullOrEmpty(_protocolo))
            {
                graphics.DrawString(_protocolo + " - " + _dhRecbto, _font10, Brushes.Black, 167, 36.2f);
            }

            //INICIO DO PREENCHIMENTO NOTA EMITENTE
            graphics.DrawString(_nfe.infNFe.emit.IE, _font10, Brushes.Black, 25, 43.2f);
            graphics.DrawString(_nfe.infNFe.emit.IEST, _font10, Brushes.Black, 113, 43.2f);
            graphics.DrawString(Convert.ToInt64(_nfe.infNFe.emit.CNPJ).ToString("00'.'000'.'000'/'0000'-'00", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, 202, 43.2f);

            //------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
            //                          DADOS DO COMPROVANTE DE RECEBIMENTO DO DESTINARIO
            //------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
            //INSERIR BLOCOS DE CAMPOS
            System.Drawing.StringFormat formatoVertical = null;
            System.Drawing.Point posicaoTexto = default(System.Drawing.Point);
            System.Drawing.Drawing2D.Matrix rotacionadorDeTexto = graphics.Transform;

            formatoVertical = new StringFormat(StringFormatFlags.DirectionVertical);
            posicaoTexto = new Point((int)27.5f, 65);

            rotacionadorDeTexto.RotateAt(180, posicaoTexto);
            graphics.Transform = rotacionadorDeTexto;

            //GUIA DO CLIENTE
            posicaoTexto = new Point(48, -71);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("RECEBEMOS DE " + _nfe.infNFe.emit.xNome, _font8B, Brushes.Black, posicaoTexto, formatoVertical);

            posicaoTexto = new Point(45, -71);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("OS PRODUTOS OU SERVIÇOS CONSTANTES NA NOTA FISCAL ELETRÔNICA INDICADA AO LADO", _font6, Brushes.Black, posicaoTexto, formatoVertical);

            posicaoTexto = new Point(42, -71);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("DATA E HORA", _font6, Brushes.Black, posicaoTexto, formatoVertical);

            posicaoTexto = new Point(42, -6);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("IDENTIFICAÇÃO DO RECEBEDOR", _font6, Brushes.Black, posicaoTexto, formatoVertical);

            //VOLTA TEXTO PARA POSIÇÃO ORIGINAL
            graphics.ResetTransform();
        }

        #endregion

        #region " ImprimirDados - Imprime dados quando é primeira pagina "

        //PREENCHE DADOS QUANDO É PRIMEIRA PAGINA
        private void ImprimirDados(System.Drawing.Printing.PrintPageEventArgs graphicsSaida)
        {
            // instrução adicionada para evitar exception de elementos inexistentes no objeto nf (na deserialização caso não exista determinada tag o elemento correspondente também não é criado)
            Graphics graphics = graphicsSaida.Graphics;
            graphics.PageUnit = GraphicsUnit.Millimeter;

            //DADOS DO DESTINATARIO
            string cnpjDestinatario = string.Empty;
            string cpfDestinatario = string.Empty;
            string enderecoDestinatario = string.Empty;
            cnpjDestinatario = string.Empty;
            cpfDestinatario = string.Empty;
            enderecoDestinatario = string.Empty;

            dest destinatario = _nfe.infNFe.dest;
            if (destinatario.CNPJ != null)
            {
                cnpjDestinatario = Convert.ToInt64(destinatario.CNPJ).ToString("00'.'000'.'000'/'0000'-'00", FunctionNFe.CulturaPtBr);
            }
            else
            {
                cpfDestinatario = Convert.ToInt64(destinatario.CPF).ToString("000'.'000'.'000'-'00", FunctionNFe.CulturaPtBr);
            }

            enderDest enderDestinatario = _nfe.infNFe.dest.enderDest;
            enderecoDestinatario = enderDestinatario.xLgr;
            if (!string.IsNullOrEmpty(enderecoDestinatario) && !string.IsNullOrEmpty(enderDestinatario.nro))
            {
                enderecoDestinatario += ", " + enderDestinatario.nro;
            }

            graphics.DrawString(_nfe.infNFe.emit.xNome, _font10, Brushes.Black, 31, 50.2f);
            graphics.DrawString((!string.IsNullOrEmpty(cnpjDestinatario) ? cnpjDestinatario : cpfDestinatario), _font10, Brushes.Black, 187, 50.2f);
            graphics.DrawString(enderecoDestinatario, _font10, Brushes.Black, 31, 57.2f);
            graphics.DrawString(_nfe.infNFe.dest.enderDest.xBairro, _font10, Brushes.Black, 156, 57.2f);
            graphics.DrawString(Convert.ToInt32(_nfe.infNFe.dest.enderDest.CEP).ToString("00000-000", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, 210, 57.2f);
            graphics.DrawString(_nfe.infNFe.dest.enderDest.xMun, _font10, Brushes.Black, 31, 64.2f);
            graphics.DrawString(_nfe.infNFe.dest.enderDest.fone, _font10, Brushes.Black, 126, 64.2f);
            graphics.DrawString(_nfe.infNFe.dest.enderDest.UF, _font10, Brushes.Black, 175, 64.2f);
            graphics.DrawString(_nfe.infNFe.dest.IE, _font10, Brushes.Black, 187, 64.2f);

            //FATURAMENTO
            string textoDuplicatas = string.Empty;
            if (_nfe.infNFe.cobr != null)
            {
                foreach (dup duplicata in _nfe.infNFe.cobr.dup)
                {
                    textoDuplicatas += (textoDuplicatas == string.Empty ? null : "  |  ") + "Venc: " + Convert.ToDateTime(duplicata.dVenc).ToString("dd/MM/yyyy") + " Valor: " + Convert.ToDecimal(duplicata.vDup).ToString("N", FunctionNFe.CulturaPtBr);
                }
            }
            graphics.DrawString(textoDuplicatas, _fontArial7, Brushes.Black, 31, 71);

            //DATAS E HORAS
            graphics.DrawString(!string.IsNullOrEmpty(_nfe.infNFe.ide.dhEmi) ? Convert.ToDateTime(_nfe.infNFe.ide.dhEmi).ToString("dd/MM/yyyy") : "", _font10, Brushes.Black, 247, 50.2f);
            graphics.DrawString(!string.IsNullOrEmpty(_nfe.infNFe.ide.dhSaiEnt) ? Convert.ToDateTime(_nfe.infNFe.ide.dhSaiEnt).ToString("dd/MM/yyyy") : "", _font10, Brushes.Black, 247, 57.2f);
            graphics.DrawString(!string.IsNullOrEmpty(_nfe.infNFe.ide.dhSaiEnt) ? Convert.ToDateTime(_nfe.infNFe.ide.dhSaiEnt).ToString("HH:mm:ss"): "", _font10, Brushes.Black, 247, 64.2f);

            //VALORES DA NOTA
            StringFormat Alinhamento = new StringFormat();
            Alinhamento.Alignment = StringAlignment.Far;

            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vBC).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(31, 78.2f, 51, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vICMS).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(83, 78.2f, 51, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vBCST).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(135, 78.2f, 51, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vST).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(188, 78.2f, 51, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vProd).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(236, 78.2f, 42, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vFrete).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(31, 85.2f, 43, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vSeg).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(76, 85.2f, 40, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vDesc).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(118, 85.2f, 40, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vOutro).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(160, 85.2f, 40, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vIPI).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(202, 85.2f, 40, _font10.Height), Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vNF).ToString("N", FunctionNFe.CulturaPtBr), _font10, Brushes.Black, new RectangleF(236, 85.2f, 42, _font10.Height), Alinhamento);

            //DADOS TRANSPORTADORA
            if (_nfe.infNFe.transp != null)
            {
                string cnpjTransportador = string.Empty;
                string cpfTransportador = string.Empty;
                string rntc = string.Empty;
                string placa = string.Empty;
                string placaUf = string.Empty;

                if (_nfe.infNFe.transp != null)
                {
                    if (_nfe.infNFe.transp.transporta != null)
                    {
                        cnpjTransportador = Convert.ToInt64(_nfe.infNFe.transp.transporta.CNPJ).ToString("00'.'000'.'000'/'0000'-'00", FunctionNFe.CulturaPtBr);
                        cpfTransportador = Convert.ToInt64(_nfe.infNFe.transp.transporta.CPF).ToString("000'.'000'.'000'-'00", FunctionNFe.CulturaPtBr);
                        graphics.DrawString(_nfe.infNFe.transp.transporta.xNome, _font10, Brushes.Black, 31, 92.2f);
                    }

                    graphics.DrawString(_nfe.infNFe.transp.modFrete, _font10, Brushes.Black, 162, 92.2f);
                }
                if (_nfe.infNFe.transp.veicTransp != null)
                {
                    graphics.DrawString(_nfe.infNFe.transp.veicTransp.RNTC, _font10, Brushes.Black, 168, 81.2f);
                    graphics.DrawString(_nfe.infNFe.transp.veicTransp.placa, _font10, Brushes.Black, 196, 92.2f);
                    graphics.DrawString(_nfe.infNFe.transp.veicTransp.UF, _font10, Brushes.Black, 232, 92.2f);
                }
                graphics.DrawString((!string.IsNullOrEmpty(cnpjTransportador) ? cnpjTransportador : cpfTransportador), _font10, Brushes.Black, 244, 92.2f);
                if (_nfe.infNFe.transp.transporta != null)
                {
                    graphics.DrawString(_nfe.infNFe.transp.transporta.xEnder, _font10, Brushes.Black, 31, 99.2f);
                    graphics.DrawString(_nfe.infNFe.transp.transporta.xMun, _font10, Brushes.Black, 144, 99.2f);
                    graphics.DrawString(_nfe.infNFe.transp.transporta.UF, _font10, Brushes.Black, 232, 99.2f);
                    graphics.DrawString(_nfe.infNFe.transp.transporta.IE, _font10, Brushes.Black, 244, 99.2f);
                }
                if (_nfe.infNFe.transp.vol != null)
                {
                    graphics.DrawString(_nfe.infNFe.transp.vol.qVol.ToString(), _font10, Brushes.Black, 31, 106.2f);
                    graphics.DrawString(_nfe.infNFe.transp.vol.esp, _font10, Brushes.Black, 65, 106.2f);
                    graphics.DrawString(_nfe.infNFe.transp.vol.marca, _font10, Brushes.Black, 101, 106.2f);
                    graphics.DrawString(_nfe.infNFe.transp.vol.nVol, _font10, Brushes.Black, 144, 106.2f);
                    decimal pesoB = _nfe.infNFe.transp.vol.pesoB ?? 0;
                    decimal pesoL = _nfe.infNFe.transp.vol.pesoL ?? 0;
                    graphics.DrawString(pesoB.ToString("0.00"), _font10, Brushes.Black, 197, 106.2f);
                    graphics.DrawString(pesoL.ToString("0.00"), _font10, Brushes.Black, 245, 106.2f);
                }
            }

            //DADOS ISSQN
            if (_nfe.infNFe.total.ISSQNTot != null)
            {
                graphics.DrawString(_nfe.infNFe.emit.IM, _font10, Brushes.Black, 31, 166.2f);
                graphics.DrawString(_nfe.infNFe.total.ISSQNTot.vServ.ToString("0.00"), _font10, Brushes.Black, 97, 166.2f);
                graphics.DrawString(_nfe.infNFe.total.ISSQNTot.vBC.ToString("0.00"), _font10, Brushes.Black, 160, 166.2f);
                graphics.DrawString(_nfe.infNFe.total.ISSQNTot.vISS.ToString("0.00"), _font10, Brushes.Black, 226, 166.2f);
            }

            Alinhamento.Alignment = StringAlignment.Near;
            if (_nfe.infNFe.infAdic != null)
            {
                graphics.DrawString(_nfe.infNFe.infAdic.infCpl, _font5, Brushes.Black, new RectangleF(31, 173.2f, 190, 30), Alinhamento);
            }
        }

        #endregion

        #region " ImprimirCamposDemaisPaginas - Imprime as demais paginas apenas com os campos de produtos "

        //DEMAIS PAGINAS SÃO PREENCHIDAS APENAS COM OS CAMPOS DE PRODUTOS
        private void ImprimirCamposDemaisPaginas(System.Drawing.Printing.PrintPageEventArgs graphicsSaida)
        {
            Graphics graphics = graphicsSaida.Graphics;
            graphics.PageUnit = GraphicsUnit.Millimeter;
            Pen pen = new Pen(Brushes.Black, 0.1f);

            // instrução adicionada para evitar exception de elementos inexistentes no objeto nf (na deserialização caso não exista determinada tag o elemento correspondente também não é criado)

            //LINHA PRODUTOS 5 CENTIMETROS
            graphics.DrawLine(pen, 23, 52, 287, 52);
            //CODIGO PRODUTO
            graphics.DrawLine(pen, 64, 47, 64, 201);
            //DESCRIÇÃO DOS PRODUTOS
            graphics.DrawLine(pen, 136, 47, 136, 201);
            //NCM/SH
            graphics.DrawLine(pen, 146, 47, 146, 201);
            //CST
            graphics.DrawLine(pen, 151, 47, 151, 201);
            //CFOP
            graphics.DrawLine(pen, 157, 47, 157, 201);
            //UNIDADE
            graphics.DrawLine(pen, 163, 47, 163, 201);
            //QUANTIDADE
            graphics.DrawLine(pen, 171, 47, 171, 201);
            //VALOR UNITARIO
            graphics.DrawLine(pen, 187, 47, 187, 201);
            //VALOR TOTAL
            graphics.DrawLine(pen, 201, 47, 201, 201);
            //B CALC ICMS
            graphics.DrawLine(pen, 214, 47, 214, 201);
            //VALOR ICMS
            graphics.DrawLine(pen, 226, 47, 226, 201);
            //BASE DE CALCULO ICMS
            graphics.DrawLine(pen, 244, 47, 244, 201);
            //VALOR ICMS ST
            graphics.DrawLine(pen, 259, 47, 259, 201);
            //VALOR IPI
            graphics.DrawLine(pen, 269, 47, 269, 201);
            //BASE DE CALCULO 
            graphics.DrawLine(pen, 279, 47, 279, 201);

            //QUADRO DE PRODUTOS
            graphics.DrawString("CÓDIGO", _font5, Brushes.Black, 34, 48.2f);
            graphics.DrawString("DESCRIÇÃO DOS PRODUTOS/SERVIÇOS", _font5, Brushes.Black, 78, 48.2f);
            graphics.DrawString("NCM/SH", _font5, Brushes.Black, 137, 48.2f);
            graphics.DrawString("CST", _font5, Brushes.Black, 146.5f, 48.2f);
            graphics.DrawString("CFOP", _font5, Brushes.Black, 151.5f, 48.2f);
            graphics.DrawString("UNID", _font5, Brushes.Black, 157.5f, 48.2f);
            graphics.DrawString("QUANT.", _font5, Brushes.Black, 163.5f, 48.2f);
            graphics.DrawString("VALOR UNIT", _font5, Brushes.Black, 171.5f, 48.2f);
            graphics.DrawString("VALOR TOTAL", _font5, Brushes.Black, 187.5f, 48.2f);
            graphics.DrawString("B.CALC.ICMS", _font5, Brushes.Black, 201.1f, 48.2f);
            graphics.DrawString("VALOR ICMS", _font5, Brushes.Black, 214.5f, 48.2f);
            graphics.DrawString("B.CALC.ICMS ST", _font5, Brushes.Black, 227.3f, 48.2f);
            graphics.DrawString("VALOR ICMS ST", _font5, Brushes.Black, 244.5f, 48.2f);
            graphics.DrawString("VALOR IPI", _font5, Brushes.Black, 259.5f, 48.2f);
            graphics.DrawString("ALÍQ", _font5, Brushes.Black, 271.5f, 47.5f);
            graphics.DrawString("ICMS", _font5, Brushes.Black, 271.5f, 49.8f);
            graphics.DrawString("ALÍQ", _font5, Brushes.Black, 281, 47.5f);
            graphics.DrawString("IPI", _font5, Brushes.Black, 282, 49.8f);

        }

        #endregion

        #region " ImprimirDetalhes - Imprime informações de nf.infNFe.det "

        private void ImprimirDetalhes(System.Drawing.Printing.PrintPageEventArgs graphicsSaida)
        {
            float alturaLinha = 0;
            int alturaLinhaFinal = 0;
            int contadorJumpProdutos = 0;
            StringFormat alinhamento = new StringFormat();
            int preenchimentoLoteRastro = 0;
            string linhaLoteRastro = null;
            Pen pen = new Pen(Brushes.Black, 0.1f);
            alinhamento.Alignment = StringAlignment.Center;

            // instrução adicionada para evitar exception de elementos inexistentes no objeto nf (na deserialização caso não exista determinada tag o elemento correspondente também não é criado)

            //VERIFICA SE É PRIMEIRA PAGINA E LIMITA NUMERO DE PRODUTOS
            alturaLinha = _pagina == 1 ? 115 : 52;
            if (_pagina == 1)
            {
                //alturaLinhaFinal = 150;//Rotina Antiga
                alturaLinhaFinal = 160;
            }
            else
            {
                //alturaLinhaFinal = 150;//Rotina Antiga
                alturaLinhaFinal = 195;
            }

            Graphics graphics = graphicsSaida.Graphics;
            //PERCORRE TODA A MATRIZ DE PRODUTOS E IMPRIME OS MESMOS
            contadorJumpProdutos = 0;
            foreach (det detInf in _nfe.infNFe.det)
            {
                //VERIFICA SE PRODUTO NÃO FOI IMPRESSO
                if (contadorJumpProdutos >= _contadorProdutos)
                {
                    string valorIpi = string.Empty;
                    string aliquotaIpi = string.Empty;
                    string baseIcms = string.Empty;
                    string valorIcms = string.Empty;
                    string aliquotaIcms = string.Empty;
                    string baseIcmsSt = string.Empty;
                    string valorIcmsSt = string.Empty;
                    string cst = string.Empty;

                    if (detInf.imposto.IPI != null && detInf.imposto.IPI.IPITrib != null)
                    {
                        valorIpi = Convert.ToDecimal(detInf.imposto.IPI.IPITrib.vIPI).ToString("N", FunctionNFe.CulturaPtBr);
                        aliquotaIpi = Convert.ToDecimal(detInf.imposto.IPI.IPITrib.vIPI).ToString("N", FunctionNFe.CulturaPtBr);
                    }

                    FunctionNFe.GetIcms(_nfe.infNFe.emit.CRT, detInf, ref cst, ref baseIcms, ref valorIcms, ref aliquotaIcms, ref baseIcmsSt, ref valorIcmsSt);

                    graphics.DrawString(detInf.prod.cProd, _font6, Brushes.Black, 31, alturaLinha);
                    graphics.DrawString(detInf.prod.xProd, _font6, Brushes.Black, 65, alturaLinha);
                    graphics.DrawString(detInf.prod.NCM, _font6, Brushes.Black, 136.5f, alturaLinha);
                    graphics.DrawString(cst, _font6, Brushes.Black, 146.5f, alturaLinha);
                    graphics.DrawString(detInf.prod.CFOP, _font6, Brushes.Black, 151.5f, alturaLinha);
                    graphics.DrawString(detInf.prod.uCom, _font6, Brushes.Black, 157.5f, alturaLinha);

                    graphics.DrawString(detInf.prod.qCom.ToString("0.00"), _font6, Brushes.Black, new RectangleF(164, alturaLinha, 8, _font6.Height), alinhamento);
                    graphics.DrawString(Convert.ToDecimal(detInf.prod.vUnCom).ToString("N", FunctionNFe.CulturaPtBr), _font6, Brushes.Black, new RectangleF(175, alturaLinha, 17, _font6.Height), alinhamento);
                    graphics.DrawString(Convert.ToDecimal(detInf.prod.vProd).ToString("N", FunctionNFe.CulturaPtBr), _font6, Brushes.Black, new RectangleF(190, alturaLinha, 15, _font6.Height), alinhamento);
                    graphics.DrawString(baseIcms, _font6, Brushes.Black, new RectangleF(204, alturaLinha, 14, _font6.Height), alinhamento);
                    graphics.DrawString(valorIcms, _font6, Brushes.Black, new RectangleF(217, alturaLinha, 12, _font6.Height), alinhamento);
                    graphics.DrawString(baseIcmsSt, _font6, Brushes.Black, new RectangleF(231, alturaLinha, 16, _font6.Height), alinhamento);
                    graphics.DrawString(valorIcmsSt, _font6, Brushes.Black, new RectangleF(247, alturaLinha, 15, _font6.Height), alinhamento);
                    graphics.DrawString(valorIpi, _font6, Brushes.Black, new RectangleF(261, alturaLinha, 10, _font6.Height), alinhamento);
                    graphics.DrawString(aliquotaIcms, _font6, Brushes.Black, new RectangleF(271, alturaLinha, 10, _font6.Height), alinhamento);
                    graphics.DrawString(aliquotaIpi, _font6, Brushes.Black, new RectangleF(279, alturaLinha, 10, _font6.Height), alinhamento);

                    alturaLinha += 2.8f;

                    preenchimentoLoteRastro = 0;
                    linhaLoteRastro = string.Empty;
                    foreach (rastro rastroInf in detInf.prod.rastro)
                    {
                        preenchimentoLoteRastro += 1;
                        linhaLoteRastro += (string.IsNullOrEmpty(linhaLoteRastro) ? null : " ") + "Lote: " + rastroInf.nLote + " Qtd: " + rastroInf.qLote.ToString("#.##", FunctionNFe.CulturaPtBr);
                        if (preenchimentoLoteRastro == 3)
                        {
                            graphics.DrawString(linhaLoteRastro, _font5, Brushes.Black, 65, alturaLinha);
                            preenchimentoLoteRastro = 0;
                            linhaLoteRastro = string.Empty;
                            alturaLinha += 2.8f;
                        }
                    }
                    if (linhaLoteRastro != string.Empty)
                    {
                        graphics.DrawString(linhaLoteRastro, _font5, Brushes.Black, 65, alturaLinha);
                        alturaLinha += 2.8f;
                    }

                    //PARA USAR LINHAS PONTILHADAS HABILITAR FUNÇÃO ABAIXO
                    //pen.DashStyle = System.Drawing.Drawing2D.DashStyle.Dot;
                    graphics.DrawLine(pen, _pagina == 1 ? 31 : 23, alturaLinha, 287, alturaLinha);
                    alturaLinha += 1.0f;

                    _contadorProdutos += 1;

                    if (alturaLinha > alturaLinhaFinal)
                    {
                        graphicsSaida.HasMorePages = true;
                        break;
                    }
                    else
                    {
                        graphicsSaida.HasMorePages = false;
                    }
                }
                contadorJumpProdutos += 1;
            }

            //Sofware House e Versão NFe
            StringFormat alinhamentoFar = new StringFormat();
            graphics.DrawString( _msgSoftWareHouse, _font6, Brushes.Black,250, 201.5f, alinhamentoFar);

            _pagina += 1;
        }

        #endregion

        #region " ImprimirTextos - Imprime os textos "

        //INSERIR Imprimir_Textos NOS CAMPOS DA DANFE
        private void ImprimirTextos(System.Drawing.Printing.PrintPageEventArgs graphicsSaida)
        {
            Graphics graphics = graphicsSaida.Graphics;
            graphics.PageUnit = GraphicsUnit.Millimeter;

            //TERCEIRA LINHA
            graphics.DrawString("NOME/RAZÃO SOCIAL", _font6, Brushes.Black, 31, 47.2f);
            graphics.DrawString("CNPJ/CPF", _font6, Brushes.Black, 187, 47.2f);
            graphics.DrawString("DATA DA EMISSÃO", _font6, Brushes.Black, 247, 47.2f);

            //QUARTA LINHA
            graphics.DrawString("ENDEREÇO", _font6, Brushes.Black, 31, 54.2f);
            graphics.DrawString("BAIRRO/DESTRITO", _font6, Brushes.Black, 156, 54.2f);
            graphics.DrawString("CEP", _font6, Brushes.Black, 210, 54.2f);
            graphics.DrawString("DATA DA ENTRADA/SAÍDA", _font6, Brushes.Black, 247, 54.2f);

            //QUINTA LINHA
            graphics.DrawString("MUNICIPIO", _font6, Brushes.Black, 31, 61.2f);
            graphics.DrawString("FONE/FAX", _font6, Brushes.Black, 126, 61.2f);
            graphics.DrawString("UF", _font6, Brushes.Black, 175, 61.2f);
            graphics.DrawString("INSCRIÇÃO ESTADUAL", _font6, Brushes.Black, 187, 61.2f);
            graphics.DrawString("HORA DA ENTRADA/SAÍDA", _font6, Brushes.Black, 247, 61.2f);

            //SEXTA LINHA
            graphics.DrawString("BASE DE CÁLCULO DO ICMS", _font6, Brushes.Black, 31, 75.2f);
            graphics.DrawString("VALOR DO ICMS", _font6, Brushes.Black, 83, 75.2f);
            graphics.DrawString("BASE DE CÁLCULO DO ICMS ST", _font6, Brushes.Black, 135, 75.2f);
            graphics.DrawString("VALOR DO ICMS SUBSTITUIÇÃO", _font6, Brushes.Black, 188, 75.2f);
            graphics.DrawString("VALOR TOTAL DOS PRODUTOS", _font6, Brushes.Black, 242, 75.2f);

            //SEXTA LINHA
            graphics.DrawString("VALOR DO FRETE", _font6, Brushes.Black, 31, 82.2f);
            graphics.DrawString("VALOR SEGURO", _font6, Brushes.Black, 76, 82.2f);
            graphics.DrawString("DESCONTO", _font6, Brushes.Black, 118, 82.2f);
            graphics.DrawString("OUTRAS DESPESAS", _font6, Brushes.Black, 160, 82.2f);
            graphics.DrawString("VALOR DO IPI", _font6, Brushes.Black, 202, 82.2f);
            graphics.DrawString("VALOR TOTAL DA NOTA", _font6, Brushes.Black, 244, 82.2f);

            //SETIMA LINHA
            graphics.DrawString("NOME/RAZÃO SOCIAL", _font6, Brushes.Black, 31, 89.2f);
            graphics.DrawString("FRETE POR CONTA", _font6, Brushes.Black, 144, 89.2f);
            graphics.DrawString("CÓDIGO ANTT", _font6, Brushes.Black, 168, 89.2f);
            graphics.DrawString("PLACA DO VEÍCULO", _font6, Brushes.Black, 196, 89.2f);
            graphics.DrawString("UF", _font6, Brushes.Black, 232, 89.2f);
            graphics.DrawString("CNPJ/CPF", _font6, Brushes.Black, 244, 89.2f);

            //SUBLINHAS DO FRETE
            graphics.DrawString("0-EMITENTE", _font5, Brushes.Black, 145, 91.6f);
            graphics.DrawString("1-DESTINATARIO", _font5, Brushes.Black, 145, 94f);

            //OITAVA LINHA
            graphics.DrawString("ENDEREÇO", _font6, Brushes.Black, 31, 96.2f);
            graphics.DrawString("MUNICÍPIO", _font6, Brushes.Black, 144, 96.2f);
            graphics.DrawString("UF", _font6, Brushes.Black, 232, 96.2f);
            graphics.DrawString("INSCRIÇÃO ESTADUAL", _font6, Brushes.Black, 244, 96.2f);

            //NONA LINHA
            graphics.DrawString("QUANTIDADE", _font6, Brushes.Black, 31, 103.2f);
            graphics.DrawString("ESPÉCIE", _font6, Brushes.Black, 65, 103.2f);
            graphics.DrawString("MARCA", _font6, Brushes.Black, 101, 103.2f);
            graphics.DrawString("NÚMERO", _font6, Brushes.Black, 144, 103.2f);
            graphics.DrawString("PESO BRUTO", _font6, Brushes.Black, 197, 103.2f);
            graphics.DrawString("PESO LÍQUIDO", _font6, Brushes.Black, 245, 103.2f);

            //QUADRO DE PRODUTOS
            graphics.DrawString("CÓDIGO", _font5, Brushes.Black, 34, 111.2f);
            graphics.DrawString("DESCRIÇÃO DOS PRODUTOS/SERVIÇOS", _font5, Brushes.Black, 78, 111.2f);
            graphics.DrawString("NCM/SH", _font5, Brushes.Black, 137, 111.2f);
            graphics.DrawString("CST", _font5, Brushes.Black, 146.5f, 111.2f);
            graphics.DrawString("CFOP", _font5, Brushes.Black, 151.5f, 111.2f);
            graphics.DrawString("UNID", _font5, Brushes.Black, 157.5f, 111.2f);
            graphics.DrawString("QUANT.", _font5, Brushes.Black, 163.5f, 111.2f);
            graphics.DrawString("VALOR UNIT", _font5, Brushes.Black, 171.5f, 111.2f);
            graphics.DrawString("VALOR TOTAL", _font5, Brushes.Black, 187.5f, 111.2f);
            graphics.DrawString("B. CALC. ICMS", _font5, Brushes.Black, 201.1f, 111.2f);
            graphics.DrawString("VALOR ICMS", _font5, Brushes.Black, 214.5f, 111.2f);
            graphics.DrawString("B. CALC. ICMS ST", _font5, Brushes.Black, 227.3f, 111.2f);
            graphics.DrawString("VALOR ICMS ST", _font5, Brushes.Black, 244.5f, 111.2f);
            graphics.DrawString("VALOR IPI", _font5, Brushes.Black, 259.5f, 111.2f);
            graphics.DrawString("ALÍQ", _font5, Brushes.Black, 271.5f, 110.5f);
            graphics.DrawString("ICMS", _font5, Brushes.Black, 271.5f, 112.5f);
            graphics.DrawString("ALÍQ", _font5, Brushes.Black, 281, 110.5f);
            graphics.DrawString("IPI", _font5, Brushes.Black, 282, 112.5f);

            //DECIMA LINHA
            graphics.DrawString("INSCRIÇÃO MUNICIPAL", _font6, Brushes.Black, 31, 163.2f);
            graphics.DrawString("VALOR TOTAL DOS SERVIÇOS", _font6, Brushes.Black, 97, 163.2f);
            graphics.DrawString("BASE DE CALCULO ISSQN", _font6, Brushes.Black, 160, 163.2f);
            graphics.DrawString("VALOR DO ISSQN", _font6, Brushes.Black, 226, 163.2f);

            //DECIMA PRIMEIRA LINHA
            graphics.DrawString("INFORMAÇÕES COMPLEMENTARES", _font6, Brushes.Black, 31, 170.2f);
            graphics.DrawString("RESERVADO AO FISCO", _font6, Brushes.Black, 224, 170.2f);

            //INSERIR BLOCOS DE CAMPOS
            System.Drawing.StringFormat formatoVertical = null;
            System.Drawing.Point posicaoTexto = default(System.Drawing.Point);
            System.Drawing.Drawing2D.Matrix rotacionadorDeTexto = graphics.Transform;

            formatoVertical = new StringFormat(StringFormatFlags.DirectionVertical);
            posicaoTexto = new Point((int)27.5f, 65);

            rotacionadorDeTexto.RotateAt(180, posicaoTexto);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("DESTINATÁRIO/", _font5B, Brushes.Black, posicaoTexto, formatoVertical);
            posicaoTexto = new Point((int)25.5f, 66);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("REMETENTE", _font5B, Brushes.Black, posicaoTexto, formatoVertical);

            posicaoTexto = new Point((int)27.5f, 55);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("FATURA", _font5B, Brushes.Black, posicaoTexto, formatoVertical);

            posicaoTexto = new Point((int)27.5f, (int)43.5f);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("CÁLCULO", _font5B, Brushes.Black, posicaoTexto, formatoVertical);
            posicaoTexto = new Point((int)25.5f, (int)43.5f);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("IMPOSTO", _font5B, Brushes.Black, posicaoTexto, formatoVertical);

            posicaoTexto = new Point((int)27.5f, (int)18.5f);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("TRANSPORTADOR/VOLUMES", _font5B, Brushes.Black, posicaoTexto, formatoVertical);
            posicaoTexto = new Point((int)25.5, 22);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("TRANSPORTADOS", _font5B, Brushes.Black, posicaoTexto, formatoVertical);

            posicaoTexto = new Point((int)27.5f, -23);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("DADOS DOS PRODUTOS/SERVIÇOS", _font5B, Brushes.Black, posicaoTexto, formatoVertical);

            //Linha Verticais Dados ISSQN(DADOS SÓ APARECERAM NA PRIMEIRA PAGINA)
            if (_pagina == 1)
            {
                posicaoTexto = new Point((int)27.5f, -41);
                graphics.Transform = rotacionadorDeTexto;
                graphics.DrawString("CÁLCULO", _font5B, Brushes.Black, posicaoTexto, formatoVertical);
                posicaoTexto = new Point((int)25.5f, -40);
                graphics.Transform = rotacionadorDeTexto;
                graphics.DrawString("ISSQN", _font5B, Brushes.Black, posicaoTexto, formatoVertical);
            }

            posicaoTexto = new Point((int)27.5f, -66);
            graphics.Transform = rotacionadorDeTexto;
            graphics.DrawString("DADOS ADICIONAIS", _font5B, Brushes.Black, posicaoTexto, formatoVertical);

            //VOLTA TEXTO PARA POSIÇÃO ORIGINAL
            graphics.ResetTransform();
        }

        #endregion

        #region " ImprimirDesenhoDeRetangulos - Imprime as linhas "

        //DESENHAR LINHAS DA DANFE
        public void ImprimirDesenhoDeRetangulos(System.Drawing.Printing.PrintPageEventArgs graphicsSaida)
        {
            Graphics graphics = graphicsSaida.Graphics;
            //CONVERT A MEDIDA EM MILIMETROS
            Pen pen = new Pen(Brushes.Black, 0.1f);
            graphics.PageUnit = GraphicsUnit.Millimeter;

            graphics.DrawRectangle(pen, 161, 92, 4, 4);

            //CONJUNTO DE LINHAS HORIZONTAIS DADOS CLIENTE E TRANSPORTADORA
            graphics.DrawLine(pen, 31, 54, 287, 54);
            graphics.DrawLine(pen, 31, 61, 287, 61);
            graphics.DrawLine(pen, 31, 68, 287, 68);
            graphics.DrawLine(pen, 31, 75, 287, 75);
            graphics.DrawLine(pen, 31, 82, 287, 82);
            graphics.DrawLine(pen, 31, 89, 287, 89);
            graphics.DrawLine(pen, 31, 96, 287, 96);
            graphics.DrawLine(pen, 31, 103, 287, 103);
            graphics.DrawLine(pen, 31, 110, 287, 110);

            //CONJUNTO DE LINHAS HORIZONTAIS DADOS PRODUTOS
            graphics.DrawLine(pen, 31, 163, 287, 163);
            graphics.DrawLine(pen, 31, 170, 287, 170);
            //.DrawLine(pen, 31, 177, 287, 177)

            //NOME / CNPJ-CPF / DATA DE EMISSÃO
            graphics.DrawLine(pen, 186, 47, 186, 54);
            graphics.DrawLine(pen, 246, 47, 246, 54);

            //ENDEREÇO / BAIRRO / CEP / DATA ENTRADA - SAÍDA
            graphics.DrawLine(pen, 155, 54, 155, 61);
            graphics.DrawLine(pen, 209, 54, 209, 61);
            graphics.DrawLine(pen, 246, 54, 246, 61);

            //MUNICIPIO / FONE / UF / INSCRIÇÃO ESTADUAL / HORA ENTRADA E SAÍDA
            graphics.DrawLine(pen, 125, 61, 125, 68);
            graphics.DrawLine(pen, 174, 61, 174, 68);
            graphics.DrawLine(pen, 186, 61, 186, 68);
            graphics.DrawLine(pen, 246, 61, 246, 68);

            //BASE DE CALCULO DO ICMS / VALOR ICMS / BASE SUBST. ICMS ST / VALOR SUBST ICMS / VALOR TOTAL DOS PRODUTOS 
            graphics.DrawLine(pen, 82, 75, 82, 82);
            graphics.DrawLine(pen, 134, 75, 134, 82);
            graphics.DrawLine(pen, 187, 75, 187, 82);
            graphics.DrawLine(pen, 241, 75, 241, 82);

            //VALOR FRETE / VALOR SEGURO / DESCONTO / OUTRAS DESPESAS ACESSORAIS / VALOR TOTAL DO IPI / VALOR TOTAL DA NOTA 
            graphics.DrawLine(pen, 75, 82, 75, 89);
            graphics.DrawLine(pen, 117, 82, 117, 89);
            graphics.DrawLine(pen, 159, 82, 159, 89);
            graphics.DrawLine(pen, 201, 82, 201, 89);
            graphics.DrawLine(pen, 243, 82, 243, 89);

            //NOME RAZÃO SOCIAL / FRETE POR CONTA / CÓDIGO ANTT / PLACA VEÍCULO / UF / CNPJ - CPF
            graphics.DrawLine(pen, 143, 89, 143, 96);
            graphics.DrawLine(pen, 167, 89, 167, 96);
            graphics.DrawLine(pen, 195, 89, 195, 96);
            graphics.DrawLine(pen, 231, 89, 231, 96);
            graphics.DrawLine(pen, 243, 89, 243, 96);

            //ENDEREÇO / MUNICIPIO / UF / INCRIÇÃO ESTADUAL
            graphics.DrawLine(pen, 143, 96, 143, 103);
            graphics.DrawLine(pen, 231, 96, 231, 103);
            graphics.DrawLine(pen, 243, 96, 243, 103);

            //QUANTIDADE / ESPECIE / MARCA / NUMERO / PESO BRUTO / PESO LIQUIDO
            graphics.DrawLine(pen, 64, 103, 64, 110);
            graphics.DrawLine(pen, 100, 103, 100, 110);
            graphics.DrawLine(pen, 143, 103, 143, 110);
            graphics.DrawLine(pen, 196, 103, 196, 110);
            graphics.DrawLine(pen, 244, 103, 244, 110);

            //LINHA PRODUTOS 5 CENTIMETROS
            graphics.DrawLine(pen, 31, 115, 287, 115);

            //CODIGO PRODUTO
            graphics.DrawLine(pen, 64, 110, 64, 163);
            //DESCRIÇÃO DOS PRODUTOS
            graphics.DrawLine(pen, 136, 110, 136, 163);
            //NCM/SH
            graphics.DrawLine(pen, 146, 110, 146, 163);
            //CST
            graphics.DrawLine(pen, 151, 110, 151, 163);
            //CFOP
            graphics.DrawLine(pen, 157, 110, 157, 163);
            //UNIDADE
            graphics.DrawLine(pen, 163, 110, 163, 163);
            //QUANTIDADE
            graphics.DrawLine(pen, 171, 110, 171, 163);
            //VALOR UNITARIO
            graphics.DrawLine(pen, 187, 110, 187, 163);
            //VALOR TOTAL
            graphics.DrawLine(pen, 201, 110, 201, 163);
            //B CALC ICMS
            graphics.DrawLine(pen, 214, 110, 214, 163);
            //VALOR ICMS
            graphics.DrawLine(pen, 226, 110, 226, 163);
            //BASE DE CALCULO ICMS
            graphics.DrawLine(pen, 244, 110, 244, 163);
            //VALOR ICMS ST
            graphics.DrawLine(pen, 259, 110, 259, 163);
            //VALOR IPI
            graphics.DrawLine(pen, 269, 110, 269, 163);
            //BASE DE CALCULO 
            graphics.DrawLine(pen, 279, 110, 279, 163);

            //CALCULO ISSQN
            graphics.DrawLine(pen, 96, 163, 96, 170);
            graphics.DrawLine(pen, 159, 163, 159, 170);
            graphics.DrawLine(pen, 225, 163, 225, 170);

            //FISCO
            graphics.DrawLine(pen, 223, 170, 223, 201);

            //DESENHAR RETANGULOS COM PREECHIMENTO BLOCOS DE CAMPOS
            graphics.FillRectangle(Brushes.LightGray, 25, 49, 5, 17);
            graphics.FillRectangle(Brushes.LightGray, 25, 68, 5, 7);
            graphics.FillRectangle(Brushes.LightGray, 25, 77, 5, 10);
            graphics.FillRectangle(Brushes.LightGray, 25, 89, 5, 23);
            graphics.FillRectangle(Brushes.LightGray, 25, 114, 5, 46);
            graphics.FillRectangle(Brushes.LightGray, 25, 162, 5, 10);
            graphics.FillRectangle(Brushes.LightGray, 25, 173, 5, 27);
        }

        #endregion

        #region " DrawRoundedRectangle - Sub para campos arredondados "

        //FUNÇÃO PARA CAMPOS ARREDONDADOS

        private void DrawRoundedRectangle(System.Drawing.Graphics g, Rectangle r, int d, Pen p)
        {
            g.DrawArc(p, r.X, r.Y, d, d, 180, 90);
            g.DrawLine(p, Convert.ToInt32(r.X + d / 2), r.Y, Convert.ToInt32(r.X + r.Width - d / 2), r.Y);
            g.DrawArc(p, r.X + r.Width - d, r.Y, d, d, 270, 90);
            g.DrawLine(p, r.X, Convert.ToInt32(r.Y + d / 2), r.X, Convert.ToInt32(r.Y + r.Height - d / 2));
            g.DrawLine(p, Convert.ToInt32(r.X + r.Width), Convert.ToInt32(r.Y + d / 2), Convert.ToInt32(r.X + r.Width), Convert.ToInt32(r.Y + r.Height - d / 2));
            g.DrawLine(p, Convert.ToInt32(r.X + d / 2), Convert.ToInt32(r.Y + r.Height), Convert.ToInt32(r.X + r.Width - d / 2), Convert.ToInt32(r.Y + r.Height));
            g.DrawArc(p, r.X, r.Y + r.Height - d, d, d, 90, 90);
            g.DrawArc(p, r.X + r.Width - d, r.Y + r.Height - d, d, d, 0, 90);
        }

        #endregion

    }
}

