﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Drawing.Printing;
using System.IO;
using BarcodeLib;
using BarcodeLib.Symbologies;
using System.Xml;
using System.Linq;
using System.Xml.Linq;
using System.Xml.XPath;
using System.Text.RegularExpressions;

using NFeLib.NFE.BaseNF;
using NFeLib.Utils;
using NFeLib.NFE.BaseNF.Informacoes.Emitente;
using NFeLib.NFE.Utils;
using NFeLib.NFE.BaseNF.Informacoes.Destinatario;
using NFeLib.NFE.BaseNF.Informacoes.Detalhes;
using NFeLib.NFE.BaseNF.Informacoes.PagCobranca;
using NFeLib.NFE.BaseNF.Informacoes.TranspVolumes;


/**************************************************************/
/*  Classe Convetida de VB.Net para C#                        */
/*  FONTE SITE: http://vbmania.com.br - TÓPICO NFE VB.NET     */
/*  CLASSE PARA IMPRESSÃO DO DANFE SEM O USO DE GERADORES     */
/*  NOME: DANIEL COUTINHO DE MELO                             */
/*  EMAIL: DANIELCPAETE@GMAIL.COM                             */
/*  DATA: 24-02-2010 PORTO ALEGRE - RS                        */
/*  ATUALIZAÇÃO DELWOKO VBMANIA 06/01/2010                    */
/**************************************************************/

namespace NFeLib.Danfes
{

    public class DanfeRetrato : IDanfe
    {
        private int _contadorProdutos = 0;
        private int _pagina = 1;
        private int _totalPaginas;
        private bool _paginaExtra;
        private int _paginaExtraHeight;
        private string _paginaExtraDados;
        private bool _calculoTotalPaginasEfetuado;
        private bool _processandoImpressaoProdutos = true;
        private Dictionary<int, int> _listaAlturaLinhaFinal = new Dictionary<int, int>();
        private Dictionary<int, int> _listaRetanguloProdutos = new Dictionary<int, int>();
        private Dictionary<int, string> _listaDadosAdicionais = new Dictionary<int, string>();
        private NFe _nfe;
        private string _protocolo;
        private string _dhRecbto;

        //FONTES DA DANFE
        private Font _font12B = new Font("Times New Roman", 12, FontStyle.Bold);
        private Font _font6 = new Font("Times New Roman", 6, FontStyle.Regular);
        private Font _font6B = new Font("Times New Roman", 6, FontStyle.Bold);
        private Font _font5B = new Font("Courier New", 5, FontStyle.Bold);
        private Font _font7 = new Font("Times New Roman", 7, FontStyle.Regular);
        private Font _font10 = new Font("Times New Roman", 10, FontStyle.Regular);
        private Font _font8B = new Font("Times New Roman", 8, FontStyle.Bold);
        private Font _fontArial7 = new Font("Arial", 7, FontStyle.Bold);
        private Font _fontArial6 = new Font("Arial", 6, FontStyle.Regular);
        private Font _fontArial8 = new Font("Arial", 8, FontStyle.Bold);

        private string _msgSoftWareHouse = string.Empty;
        
        public PrintDocument RptPrintDocument { get; set; }

        public DanfeRetrato(NFe nfeRef, string numProt, string dataProt,string msgSoftWareHouse)
        {
            this._msgSoftWareHouse = msgSoftWareHouse;
            PrintDocument printDoc = new PrintDocument();
            _nfe = nfeRef;
            _protocolo = numProt;
            _dhRecbto = Convert.ToDateTime(dataProt).ToString("dd/MM/yyyy HH:mm:ss");

            //ASSOCIA OS EVENTOS DE IMPRESSÃO COM MINHAS FUNÇÕES
            printDoc.BeginPrint += InicioImpressao;
            printDoc.PrintPage += ImprimirDanfe;

            printDoc.DefaultPageSettings.Landscape = false;
            printDoc.DefaultPageSettings.PrinterSettings.Copies = 1;

            //AS MARGENS PRECISAM SER AJUSTADAS PARA QUE A IMPRESSÃO INICIAL TENHA 5 MILIMETROS
            printDoc.DefaultPageSettings.Margins = new Margins(11, 11, 11, 11);
            RptPrintDocument = printDoc;
        }

        public DanfeRetrato(XmlDocument xmlDoc,string msgSoftWareHouse)
        {
            this._msgSoftWareHouse = msgSoftWareHouse;
            PrintDocument printDoc = new PrintDocument();
            _nfe = new NFe();

            XDocument xDocTmp = XDocument.Parse(xmlDoc.OuterXml);
            XDocument xDoc = XDocument.Parse(Regex.Replace(xDocTmp.ToString(), "xmlns=\".+\"", String.Empty));

            // NFe já processada e com o protocolo
            if (xDoc.XPathSelectElements("nfeProc/protNFe/infProt/chNFe").Count() > 0)
            {
                _protocolo = xDoc.XPathSelectElements("nfeProc/protNFe/infProt/nProt").FirstOrDefault().Value;
                _dhRecbto = Convert.ToDateTime(xDoc.XPathSelectElements("nfeProc/protNFe/infProt/dhRecbto").FirstOrDefault().Value).ToString("dd/MM/yyyy HH:mm:ss");
                nfeProc procNFe = FunctionNFe.DeserializarNFe<nfeProc>(xmlDoc.OuterXml);
                _nfe = procNFe.NFe; 
            }
            else
            {
                _nfe = (FunctionNFe.DeserializarNFe<nfeProc>(xmlDoc.ToString())).NFe;
            }

            //ASSOCIA OS EVENTOS DE IMPRESSÃO COM MINHAS FUNÇÕES
            printDoc.BeginPrint += InicioImpressao;
            printDoc.PrintPage += ImprimirDanfe;

            printDoc.DefaultPageSettings.Landscape = false;
            printDoc.DefaultPageSettings.PrinterSettings.Copies = 1;

            //AS MARGENS PRECISAM SER AJUSTADAS PARA QUE A IMPRESSÃO INICIAL TENHA 5 MILIMETROS
            printDoc.DefaultPageSettings.Margins = new Margins(11, 11, 11, 11);
            RptPrintDocument = printDoc;
        }

        #region " InicioImpressao - inicializa algumas variaves e arrays "

        private void InicioImpressao(object sender, PrintEventArgs e)
        {
            //ZERA VARIAVEIS DE CONTROLE DE IMPRESSÃO
            _pagina = 1;
            _contadorProdutos = 0;
            _paginaExtra = false;
            _paginaExtraDados = null;
            _calculoTotalPaginasEfetuado = false;
            _processandoImpressaoProdutos = true;
            _listaAlturaLinhaFinal.Clear();
            _listaRetanguloProdutos.Clear();
            _listaDadosAdicionais.Clear();
        }

        #endregion

        #region " ImprimirDanfe - Efetua a chamada para as subs de impressão "

        private void ImprimirDanfe(object sender, System.Drawing.Printing.PrintPageEventArgs e)
        {
            //VERIFICA SE É PRIMEIRA FOLHA OU DEMAIS PARA FORMATAR A IMPRESSÃO
            if (!_calculoTotalPaginasEfetuado)
            {
                CalculaTotalPaginas(e);
            }
            ImprimirCabecalho(e);

            if (_processandoImpressaoProdutos)
            {
                if (_pagina == 1)
                {
                    ImprimirDados(e);
                    ImprimirDadosAdicionais(e, false);
                }
                else
                {
                    if (_listaDadosAdicionais.ContainsKey(_pagina))
                    {
                        ImprimirDadosAdicionais(e, false);
                    }
                }
                ImprimirDetalhes(e);
                // Imprime pagina extra de dados adicionais
            }
            else
            {
                ImprimirDadosAdicionais(e, true);
            }

        }


        #endregion

        #region " CalculaTotalPaginas - Calcula o total de paginas e inicializa algumas informaçoes usadas no processamento "

        private void CalculaTotalPaginas(PrintPageEventArgs graficSaida)
        {
            Dictionary<int, bool> dadosAdicionaisVerificados = new Dictionary<int, bool>();
            int alturaLinha = 0;
            string linhaLoteRastro = null;
            string dadosAdicionais = null;
            StringFormat alinhamentoNear = new StringFormat();
            RectangleF descricaoRect = default(RectangleF);
            SizeF stringSize = new SizeF();
            int charactersFitted = 0;
            int linesFilled = 0;

            alinhamentoNear.LineAlignment = StringAlignment.Near;
            alturaLinha = 525;
            alturaLinha += 34;
            _totalPaginas = 1;

            if (_nfe.infNFe.infAdic == null)
            {
                dadosAdicionais = string.Empty;
            }
            else
            {
                dadosAdicionais = _nfe.infNFe.infAdic.infCpl == null ? string.Empty : _nfe.infNFe.infAdic.infCpl;
            }

            dadosAdicionaisVerificados.Add(1, false);
            _listaAlturaLinhaFinal.Add(1, 950);

            Graphics graphics = graficSaida.Graphics;

            foreach (det detInf in _nfe.infNFe.det)
            {
                descricaoRect = new RectangleF(121, alturaLinha, 208, 24);
                stringSize = graphics.MeasureString(detInf.prod.xProd, _font7, descricaoRect.Size, alinhamentoNear, out charactersFitted, out linesFilled);
                alturaLinha += linesFilled * 12;

                linhaLoteRastro = string.Empty;
                foreach (rastro rastroInf in detInf.prod.rastro)
                {
                    linhaLoteRastro += (string.IsNullOrEmpty(linhaLoteRastro) ? null : " ") + "Lote: " + rastroInf.nLote + " Qtd: " + rastroInf.qLote.ToString("#.##", FunctionNFe.CulturaPtBr);
                }

                if (linhaLoteRastro != string.Empty)
                {
                    descricaoRect = new RectangleF(121, alturaLinha, 208, 24);
                    stringSize = graphics.MeasureString(linhaLoteRastro, _font7, descricaoRect.Size, alinhamentoNear, out charactersFitted, out linesFilled);
                    alturaLinha += linesFilled * 12;
                }

                alturaLinha += 4;

                if (!dadosAdicionaisVerificados[_totalPaginas])
                {
                    dadosAdicionaisVerificados[_totalPaginas] = true;

                    if (!string.IsNullOrEmpty(dadosAdicionais))
                    {
                        if (_totalPaginas == 1)
                        {
                            descricaoRect = new RectangleF(12, 1023, 505, 66);
                        }
                        else
                        {
                            descricaoRect = new RectangleF(12, 1023, 790, 66);
                        }
                        stringSize = graphics.MeasureString(dadosAdicionais, _font6, descricaoRect.Size, alinhamentoNear, out charactersFitted, out linesFilled);
                        if (charactersFitted < dadosAdicionais.Length)
                        {
                            _listaDadosAdicionais.Add(_totalPaginas, dadosAdicionais.Substring(0, charactersFitted));
                            dadosAdicionais = dadosAdicionais.Remove(0, charactersFitted);
                        }
                        else
                        {
                            _listaDadosAdicionais.Add(_totalPaginas, dadosAdicionais);
                            dadosAdicionais = null;
                        }
                    }

                    // Caso não seja a primeira pagina e não contenha dados adicionais, redefine o valor limite da altura da linha final de produtos
                    if (_totalPaginas != 1 && !_listaDadosAdicionais.ContainsKey(_totalPaginas))
                    {
                        _listaAlturaLinhaFinal[_totalPaginas] = 1050;
                    }
                }

                if (alturaLinha > _listaAlturaLinhaFinal[_totalPaginas] && detInf.nItem != _nfe.infNFe.det[_nfe.infNFe.det.Count - 1].nItem)
                {
                    _listaRetanguloProdutos.Add(_totalPaginas, alturaLinha - 4);
                    _totalPaginas += 1;
                    alturaLinha = 260;
                    alturaLinha += 34;
                    dadosAdicionaisVerificados.Add(_totalPaginas, false);
                    _listaAlturaLinhaFinal.Add(_totalPaginas, 980);
                }
            }

            if (!dadosAdicionaisVerificados[_totalPaginas])
            {
                dadosAdicionaisVerificados[_totalPaginas] = true;

                if (!string.IsNullOrEmpty(dadosAdicionais))
                {
                    if (_totalPaginas == 1)
                    {
                        descricaoRect = new RectangleF(12, 1023, 505, 66);
                    }
                    else
                    {
                        descricaoRect = new RectangleF(12, 1023, 790, 66);
                    }
                    stringSize = graphics.MeasureString(dadosAdicionais, _font6, descricaoRect.Size, alinhamentoNear, out charactersFitted, out linesFilled);
                    if (charactersFitted < dadosAdicionais.Length)
                    {
                        _listaDadosAdicionais.Add(_totalPaginas, dadosAdicionais.Substring(0, charactersFitted));
                        dadosAdicionais = dadosAdicionais.Remove(0, charactersFitted);
                    }
                    else
                    {
                        _listaDadosAdicionais.Add(_totalPaginas, dadosAdicionais);
                        dadosAdicionais = null;
                    }
                }

                // Caso não seja a primeira pagina e não contenha dados adicionais, redefine o valor limite da altura da linha final de produtos
                if (_totalPaginas != 1 && !_listaDadosAdicionais.ContainsKey(_totalPaginas))
                {
                    _listaAlturaLinhaFinal[_totalPaginas] = 1050;
                }
            }

            if (!_listaRetanguloProdutos.ContainsValue(_totalPaginas))
            {
                _listaRetanguloProdutos.Add(_totalPaginas, alturaLinha - 4);
            }

            // Faz ultima verificação para saber se ainda há informações adicionais para serem impressas
            if (!string.IsNullOrEmpty(dadosAdicionais))
            {
                _paginaExtra = true;
                descricaoRect = new RectangleF(12, 277, 790, 1050);
                stringSize = graphics.MeasureString(dadosAdicionais, _font6, descricaoRect.Size, alinhamentoNear, out charactersFitted, out linesFilled);
                _paginaExtraDados = dadosAdicionais;
                _paginaExtraHeight = (int)stringSize.Height + 6;
                _totalPaginas += 1;
            }
            _calculoTotalPaginasEfetuado = true;
        }

        #endregion

        #region " Imprimir_Cabecalho - Imprime cabeçalho e guia do cliente "

        //GERA CABEÇALHO E GUIA DO CLIENTE
        private void ImprimirCabecalho(PrintPageEventArgs graphicsSaida)
        {
            Pen pen = new Pen(Brushes.Black, 0.5f);
            Graphics graphics = graphicsSaida.Graphics;

            //PROTOCOLO DO CLIENTE
            graphics.DrawRectangle(pen, 10, 10, 785, 60);
            graphics.DrawLine(pen, 10, 30, 640, 30);
            graphics.DrawLine(pen, 140, 30, 140, 70);
            graphics.DrawLine(pen, 640, 10, 640, 70);

            graphics.DrawString("RECEBEMOS DE " + _nfe.infNFe.emit.xNome.Left(52) + " OS PRODUTOS CONSTANTES NA NOTA FISCAL INDICADA AO LADO", _fontArial6, Brushes.Black, 10, 13, new StringFormat());

            graphics.DrawString("DATA E HORA", _fontArial6, Brushes.Black, 10, 32, new StringFormat());
            graphics.DrawString("IDENTIFICAÇÃO DO RECEBEDOR", _fontArial6, Brushes.Black, 142, 32, new StringFormat());

            graphics.DrawString("NF-e", _fontArial8, Brushes.Black, 652, 13, new StringFormat());
            graphics.DrawString("Nº   " + Int32.Parse(_nfe.infNFe.ide.nNF).ToString("000'.'000'.'000", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 652, 31, new StringFormat());
            graphics.DrawString("SÉRIE 1 - FOLHA " + _pagina + "/" + _totalPaginas, _fontArial7, Brushes.Black, 652, 50, new StringFormat());

            //------------Logotipo Emitente--------------------
            graphics.DrawRectangle(pen,10, 72, 315, 121);
            string pathLogo = Directory.GetCurrentDirectory() + @"\LogoEmpresa.jpg";
            //Caso exista o Logo carrega no Danfe
            if (File.Exists(pathLogo))
            {
                graphics.DrawImage(Image.FromFile(pathLogo), 15, 90, 80, 80);
            }
            else
            {
                //Caso não exista imprime o Logo Padrão da NFe
                graphics.DrawImage(NFeLib.Properties.Resources.LogoNFe, 15, 90, 80, 80);
            }
            //--------------------Imprime os Dados do Emitente ao lado do Logo--------------------
            string enderecoEmitente = string.Empty;
            string municipioEmitente = string.Empty;
            string ufEmitente = string.Empty;
            string cepEmitente = string.Empty;
            string foneEmitente = string.Empty;

            enderEmit enderEmitente = _nfe.infNFe.emit.enderEmit;
            enderecoEmitente = enderEmitente.xLgr;
            if (!string.IsNullOrEmpty(enderecoEmitente) && !string.IsNullOrEmpty(enderEmitente.nro))
            {
                enderecoEmitente += ", " + enderEmitente.nro;
            }
            municipioEmitente = enderEmitente.xMun;
            ufEmitente = enderEmitente.UF;
            cepEmitente = "CEP: " + Convert.ToInt32(enderEmitente.CEP).ToString("00000-000", FunctionNFe.CulturaPtBr);
            foneEmitente = "FONE: " + enderEmitente.fone;
            graphics.DrawString(_nfe.infNFe.emit.xNome.QuebrarString(20), _fontArial8, Brushes.Black, 110, 80, new StringFormat());
            graphics.DrawString(enderecoEmitente.ToUpper().QuebrarString(28), _fontArial6, Brushes.Black, 110, 130, new StringFormat());
            graphics.DrawString((_nfe.infNFe.emit.enderEmit.xBairro.ToUpper() + " - " + cepEmitente).QuebrarString(40), _fontArial6, Brushes.Black, 110, 140);
            graphics.DrawString((municipioEmitente + (string.IsNullOrEmpty(ufEmitente) ? null : ", ") + ufEmitente).ToUpper().QuebrarString(28), _fontArial6, Brushes.Black, 110, 150);
            graphics.DrawString(foneEmitente, _fontArial6, Brushes.Black, 110, 160);

            graphics.DrawString("DANFE", _font12B, Brushes.Black, 350, 75, new StringFormat());
            graphics.DrawString("Documento Auxiliar da", _fontArial6, Brushes.Black, 330, 95, new StringFormat());
            graphics.DrawString("Nota Fiscal Eletrônica", _fontArial6, Brushes.Black, 330, 105, new StringFormat());
            graphics.DrawString("0 - ENTRADA", _fontArial8, Brushes.Black, 330, 120, new StringFormat());
            graphics.DrawString("1 - SAÍDA", _fontArial8, Brushes.Black, 330, 135, new StringFormat());
            graphics.DrawString("N.º   " + Int32.Parse(_nfe.infNFe.ide.nNF).ToString("000'.'000'.'000", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 330, 150, new StringFormat());
            graphics.DrawString("SÉRIE 1 - FOLHA " + _pagina + "/" + _totalPaginas, _fontArial7, Brushes.Black, 330, 165, new StringFormat());
            graphics.DrawRectangle(pen, 420, 127, 20, 20);
            graphics.DrawString(_nfe.infNFe.ide.tpNF, _font10, Brushes.Black, 423, 129, new StringFormat());

            //-----------------Dados Nfe-------------------
            graphics.DrawRectangle(pen, 445, 72, 350, 185);
            graphics.DrawLine(pen, 445, 134, 795, 134);
            graphics.DrawLine(pen, 445, 160, 795, 160);
            graphics.DrawLine(pen, 445, 220, 795, 220);

            string nchave = string.Empty;
            int contarS = 0;
            string chvAcesso = _nfe.infNFe.Id.Replace("NFe", "");
            for (Int16 x = 0; x <= chvAcesso.Length - 1; x++)
            {
                contarS += 1;
                nchave += chvAcesso.Substring(x, 1);
                if (contarS == 4)
                {
                    contarS = 0;
                    nchave += " ";
                }
            }

            //Imprime o Código de Barra
            Barcode codBarra = new Barcode();
            int widthBarCode = 280;
            int heightBarCode = 40;
            codBarra.Alignment = AlignmentPositions.LEFT;
            TYPE type = TYPE.CODE128C;
            Image imgCodBarra = codBarra.Encode(type, chvAcesso.Trim(), Color.Black, Color.White, widthBarCode, heightBarCode);
            graphics.DrawImage(imgCodBarra, 485, 82, 280, 40);

            //graphics.DrawImage(codigoBarra.DrawBarCode(chvAcesso), 485, 80, 280, 40);
            graphics.DrawString("CHAVE DE ACESSO", _fontArial6, Brushes.Black, 447, 135, new StringFormat());
            graphics.DrawString(nchave, _fontArial8, Brushes.Black, 470, 147, new StringFormat());

            graphics.DrawString("Consulta de autenticidade no portal nacional da NF-e", _font8B, Brushes.Black, 450, 165, new StringFormat());
            graphics.DrawString("www.nfe.fazenda.gov.br/portal", _font8B, Brushes.Black, 450, 175, new StringFormat());
            graphics.DrawString("ou no site da Sefaz Autorizadora", _font8B, Brushes.Black, 450, 185, new StringFormat());
            graphics.DrawString("PROTOCOLO DE AUTORIZAÇÃO DE USO", _fontArial6, Brushes.Black, 447, 221, new StringFormat());
            if (!string.IsNullOrEmpty(_protocolo))
            {
                graphics.DrawString(_protocolo + " - " + _dhRecbto, _fontArial8, Brushes.Black, 530, 235, new StringFormat());
            }
            graphics.DrawRectangle(pen, 10, 193, 435, 64);
            graphics.DrawLine(pen, 10, 213, 445, 213);
            graphics.DrawLine(pen, 10, 233, 445, 233);
            graphics.DrawLine(pen, 120, 213, 120, 233);
            graphics.DrawLine(pen, 260, 213, 260, 233);
            graphics.DrawString("NATUREZA DE OPERAÇÃO", _font5B, Brushes.Black, 12, 193, new StringFormat());
            graphics.DrawString(_nfe.infNFe.ide.natOp, _fontArial7, Brushes.Black, 12, 201, new StringFormat());
            graphics.DrawString("INSCRIÇÃO ESTADUAL", _font5B, Brushes.Black, 12, 213, new StringFormat());
            graphics.DrawString(_nfe.infNFe.emit.IE, _fontArial7, Brushes.Black, 12, 221, new StringFormat());
            graphics.DrawString("INSCR EST DO SUBST TRIBUTÁRIO", _font5B, Brushes.Black, 120, 213, new StringFormat());
            graphics.DrawString(_nfe.infNFe.emit.IEST, _fontArial7, Brushes.Black, 260, 221, new StringFormat());
            graphics.DrawString("CNPJ", _font5B, Brushes.Black, 260, 213, new StringFormat());
            graphics.DrawString(Convert.ToInt64(_nfe.infNFe.emit.CNPJ).ToString("00'.'000'.'000'/'0000'-'00", FunctionNFe.CulturaPtBr), _fontArial7, Brushes.Black, 260, 221, new StringFormat());
        }

        #endregion

        #region " Imprimir_Dados - Imprime dados quando é primeira pagina "

        //PREENCHE DADOS QUANDO É PRIMEIRA PAGINA
        private void ImprimirDados(PrintPageEventArgs graphicsSaida)
        {
            Pen pen = new Pen(Brushes.Black, 0.5f);

            // instrução adicionada para evitar exception de elementos inexistentes no objeto nf (na deserialização caso não exista determinada tag o elemento correspondente também não é criado)
            Graphics graphics = graphicsSaida.Graphics;

            // DESTINATARIO/REMETENTE
            graphics.FillRectangle(Brushes.LightGray, 10, 258, 785, 12);
            graphics.DrawString("DESTINATARIO/REMETENTE", _fontArial7, Brushes.Black, 12, 259, new StringFormat());
            graphics.DrawRectangle(pen, 10, 270, 640, 60);
            graphics.DrawRectangle(pen, 650, 270, 145, 60);

            graphics.DrawLine(pen, 10, 290, 795, 290);
            graphics.DrawLine(pen, 10, 310, 795, 310);
            graphics.DrawLine(pen, 470, 270, 470, 290);
            graphics.DrawLine(pen, 370, 290, 370, 310);
            graphics.DrawLine(pen, 560, 290, 560, 310);

            graphics.DrawLine(pen, 260, 310, 260, 330);
            graphics.DrawLine(pen, 440, 310, 440, 330);
            graphics.DrawLine(pen, 480, 310, 480, 330);

            string cnpjDestinatario = null;
            string cpfDestinatario = null;
            string enderecoDestinatario = null;
            cnpjDestinatario = null;
            cpfDestinatario = null;
            enderecoDestinatario = null;
            dest destinatario = _nfe.infNFe.dest;

            if (destinatario.CNPJ != null)
            {
                cnpjDestinatario = Convert.ToInt64(destinatario.CNPJ).ToString("00'.'000'.'000'/'0000'-'00", FunctionNFe.CulturaPtBr);
            }
            else
            {
                cpfDestinatario = Convert.ToInt64(destinatario.CPF).ToString("000'.'000'.'000'-'00", FunctionNFe.CulturaPtBr);
            }

            enderDest enderDestinatario = _nfe.infNFe.dest.enderDest;
            enderecoDestinatario = enderDestinatario.xLgr;
            if (!string.IsNullOrEmpty(enderecoDestinatario) && !string.IsNullOrEmpty(enderDestinatario.nro))
            {
                enderecoDestinatario += ", " + enderDestinatario.nro;
            }

            graphics.DrawString("NOME/RAZÃO SOCIAL", _font5B, Brushes.Black, 12, 270, new StringFormat());
            graphics.DrawString(_nfe.infNFe.dest.xNome.Left(60), _fontArial7, Brushes.Black, 12, 278, new StringFormat());
            graphics.DrawString("CNPJ/CPF", _font5B, Brushes.Black, 472, 270, new StringFormat());
            graphics.DrawString((!string.IsNullOrEmpty(cnpjDestinatario) ? cnpjDestinatario : cpfDestinatario), _fontArial7, Brushes.Black, 472, 278, new StringFormat());
            graphics.DrawString("DATA DE EMISSÃO", _font5B, Brushes.Black, 650, 270, new StringFormat());
            graphics.DrawString(Convert.ToDateTime(_nfe.infNFe.ide.dhEmi).ToString("dd/MM/yyyy"), _fontArial7, Brushes.Black, 650, 278);

            graphics.DrawString("ENDEREÇO", _font5B, Brushes.Black, 12, 290, new StringFormat());
            graphics.DrawString(enderecoDestinatario.Left(55), _fontArial7, Brushes.Black, 12, 298, new StringFormat());
            graphics.DrawString("BAIRRO/DISTRITO", _font5B, Brushes.Black, 372, 290, new StringFormat());
            graphics.DrawString(_nfe.infNFe.dest.enderDest.xBairro.Left(50), _fontArial7, Brushes.Black, 372, 298, new StringFormat());
            graphics.DrawString("CEP", _font5B, Brushes.Black, 562, 290, new StringFormat());
            graphics.DrawString(Convert.ToInt32(_nfe.infNFe.dest.enderDest.CEP).ToString("00000-000", FunctionNFe.CulturaPtBr), _fontArial7, Brushes.Black, 562, 298, new StringFormat());
            graphics.DrawString("DATA SAÍDA/ENTRADA", _font5B, Brushes.Black, 650, 290, new StringFormat());
            graphics.DrawString(!string.IsNullOrEmpty(_nfe.infNFe.ide.dhSaiEnt) ? Convert.ToDateTime(_nfe.infNFe.ide.dhSaiEnt).ToString("dd/MM/yyyy") : "", _fontArial7, Brushes.Black, 650, 298);

            graphics.DrawString("MUNICÍPIO", _font5B, Brushes.Black, 12, 310, new StringFormat());
            graphics.DrawString(_nfe.infNFe.dest.enderDest.xMun, _fontArial7, Brushes.Black, 12, 318, new StringFormat());
            graphics.DrawString("FONE/FAX", _font5B, Brushes.Black, 262, 310, new StringFormat());
            graphics.DrawString(_nfe.infNFe.dest.enderDest.fone, _fontArial7, Brushes.Black, 262, 318, new StringFormat());
            graphics.DrawString("UF", _font5B, Brushes.Black, 442, 310, new StringFormat());
            graphics.DrawString(_nfe.infNFe.dest.enderDest.UF, _fontArial7, Brushes.Black, 442, 318, new StringFormat());
            graphics.DrawString("INSCRIÇÃO ESTADUAL", _font5B, Brushes.Black, 482, 310, new StringFormat());
            graphics.DrawString(_nfe.infNFe.dest.IE, _fontArial7, Brushes.Black, 482, 318, new StringFormat());
            graphics.DrawString("HORA SAÍDA/ENTRADA", _font5B, Brushes.Black, 650, 310, new StringFormat());
            graphics.DrawString(!string.IsNullOrEmpty(_nfe.infNFe.ide.dhSaiEnt) ? Convert.ToDateTime(_nfe.infNFe.ide.dhSaiEnt).ToString("HH:mm:ss") : "", _fontArial7, Brushes.Black, 650, 318, new StringFormat());

            //FATURA
            string textoDeDuplicatas = string.Empty;
            if (_nfe.infNFe.cobr != null)
            {
                foreach (dup duplicata in _nfe.infNFe.cobr.dup)
                {
                    textoDeDuplicatas += (textoDeDuplicatas == string.Empty ? null : "  |  ") + "Venc: " + Convert.ToDateTime(duplicata.dVenc).ToString("dd/MM/yyyy") + " Valor: " + Convert.ToDecimal(duplicata.vDup).ToString("N", FunctionNFe.CulturaPtBr);
                }
            }

            graphics.FillRectangle(Brushes.LightGray, 10, 332, 785, 12);
            graphics.DrawString("FATURA", _fontArial7, Brushes.Black, 12, 332, new StringFormat());
            graphics.DrawRectangle(pen, 10, 344, 785, 40);
            graphics.DrawString(textoDeDuplicatas, _fontArial7, Brushes.Black, 12, 350, new StringFormat());

            // VALORES
            StringFormat Alinhamento = new StringFormat();
            Alinhamento.Alignment = StringAlignment.Far;
            graphics.FillRectangle(Brushes.LightGray, 10, 385, 785, 12);
            graphics.DrawString("CÁLCULO DO IMPOSTO", _fontArial7, Brushes.Black, 12, 386, new StringFormat());
            graphics.DrawRectangle(pen, 10, 397, 785, 56);
            graphics.DrawLine(pen, 10, 425, 795, 425);
            graphics.DrawLine(pen, 157, 397, 157, 425);
            graphics.DrawLine(pen, 314, 397, 314, 425);
            graphics.DrawLine(pen, 471, 397, 471, 425);
            graphics.DrawLine(pen, 628, 397, 628, 425);
            graphics.DrawString("BASE DE CÁLCULO DE ICMS", _font5B, Brushes.Black, 12, 397, new StringFormat());
            graphics.DrawString("VALOR ICMS", _font5B, Brushes.Black, 159, 397, new StringFormat());
            graphics.DrawString("BASE CÁLCULO ICMS ST", _font5B, Brushes.Black, 316, 397, new StringFormat());
            graphics.DrawString("VALOR ICMS ST", _font5B, Brushes.Black, 473, 397, new StringFormat());
            graphics.DrawString("VALOR TOTAL DOS PRODUTOS", _font5B, Brushes.Black, 630, 397, new StringFormat());
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vBC).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 155, 404, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vICMS).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 312, 404, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vBCST).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 469, 404, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vST).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 626, 404, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vProd).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 783, 404, Alinhamento);

            graphics.DrawLine(pen, 114, 425, 114, 453);
            graphics.DrawLine(pen, 228, 425, 228, 453);
            graphics.DrawLine(pen, 342, 425, 342, 453);
            graphics.DrawLine(pen, 471, 425, 471, 453);
            graphics.DrawLine(pen, 628, 425, 628, 453);
            graphics.DrawString("VALOR DO FRETE", _font5B, Brushes.Black, 12, 425, new StringFormat());
            graphics.DrawString("VALOR DO SEGURO", _font5B, Brushes.Black, 116, 425, new StringFormat());
            graphics.DrawString("DESCONTO", _font5B, Brushes.Black, 230, 425, new StringFormat());
            graphics.DrawString("OUTRAS DESPESAS", _font5B, Brushes.Black, 344, 425, new StringFormat());
            graphics.DrawString("VALOR DO IPI", _font5B, Brushes.Black, 473, 425, new StringFormat());
            graphics.DrawString("VALOR TOTAL DA NOTA", _font5B, Brushes.Black, 630, 425, new StringFormat());
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vFrete).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 112, 432, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vSeg).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 226, 432, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vDesc).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 340, 432, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vOutro).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 469, 432, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vIPI).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 626, 432, Alinhamento);
            graphics.DrawString(Convert.ToDecimal(_nfe.infNFe.total.ICMSTot.vNF).ToString("N", FunctionNFe.CulturaPtBr), _fontArial8, Brushes.Black, 783, 432, Alinhamento);

            //TRANSPORTADORA
            graphics.FillRectangle(Brushes.LightGray, 10, 454, 785, 10);
            graphics.DrawString("TRANSPORTADOR/VOLUMES TRANSPORTADOS", _fontArial7, Brushes.Black, 12, 454, new StringFormat());
            graphics.DrawRectangle(pen, 10, 464, 785, 60);
            // 1º linha 
            graphics.DrawLine(pen, 10, 484, 795, 484);
            graphics.DrawRectangle(pen, 400, 466, 14, 14);
            //frete

            graphics.DrawLine(pen, 320, 464, 320, 484);
            graphics.DrawLine(pen, 417, 464, 417, 484);
            graphics.DrawLine(pen, 500, 464, 500, 484);
            graphics.DrawLine(pen, 620, 464, 620, 484);
            graphics.DrawLine(pen, 650, 464, 650, 484);
            graphics.DrawString("RAZÃO SOCIAL", _font5B, Brushes.Black, 12, 464, new StringFormat());
            graphics.DrawString("FRETE POR CONTA", _font5B, Brushes.Black, 322, 464, new StringFormat());
            graphics.DrawString("0-Emitente", _font5B, Brushes.Black, 322, 470, new StringFormat());
            graphics.DrawString("1-Destinatario", _font5B, Brushes.Black, 322, 476, new StringFormat());
            graphics.DrawString("CODIGO ANTT", _font5B, Brushes.Black, 419, 464, new StringFormat());
            graphics.DrawString("PLACA VEICULO", _font5B, Brushes.Black, 502, 464, new StringFormat());
            graphics.DrawString("UF", _font5B, Brushes.Black, 622, 464, new StringFormat());
            graphics.DrawString("CNPJ/CPF", _font5B, Brushes.Black, 652, 464, new StringFormat());

            if (_nfe.infNFe.transp != null)
            {
                string cnpjTransportador = string.Empty;
                string cpfTransportador = string.Empty;
                string rntc = string.Empty;
                string placa = string.Empty;
                string placaUf = string.Empty;

                if (_nfe.infNFe.transp.transporta != null)
                {
                    transporta transp = _nfe.infNFe.transp.transporta;
                    cnpjTransportador = Convert.ToInt64(transp.CNPJ).ToString("00'.'000'.'000'/'0000'-'00", FunctionNFe.CulturaPtBr);
                    cpfTransportador = Convert.ToInt64(transp.CPF).ToString("000'.'000'.'000'-'00", FunctionNFe.CulturaPtBr);

                    graphics.DrawString(_nfe.infNFe.transp.transporta.xNome, _fontArial7, Brushes.Black, 12, 471, new StringFormat());
                    graphics.DrawString(_nfe.infNFe.transp.modFrete, _fontArial7, Brushes.Black, 403, 468, new StringFormat());
                }

                if (_nfe.infNFe.transp.veicTransp != null)
                {
                    graphics.DrawString(_nfe.infNFe.transp.veicTransp.RNTC, _fontArial7, Brushes.Black, 419, 471, new StringFormat());
                    graphics.DrawString(_nfe.infNFe.transp.veicTransp.placa, _fontArial7, Brushes.Black, 502, 471, new StringFormat());
                    graphics.DrawString(_nfe.infNFe.transp.veicTransp.UF, _fontArial7, Brushes.Black, 622, 471, new StringFormat());
                }
                graphics.DrawString((!string.IsNullOrEmpty(cnpjTransportador) ? cnpjTransportador : cpfTransportador), _fontArial7, Brushes.Black, 652, 471, new StringFormat());
            }

            // 2º linha 
            graphics.DrawLine(pen, 10, 504, 795, 504);
            graphics.DrawLine(pen, 320, 484, 320, 504);
            graphics.DrawLine(pen, 620, 484, 620, 504);
            graphics.DrawLine(pen, 650, 484, 650, 504);

            graphics.DrawString("ENDEREÇO", _font5B, Brushes.Black, 12, 484, new StringFormat());
            graphics.DrawString("MUNICÍPIO", _font5B, Brushes.Black, 322, 484, new StringFormat());
            graphics.DrawString("UF", _font5B, Brushes.Black, 622, 484, new StringFormat());
            graphics.DrawString("INSCRIÇÃO ESTADUAL", _font5B, Brushes.Black, 652, 484, new StringFormat());

            if (_nfe.infNFe.transp.transporta != null)
            {
                graphics.DrawString(_nfe.infNFe.transp.transporta.xEnder, _fontArial7, Brushes.Black, 12, 491, new StringFormat());
                graphics.DrawString(_nfe.infNFe.transp.transporta.xMun, _fontArial7, Brushes.Black, 322, 491, new StringFormat());
                graphics.DrawString(_nfe.infNFe.transp.transporta.UF, _fontArial7, Brushes.Black, 622, 491, new StringFormat());
                graphics.DrawString(_nfe.infNFe.transp.transporta.IE, _fontArial7, Brushes.Black, 652, 491, new StringFormat());
            }

            // 3º linha 
            graphics.DrawLine(pen, 100, 504, 100, 524);
            graphics.DrawLine(pen, 210, 504, 210, 524);
            graphics.DrawLine(pen, 320, 504, 320, 524);
            graphics.DrawLine(pen, 500, 504, 500, 524);
            graphics.DrawLine(pen, 650, 504, 650, 524);

            graphics.DrawString("QUANTIDADE", _font5B, Brushes.Black, 12, 504, new StringFormat());
            graphics.DrawString("ESPÉCIE", _font5B, Brushes.Black, 102, 504, new StringFormat());
            graphics.DrawString("MARCA", _font5B, Brushes.Black, 212, 504, new StringFormat());
            graphics.DrawString("NUMERAÇÃO", _font5B, Brushes.Black, 322, 504, new StringFormat());
            graphics.DrawString("PESO BRUTO", _font5B, Brushes.Black, 502, 504, new StringFormat());
            graphics.DrawString("PESO LÍQUIDO", _font5B, Brushes.Black, 652, 504, new StringFormat());

            if (_nfe.infNFe.transp.vol != null)
            {
                graphics.DrawString(_nfe.infNFe.transp.vol.qVol.ToString(), _fontArial7, Brushes.Black, 90, 511, Alinhamento);
                graphics.DrawString(_nfe.infNFe.transp.vol.esp, _fontArial7, Brushes.Black, 102, 511, new StringFormat());
                graphics.DrawString(_nfe.infNFe.transp.vol.marca, _fontArial7, Brushes.Black, 212, 511, new StringFormat());
                graphics.DrawString(_nfe.infNFe.transp.vol.nVol, _fontArial7, Brushes.Black, 322, 511, new StringFormat());
                decimal pesoB = _nfe.infNFe.transp.vol.pesoB ?? 0;
                decimal pesoL = _nfe.infNFe.transp.vol.pesoL ?? 0;
                graphics.DrawString(pesoB.ToString("0.00"), _fontArial7, Brushes.Black, 640, 511, Alinhamento);
                graphics.DrawString(pesoL.ToString("0.00"), _fontArial7, Brushes.Black, 780, 511, Alinhamento);
            }

            //CÁLCULO DO ISSQN
            graphics.FillRectangle(Brushes.LightGray, 10, 972, 785, 12);
            graphics.DrawString("CÁLCULO DO ISSQN", _fontArial7, Brushes.Black, 12, 974, new StringFormat());
            graphics.DrawRectangle(pen, 10, 984, 785, 20);
            graphics.DrawLine(pen, 194, 984, 194, 1004);
            graphics.DrawLine(pen, 388, 984, 388, 1004);
            graphics.DrawLine(pen, 582, 984, 582, 1004);
            graphics.DrawString("INSCRIÇÃO MUNICIPAL", _font5B, Brushes.Black, 12, 984, new StringFormat());
            graphics.DrawString("VALOR TOTAL DOS SERVIÇOS", _font5B, Brushes.Black, 196, 984, new StringFormat());
            graphics.DrawString("BASE DE CALCULO DO ISSQN", _font5B, Brushes.Black, 390, 984, new StringFormat());
            graphics.DrawString("VALOR DO ISSQN", _font5B, Brushes.Black, 584, 984, new StringFormat());

            if (_nfe.infNFe.total.ISSQNTot != null)
            {
                graphics.DrawString(_nfe.infNFe.emit.IM, _fontArial7, Brushes.Black, 12, 991, new StringFormat());
                graphics.DrawString(_nfe.infNFe.total.ISSQNTot.vServ.ToString("0.00"), _fontArial7, Brushes.Black, 383, 991, Alinhamento);
                graphics.DrawString(_nfe.infNFe.total.ISSQNTot.vBC.ToString("0.00"), _fontArial7, Brushes.Black, 577, 991, Alinhamento);
                graphics.DrawString(_nfe.infNFe.total.ISSQNTot.vISS.ToString("0.00"), _fontArial7, Brushes.Black, 780, 991, Alinhamento);
            }
        }

        #endregion

        #region " ImprimirDadosAdicionais - Imprime os dados adicionais "

        private void ImprimirDadosAdicionais(PrintPageEventArgs graphicsSaida, bool extra)
        {
            Pen pen = new Pen(Brushes.Black, 0.5f);
            StringFormat AlinhamentoNear = new StringFormat();
            AlinhamentoNear.LineAlignment = StringAlignment.Near;

            Graphics graphics = graphicsSaida.Graphics;
            if (_pagina == 1)
            {
                graphics.FillRectangle(Brushes.LightGray, 10, 1005, 785, 10);
                graphics.DrawString("DADOS ADICIONAIS", _fontArial7, Brushes.Black, 12, 1005, new StringFormat());
                graphics.DrawRectangle(pen, 10, 1015, 500, 80);
                graphics.DrawRectangle(pen, 510, 1015, 285, 80);
                graphics.DrawString("INFORMAÇÕES COMPLEMENTARES", _font5B, Brushes.Black, 12, 1015, new StringFormat());
                graphics.DrawString("RESERVADO AO FISCO", _font5B, Brushes.Black, 512, 1015, new StringFormat());
                if (_listaDadosAdicionais.ContainsKey(_pagina))
                {
                    graphics.DrawString(_listaDadosAdicionais[_pagina], _font6, Brushes.Black, new RectangleF(12, 1023, 506, 66), AlinhamentoNear);
                }
            }
            else
            {
                if (!extra)
                {
                    graphics.FillRectangle(Brushes.LightGray, 10, 1005, 785, 10);
                    graphics.DrawString("DADOS ADICIONAIS", _fontArial7, Brushes.Black, 12, 1005, new StringFormat());
                    graphics.DrawRectangle(pen, 10, 1015, 785, 80);
                    graphics.DrawString("INFORMAÇÕES COMPLEMENTARES", _font5B, Brushes.Black, 12, 1015, new StringFormat());
                    graphics.DrawString(_listaDadosAdicionais[_pagina], _font6, Brushes.Black, new RectangleF(12, 1023, 790, 66), AlinhamentoNear);
                    // Imprimir pagina extra
                }
                else
                {
                    graphics.FillRectangle(Brushes.LightGray, 10, 259, 785, 10);
                    graphics.DrawString("DADOS ADICIONAIS", _fontArial7, Brushes.Black, 12, 260, new StringFormat());
                    graphics.DrawRectangle(pen, 10, 270, 785, _paginaExtraHeight);
                    graphics.DrawString("INFORMAÇÕES COMPLEMENTARES", _font5B, Brushes.Black, 12, 270, new StringFormat());
                    graphics.DrawString(_paginaExtraDados, _font6, Brushes.Black, new RectangleF(12, 277, 790, _paginaExtraHeight), AlinhamentoNear);
                    graphicsSaida.HasMorePages = false;
                    _paginaExtra = false;
                }
            }
        }

        #endregion

        #region " ImprimirDetalhes - Imprime informações de nf.infNFe.det "

        private void ImprimirDetalhes(PrintPageEventArgs graphicsSaida)
        {
            float alturaLinha = 0;
            int alturaLinhaFinal = 0;
            int alturaRetanguloProdutos = 0;
            int contadorJumpProdutos = 0;
            StringFormat alinhamentoFar = new StringFormat();
            StringFormat alinhamentoCenter = new StringFormat();
            StringFormat alinhamentoNear = new StringFormat();
            string linhaLoteRastro = null;
            Pen pen = new Pen(Brushes.Black, 0.5f);
            RectangleF descricaoRect = default(RectangleF);
            SizeF stringSize = new SizeF();
            int charactersFitted = 0;
            int linesFilled = 0;

            alinhamentoFar.Alignment = StringAlignment.Far;
            alinhamentoCenter.Alignment = StringAlignment.Center;
            alinhamentoNear.Alignment = StringAlignment.Near;

            // instrução adicionada para evitar exception de elementos inexistentes no objeto nf (na deserialização caso não exista determinada tag o elemento correspondente também não é criado)

            alturaLinha = _pagina == 1 ? 525 : 260;
            alturaLinhaFinal = _listaAlturaLinhaFinal[_pagina];
            alturaRetanguloProdutos = _listaRetanguloProdutos[_pagina];

            Graphics graphics = graphicsSaida.Graphics;
            graphics.FillRectangle(Brushes.LightGray, 10, alturaLinha, 785, 12);
            graphics.DrawString("DADOS DOS PRODUTOS / SERVIÇOS", _fontArial7, Brushes.Black, 12, alturaLinha, new StringFormat());
            alturaLinha += 10;

            graphics.DrawLine(pen, 10, alturaLinha, 795, alturaLinha);
            graphics.DrawLine(pen, 10, alturaLinha, 10, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 795, alturaLinha, 795, alturaRetanguloProdutos);

            //Verticais
            graphics.DrawLine(pen, 58, alturaLinha, 58, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 275, alturaLinha, 275, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 320, alturaLinha, 320, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 345, alturaLinha, 345, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 370, alturaLinha, 370, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 390, alturaLinha, 390, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 435, alturaLinha, 435, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 495, alturaLinha, 495, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 555, alturaLinha, 555, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 595, alturaLinha, 595, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 650, alturaLinha, 650, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 700, alturaLinha, 700, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 745, alturaLinha, 745, alturaRetanguloProdutos);
            graphics.DrawLine(pen, 770, alturaLinha, 770, alturaRetanguloProdutos);
            alturaLinha += 5;
            graphics.DrawString("CÓDIGO", _font6B, Brushes.Black, 11, alturaLinha, new StringFormat());
            graphics.DrawString("DESCRIÇÃO DOS PRODUTOS/SERVIÇOS", _font6B, Brushes.Black, 80, alturaLinha, new StringFormat());
            graphics.DrawString("NCM", _font6B, Brushes.Black, 298, alturaLinha, alinhamentoCenter);
            graphics.DrawString("CST", _font6B, Brushes.Black, 332, alturaLinha, alinhamentoCenter);
            graphics.DrawString("CFOP", _font6B, Brushes.Black, 357, alturaLinha, alinhamentoCenter);
            graphics.DrawString("UN", _font6B, Brushes.Black, 381, alturaLinha, alinhamentoCenter);
            graphics.DrawString("QTDE", _font6B, Brushes.Black, 434, alturaLinha, alinhamentoFar);
            graphics.DrawString("VALOR UNIT", _font6B, Brushes.Black, 494, alturaLinha, alinhamentoFar);
            graphics.DrawString("VLR TOTAL", _font6B, Brushes.Black, 554, alturaLinha, alinhamentoFar);
            graphics.DrawString("DESC", _font6B, Brushes.Black, 594, alturaLinha, alinhamentoFar);
            graphics.DrawString("BC ICMS", _font6B, Brushes.Black, 649, alturaLinha, alinhamentoFar);
            graphics.DrawString("VLR ICMS", _font6B, Brushes.Black, 699, alturaLinha, alinhamentoFar);
            graphics.DrawString("VLR IPI", _font6B, Brushes.Black, 744, alturaLinha, alinhamentoFar);
            graphics.DrawString("ALIQ " + System.Environment.NewLine + "ICMS", _font5B, Brushes.Black, 769, alturaLinha - 2, alinhamentoFar);
            graphics.DrawString("ALIQ " + System.Environment.NewLine + "IPI", _font5B, Brushes.Black, 793, alturaLinha - 2, alinhamentoFar);
            alturaLinha += 14;
            graphics.DrawLine(pen, 10, alturaLinha, 795, alturaLinha);
            alturaLinha += 5;

            //PERCORRE TODA A MATRIZ DE PRODUTOS E IMPRIME OS MESMOS
            contadorJumpProdutos = 0;
            foreach (det detInf in _nfe.infNFe.det)
            {
                if (contadorJumpProdutos >= _contadorProdutos)
                {
                    string valorIpi = null;
                    string aliquotaIpi = null;
                    string baseIcms = null;
                    string valorIcms = null;
                    string aliquotaIcms = null;
                    string baseIcmsSt = null;
                    string valorIcmsSt = null;
                    string cst = null;
                    valorIpi = null;
                    aliquotaIpi = null;
                    baseIcms = null;
                    valorIcms = null;
                    aliquotaIcms = null;
                    baseIcmsSt = null;
                    valorIcmsSt = null;
                    cst = null;

                    if (detInf.imposto.IPI != null && detInf.imposto.IPI.IPITrib != null)
                    {
                        valorIpi = Convert.ToDecimal(detInf.imposto.IPI.IPITrib.vIPI).ToString("N", FunctionNFe.CulturaPtBr);
                        aliquotaIpi = Convert.ToDecimal(detInf.imposto.IPI.IPITrib.vIPI).ToString("N", FunctionNFe.CulturaPtBr);
                    }

                    FunctionNFe.GetIcms(_nfe.infNFe.emit.CRT, detInf, ref cst, ref baseIcms, ref valorIcms, ref aliquotaIcms, ref baseIcmsSt, ref valorIcmsSt);

                    graphics.DrawString(detInf.prod.cProd.Right(9), _font7, Brushes.Black, 11, alturaLinha, new StringFormat());
                    graphics.DrawString(detInf.prod.NCM, _font7, Brushes.Black, 298, alturaLinha, alinhamentoCenter);
                    graphics.DrawString(cst, _font7, Brushes.Black, 332, alturaLinha, alinhamentoCenter);
                    graphics.DrawString(detInf.prod.CFOP, _font7, Brushes.Black, 357, alturaLinha, alinhamentoCenter);
                    graphics.DrawString(detInf.prod.uCom, _font7, Brushes.Black, 381, alturaLinha, alinhamentoCenter);

                    graphics.DrawString(detInf.prod.qCom.ToString("0.##", FunctionNFe.CulturaPtBr), _font7, Brushes.Black, 434, alturaLinha, alinhamentoFar);
                    graphics.DrawString(Convert.ToDecimal(detInf.prod.vUnCom).ToString("N", FunctionNFe.CulturaPtBr), _font7, Brushes.Black, 494, alturaLinha, alinhamentoFar);
                    graphics.DrawString(Convert.ToDecimal(detInf.prod.vProd).ToString("N", FunctionNFe.CulturaPtBr), _font7, Brushes.Black, 554, alturaLinha, alinhamentoFar);
                    graphics.DrawString(Convert.ToDecimal(detInf.prod.vDesc).ToString("N", FunctionNFe.CulturaPtBr), _font7, Brushes.Black, 594, alturaLinha, alinhamentoFar);
                    graphics.DrawString(baseIcms, _font7, Brushes.Black, 649, alturaLinha, alinhamentoFar);
                    graphics.DrawString(valorIcms, _font7, Brushes.Black, 699, alturaLinha, alinhamentoFar);
                    graphics.DrawString(valorIpi, _font7, Brushes.Black, 744, alturaLinha, alinhamentoFar);
                    graphics.DrawString(aliquotaIcms, _font7, Brushes.Black, 769, alturaLinha, alinhamentoFar);
                    graphics.DrawString(aliquotaIpi, _font7, Brushes.Black, 793, alturaLinha, alinhamentoFar);

                    descricaoRect = new RectangleF(60, alturaLinha, 208, 24);
                    stringSize = graphics.MeasureString(detInf.prod.xProd, _font7, descricaoRect.Size, alinhamentoNear, out charactersFitted, out linesFilled);
                    graphics.DrawString(detInf.prod.xProd, _font7, Brushes.Black, descricaoRect, alinhamentoNear);
                    alturaLinha += linesFilled * 12;

                    linhaLoteRastro = string.Empty;
                    foreach (rastro rastroInf in detInf.prod.rastro)
                    {
                        linhaLoteRastro += (string.IsNullOrEmpty(linhaLoteRastro) ? null : " ") + "Lote: " + rastroInf.nLote + " Qtd: " + rastroInf.qLote.ToString("#.##", FunctionNFe.CulturaPtBr);
                    }

                    if (linhaLoteRastro != string.Empty)
                    {
                        descricaoRect = new RectangleF(60, alturaLinha, 208, 20);
                        stringSize = graphics.MeasureString(linhaLoteRastro, _font6, descricaoRect.Size, alinhamentoNear, out charactersFitted, out linesFilled);
                        graphics.DrawString(linhaLoteRastro, _font6, Brushes.Black, descricaoRect, alinhamentoNear);
                        alturaLinha += linesFilled * 12;
                    }

                    //pen.DashStyle = Drawing2D.DashStyle.DashDotDot ' Para usar linhas tracejadas, habilitar esta instrução
                    graphics.DrawLine(pen, 10, alturaLinha, 795, alturaLinha);
                    alturaLinha += 4;

                    _contadorProdutos += 1;

                    _processandoImpressaoProdutos = (detInf.nItem != _nfe.infNFe.det[_nfe.infNFe.det.Count - 1].nItem);
                    // Se for o ultimo produto a ser impresso, inicializa processando_impressão_produtos = False

                    if (alturaLinha > alturaLinhaFinal)
                    {
                        graphicsSaida.HasMorePages = true;
                        break; 
                    }
                }
                contadorJumpProdutos += 1;
            }

            //Sofware House e Versão NFe
            graphics.DrawString(_msgSoftWareHouse , _font6, Brushes.Black, 795, 1100, alinhamentoFar);

            _pagina += 1;

            if (!_processandoImpressaoProdutos)
            {
                graphicsSaida.HasMorePages = _paginaExtra;
                // Se houver pagina extra de dados adicionais, será inicializado com True
            }
        }

        #endregion
    }
}
