﻿using System.Drawing;
using System.Windows.Forms;
using System.Linq;
using System.Drawing.Printing;
using Bullzip.PdfWriter;

namespace NFeLib
{
    public class FrmReport
    {
        public static void View(PrintDocument printDoc) 
        {
            PrintPreviewDialog printView = new PrintPreviewDialog();

            ToolStrip toolStrip1 = printView.Controls.OfType<ToolStrip>().FirstOrDefault();
            printView.Controls.OfType<PrintPreviewControl>().FirstOrDefault().BackColor = Color.FromArgb(175, 201, 224);
            toolStrip1.BackgroundImage = NFeLib.Properties.Resources.PicCaption;
            toolStrip1.BackgroundImageLayout = ImageLayout.Stretch;
            toolStrip1.Height = 32;

            //Oculta o Botão imprimir padrão
            toolStrip1.Items[0].Visible = false;
            toolStrip1.Items[1].Image = NFeLib.Properties.Resources.zoom;
            toolStrip1.Items[1].DisplayStyle = ToolStripItemDisplayStyle.ImageAndText;
            //Oculta o Botão Fechar padrão
            toolStrip1.Items[9].Visible = false;

            //Cria o Botão Imprimir Personalizado
            ToolStripButton btn = new ToolStripButton();
            btn = new ToolStripButton();
            btn.ToolTipText = "Imprimir";
            btn.Text = "Imprimir";
            btn.Name = "btnImprimir";
            btn.Image = NFeLib.Properties.Resources.printer;
            btn.Click += (sender, args) =>
            {
                PrintDialog dialogPrint = new PrintDialog();
                if (dialogPrint.ShowDialog() == DialogResult.OK)
                {
                    if (dialogPrint.PrinterSettings.IsValid)
                    {
                        printDoc.PrinterSettings = dialogPrint.PrinterSettings;
                        printDoc.Print();
                    }
                    else
                    {
                        MessageBox.Show("Não há impressora instalada!!!", "Atenção", MessageBoxButtons.OK, MessageBoxIcon.Error);
                    }
                }
                else
                {
                    MessageBox.Show("Selecione uma impressora válida!!!","Atenção", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            };
            toolStrip1.Items.Add(btn);

            
            //Cria o Botão Exportar e atribui evento para mesmo
            btn = new ToolStripButton();
            btn.ToolTipText = "Exportar Pdf";
            btn.Text = "Exportar";
            btn.Name = "btnOk";
            btn.Image = NFeLib.Properties.Resources.pdf_icon1;
            btn.Click += (sender, args) =>
            {
                FolderBrowserDialog folder = new FolderBrowserDialog();
                if (folder.ShowDialog() == System.Windows.Forms.DialogResult.OK)
                {
                    PrintPreviewDialog printDialog = (PrintPreviewDialog)((ToolStripButton)sender).GetCurrentParent().Parent;
                    PrintDocument print = printDialog.Controls.OfType<PrintPreviewControl>().FirstOrDefault().Document;
                    PdfSettings impPdf = new PdfSettings();
                    impPdf.SetValue("Output", folder.SelectedPath + "\\NFe.pdf");
                    impPdf.SetValue("ConfirmOverwrite", "no");
                    impPdf.SetValue("ShowSaveAS", "never");
                    impPdf.SetValue("ShowSettings", "never");
                    impPdf.SetValue("ShowPDF", "no");
                    impPdf.SetValue("RememberLastFileName", "no");
                    impPdf.SetValue("RememberLastFolderName", "no");
                    impPdf.WriteSettings(true);
                    print.PrinterSettings.PrinterName = "Bullzip PDF Printer";
                    print.Print();
                }
               
            };
            toolStrip1.Items.Add(btn);


            //Cria o Botão Fechar 
            btn = new ToolStripButton();
            btn.ToolTipText = "Fechar";
            btn.Text = "Fechar";
            btn.Name = "btnClose";
            btn.Image = NFeLib.Properties.Resources.close;
            btn.Click += (sender, args) =>
            {
                printView.Close();
            };
            toolStrip1.Items.Add(btn);

            printView.Document = printDoc;
            printView.FormBorderStyle = FormBorderStyle.Fixed3D;
            printView.PrintPreviewControl.Zoom = 1.3;
            printView.AutoSizeMode = AutoSizeMode.GrowOnly;
            ((Form)printView).MinimizeBox = true;
            ((Form)printView).MaximizeBox = true;
            ((Form)printView).ControlBox = false;
            ((Form)printView).FormBorderStyle = FormBorderStyle.FixedDialog;
            //((Form)printView).ControlBox = false;
            ((Form)printView).WindowState = FormWindowState.Maximized;
            ((Form)printView).Text = "Visualização Danfe";
            printView.ShowDialog();
            printView.Close();
            printView.Dispose();
        
        }
    }
}
