using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao
{
	public class ICMS10
	{
        private decimal _vBc;
        private decimal _pIcms;
        private decimal _vIcms;
        private decimal? _pRedBcst;
        private decimal? _pMvast;
        private decimal _vBcst;
        private decimal _pIcmsst;
        private decimal _vIcmsst;
        private decimal? _pFcp;
        private decimal? _vFcp;
        private decimal? _vBcfcp;
        private decimal? _vBcfcpst;
        private decimal? _pFcpst;
        private decimal? _vFcpst;

		/// <summary>
		/// Origem da mercadoria:
		/// 0 - Nacional, exceto as indicadas nos Códigos 3 a 5;
		/// 1 - Estrangeira - Importação Direta, exceto a indicada no Código 6;
		/// 2 - Estrangeira - Adquirida no mercado interno, exceto a indicada no Código 7;
		/// 3 - Nacional, Mercadoria ou bem com conteúdo de Importação superior a 40% (Quarenta por Cento);
		/// 4 - Nacional, cuja produção tenha sido feita em conformidade com os processos produtivos básicos de que tratam o Decreto-Lei Nº 288/67, e as Leis Nºs 8.248/91, 8.387/91, 10.176/01 e 11.484/07;
		/// 5 - Nacional, Mercadoria ou bem com conteúdo de Importação inferior ou igual a 40% (Quarenta por Cento);
		/// 6 - Estrangeira - Importação Direta, sem similar Nacional, constante em lista de resolução CAMEX e gas natural;
		/// 7 - Estrangeira - Adquirida no mercado interno, sem similar Nacional, constante em lista de resolução CAMEX e gas natural.
		/// </summary>
		public string orig { get; set; }

		/// <summary>
		/// Tributação do ICMS: 10 - Tributada e com cobrança do ICMS por substituição tributária
		/// </summary>
		public string CST { get; set; }

		/// <summary>
		/// 0 - Margem Valor Agregado (%);
		/// 1 - Pauta (Valor);
		/// 2 - Preço Tabelado Máx. (valor);
		/// 3 - valor da operação.
		/// </summary>
		public string modBC { get; set; }

		/// <summary>
		/// Valor da base de calculo do imposto
		/// </summary>
        public decimal vBC
        {
            get { return FunctionNFe.RoundDecimal(_vBc, 2); }
            set { _vBc = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        /// N17a - Valor da Base de Cálculo do FCP
        /// Versão 4.00
        /// </summary>
        public decimal? vBCFCP
        {
            get { return FunctionNFe.RoundDecimal(_vBcfcp,2); }
            set { _vBcfcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vBCFCPSpecified
        {
            get { return vBCFCP.HasValue; }
        }

        /// <summary>
        /// N17b - Percentual do Fundo de Combate à Pobreza (FCP)
        /// Versão 4.00
        /// </summary>
        public decimal? pFCP
        {
            get { return FunctionNFe.RoundDecimal(_pFcp,4); }
            set { _pFcp = FunctionNFe.RoundDecimal(value,4); }
        }

        public bool pFCPSpecified
        {
            get { return pFCP.HasValue; }
        }

        /// <summary>
        /// N17c - Valor do Fundo de Combate à Pobreza (FCP)
        /// Versão 4.00
        /// </summary>
        public decimal? vFCP
        {
            get { return FunctionNFe.RoundDecimal(_vFcp,2); }
            set { _vFcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vFCPSpecified
        {
            get { return vFCP.HasValue; }
        }
        /// <summary>
        ///     N16 - Alíquota do imposto
        /// </summary>
        public decimal pICMS
        {
            get { return FunctionNFe.RoundDecimal(_pIcms, 4); }
            set { _pIcms = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N17 - Valor do ICMS
        /// </summary>
        public decimal vICMS
        {
            get { return FunctionNFe.RoundDecimal(_vIcms, 2); }
            set { _vIcms = FunctionNFe.RoundDecimal(value, 2); }
        }

		/// <summary>
		/// Modalidade de determinação da BC do ICMS ST
		/// 0 – Preço tabelado ou máximo sugerido;
		/// 1 - Lista Negativa (valor);
		/// 2 - Lista Positiva (valor);
		/// 3 - Lista Neutra (valor);
		/// 4 - Margem Valor Agregado (%);
		/// 5 - Pauta (valor);
		/// </summary>
		public string modBCST { get; set; }

		/// <summary>
		/// Percentual da margem de valor Adicionado do ICMS ST
		/// </summary>        
        public decimal? pMVAST
        {
            get { return FunctionNFe.RoundDecimal(_pMvast, 4); }
            set { _pMvast = FunctionNFe.RoundDecimal(value, 4); }
        }
        public bool ShouldSerializepMVAST()
        {
            return !(pMVAST == null || pMVAST == 0 );
        }


        /// <summary>
        ///     N20 - Percentual da Redução de BC do ICMS ST
        /// </summary>
        public decimal? pRedBCST
        {
            get { return FunctionNFe.RoundDecimal(_pRedBcst, 4); }
            set { _pRedBcst = FunctionNFe.RoundDecimal(value, 4); }
        }
        public bool ShouldSerializepRedBCST()
        {
            return !(pRedBCST == null || pRedBCST == 0);
        }

        /// <summary>
        ///     N21 - Valor da BC do ICMS ST
        /// </summary>
        public decimal vBCST
        {
            get { return FunctionNFe.RoundDecimal(_vBcst, 2); }
            set { _vBcst = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N22 - Alíquota do imposto do ICMS ST
        /// </summary>
        public decimal pICMSST
        {
            get { return FunctionNFe.RoundDecimal(_pIcmsst, 4); }
            set { _pIcmsst = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N23 - Valor do ICMS ST
        /// </summary>
        public decimal vICMSST
        {
            get { return FunctionNFe.RoundDecimal(_vIcmsst, 2); }
            set { _vIcmsst = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        /// N23a - Valor da Base de Cálculo do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vBCFCPST
        {
            get { return FunctionNFe.RoundDecimal(_vBcfcpst,2); }
            set { _vBcfcpst = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vBCFCPSTSpecified
        {
            get { return vBCFCPST.HasValue; }
        }

        /// <summary>
        /// N23b - Percentual do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? pFCPST
        {
            get { return FunctionNFe.RoundDecimal(_pFcpst,4); }
            set { _pFcpst = FunctionNFe.RoundDecimal(value,4); }
        }

        public bool pFCPSTSpecified
        {
            get { return pFCPST.HasValue; }
        }

        /// <summary>
        /// N23d - Valor do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vFCPST
        {
            get { return _vFcpst; }
            set { _vFcpst = value; }
        }

        public bool vFCPSTSpecified
        {
            get { return vFCPST.HasValue; }
        }

       
	}
}
