using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao
{
	public class ICMS20
	{
        private decimal _pRedBc;
        private decimal _vBc;
        private decimal _pIcms;
        private decimal _vIcms;
        private decimal? _vIcmsDeson;
        private decimal? _vBcfcp;
        private decimal? _pFcp;
        private decimal? _vFcp;

        /// <summary>
        ///     N11 - Origem da Mercadoria
        /// </summary>
        public string orig { get; set; }

        /// <summary>
        ///     N12- Situação Tributária
        /// </summary>
        public string CST { get; set; }

        /// <summary>
        ///     N13 - Modalidade de determinação da BC do ICMS
        /// </summary>
        public string modBC { get; set; }

        /// <summary>
        ///     N14 - Percentual de redução da BC
        /// </summary>
        public decimal pRedBC
        {
            get { return FunctionNFe.RoundDecimal(_pRedBc, 4); }
            set { _pRedBc = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N15 - Valor da BC do ICMS
        /// </summary>
        public decimal vBC
        {
            get { return FunctionNFe.RoundDecimal(_vBc, 2); }
            set { _vBc = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N16 - Alíquota do imposto
        /// </summary>
        public decimal pICMS
        {
            get { return FunctionNFe.RoundDecimal(_pIcms, 4); }
            set { _pIcms = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N17 - Valor do ICMS
        /// </summary>
        public decimal vICMS
        {
            get { return FunctionNFe.RoundDecimal(_vIcms, 2); }
            set { _vIcms = FunctionNFe.RoundDecimal(value, 2); }
        }


        /// <summary>
        /// N17a - Valor da Base de Cálculo do FCP
        /// Versão 4.00
        /// </summary>
        public decimal? vBCFCP
        {
            get { return FunctionNFe.RoundDecimal(_vBcfcp,2); }
            set { _vBcfcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vBCFCPShouldSerialize
        {
            get { return vBCFCP.HasValue; }
        }

        /// <summary>
        /// N17b - Percentual do Fundo de Combate à Pobreza (FCP)
        /// Versão 4.00
        /// </summary>
        public decimal? pFCP
        {
            get { return FunctionNFe.RoundDecimal(_pFcp,4); }
            set { _pFcp = FunctionNFe.RoundDecimal(value,4); }
        }

        public bool ShouldSerializepFCP
        {
            get { return pFCP.HasValue; }
        }

        /// <summary>
        /// N17c - Valor do Fundo de Combate à Pobreza (FCP)
        /// Versão 4.00
        /// </summary>
        public decimal? vFCP
        {
            get { return FunctionNFe.RoundDecimal(_vFcp,2); }
            set { _vFcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool ShouldSerializevFCP
        {
            get { return vFCP.HasValue; }
        }

        /// <summary>
        ///     N27a - Valor do ICMS desonerado
        /// </summary>
        public decimal? vICMSDeson
        {
            get { return FunctionNFe.RoundDecimal(_vIcmsDeson,2); }
            set { _vIcmsDeson = FunctionNFe.RoundDecimal(value,2); }
        }

        /// <summary>
        ///     N28 - Motivo da desoneração do ICMS
        /// </summary>
        public string motDesICMS { get; set; }

        public bool ShouldSerializevICMSDeson()
        {
            return vICMSDeson.HasValue;
        }

        public bool ShouldSerializemotDesICMS()
        {
            return !(string.IsNullOrEmpty(motDesICMS));
        }
	}
}
