using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao
{
	public class ICMS30
	{
        private decimal? _pMvast;
        private decimal? _pRedBcst;
        private decimal _vBcst;
        private decimal _pIcmsst;
        private decimal _vIcmsst;
        private decimal? _vIcmsDeson;
        private decimal? _vBcfcpst;
        private decimal? _pFcpst;
        private decimal? _vFcpst;

        /// <summary>
        ///     N11 - Origem da Mercadoria
        /// </summary>
        public string orig { get; set; }

        /// <summary>
        ///     N12- Situação Tributária
        /// </summary>
        public string CST { get; set; }

        /// <summary>
        ///     N18 - Modalidade de determinação da BC do ICMS ST
        /// </summary>
        public string modBCST { get; set; }

        /// <summary>
        ///     N19 - Percentual da margem de valor Adicionado do ICMS ST
        /// </summary>
        public decimal? pMVAST
        {
            get { return FunctionNFe.RoundDecimal(_pMvast, 4); }
            set { _pMvast = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N20 - Percentual da Redução de BC do ICMS ST
        /// </summary>
        public decimal? pRedBCST
        {
            get { return FunctionNFe.RoundDecimal(_pRedBcst, 4); }
            set { _pRedBcst = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N21 - Valor da BC do ICMS ST
        /// </summary>
        public decimal vBCST
        {
            get { return FunctionNFe.RoundDecimal(_vBcst, 2); }
            set { _vBcst = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N22 - Alíquota do imposto do ICMS ST
        /// </summary>
        public decimal pICMSST
        {
            get { return FunctionNFe.RoundDecimal(_pIcmsst, 4); }
            set { _pIcmsst = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N23 - Valor do ICMS ST
        /// </summary>
        public decimal vICMSST
        {
            get { return FunctionNFe.RoundDecimal(_vIcmsst, 2); }
            set { _vIcmsst = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        /// N23a - Valor da Base de Cálculo do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vBCFCPST
        {
            get { return FunctionNFe.RoundDecimal(_vBcfcpst,2); }
            set { _vBcfcpst = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vBCFCPSTSpecified
        {
            get { return vBCFCPST.HasValue; }
        }

        /// <summary>
        /// N23b - Percentual do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? pFCPST
        {
            get { return FunctionNFe.RoundDecimal(_pFcpst,4); }
            set { _pFcpst = FunctionNFe.RoundDecimal(value,4); }
        }

        public bool pFCPSTSpecified
        {
            get { return pFCPST.HasValue; }
        }

        /// <summary>
        /// N23d - Valor do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vFCPST
        {
            get { return _vFcpst; }
            set { _vFcpst = value; }
        }

        public bool vFCPSTSpecified
        {
            get { return vFCPST.HasValue; }
        }


        /// <summary>
        ///     N27a - Valor do ICMS desonerado
        /// </summary>
        public decimal? vICMSDeson
        {
            get { return _vIcmsDeson ?? FunctionNFe.RoundDecimal(_vIcmsDeson, 2); }
            set { _vIcmsDeson = value.HasValue ? decimal.Round(value.Value, 2) : (decimal?)null; }
        }

      
        public bool ShouldSerializepRedBCSTT()
        {
            return pRedBCST.HasValue;
        }

        public bool ShouldSerializevICMSDeson()
        {
            return vICMSDeson.HasValue;
        }

       
	}
}
