using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao
{
	public class ICMS51
	{
        private decimal? _pRedBc;
        private decimal? _vBc;
        private decimal? _pIcms;
        private decimal? _vIcmsOp;
        private decimal? _pDif;
        private decimal? _vIcmsDif;
        private decimal? _vIcms;
        private decimal? _vBcfcp;
        private decimal? _pFcp;
        private decimal? _vFcp;

        /// <summary>
        ///     N11 - Origem da Mercadoria
        /// </summary>
        public string orig { get; set; }

        /// <summary>
        ///     N12- Situação Tributária
        /// </summary>
        public string CST { get; set; }

        /// <summary>
        ///     N13 - Modalidade de determinação da BC do ICMS
        /// </summary>
        public string modBC { get; set; }

        /// <summary>
        ///     N14 - Percentual de redução da BC
        /// </summary>
        public decimal? pRedBC
        {
            get { return _pRedBc; }
            set { _pRedBc = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N15 - Valor da BC do ICMS
        /// </summary>
        public decimal? vBC
        {
            get { return _vBc; }
            set { _vBc = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N16 - Alíquota do imposto
        /// </summary>
        public decimal? pICMS
        {
            get { return _pIcms; }
            set { _pIcms = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N16a - Valor do ICMS da Operação
        /// </summary>
        public decimal? vICMSOp
        {
            get { return _vIcmsOp; }
            set { _vIcmsOp = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N16b - Percentual do diferimento
        /// </summary>
        public decimal? pDif
        {
            get { return _pDif; }
            set { _pDif = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N16c - Valor do ICMS diferido
        /// </summary>
        public decimal? vICMSDif
        {
            get { return _vIcmsDif; }
            set { _vIcmsDif = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N17 - Valor do ICMS
        /// </summary>
        public decimal? vICMS
        {
            get { return _vIcms; }
            set { _vIcms = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        /// N17a - Valor da Base de Cálculo do FCP
        /// Versão 4.00
        /// </summary>
        public decimal? vBCFCP
        {
            get { return FunctionNFe.RoundDecimal(_vBcfcp,2); }
            set { _vBcfcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vBCFCPSpecified
        {
            get { return vBCFCP.HasValue; }
        }

        /// <summary>
        /// N17b - Percentual do Fundo de Combate à Pobreza (FCP)
        /// Versão 4.00
        /// </summary>
        public decimal? pFCP
        {
            get { return FunctionNFe.RoundDecimal(_pFcp,4); }
            set { _pFcp = FunctionNFe.RoundDecimal(value,4); }
        }

        public bool pFCPSpecified
        {
            get { return pFCP.HasValue; }
        }

        /// <summary>
        /// N17c - Valor do Fundo de Combate à Pobreza (FCP)
        /// Versão 4.00
        /// </summary>
        public decimal? vFCP
        {
            get { return FunctionNFe.RoundDecimal(_vFcp,2); }
            set { _vFcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vFCPSpecified
        {
            get { return vFCP.HasValue; }
        }


        public bool ShouldSerializemodBC()
        {
            return !(modBC.Length == 0);
        }

        public bool ShouldSerializepRedBC()
        {
            return pRedBC.HasValue;
        }

        public bool ShouldSerializevBC()
        {
            return vBC.HasValue;
        }

        public bool ShouldSerializepICMS()
        {
            return pICMS.HasValue;
        }

        public bool ShouldSerializevICMSOp()
        {
            return vICMSOp.HasValue;
        }

        public bool ShouldSerializepDif()
        {
            return pDif.HasValue;
        }

        public bool ShouldSerializevICMSDif()
        {
            return vICMSDif.HasValue;
        }

        public bool ShouldSerializevICMS()
        {
            return vICMS.HasValue;
        }
	}
}
