using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao
{
	public class ICMS90
	{
        private decimal? _vBc;
        private decimal? _pRedBc;
        private decimal? _pIcms;
        private decimal? _vIcms;
        private decimal? _pMvast;
        private decimal? _pRedBcst;
        private decimal? _vBcst;
        private decimal? _pIcmsst;
        private decimal? _vIcmsst;
        private decimal? _vIcmsDeson;
        private decimal? _vBcfcp;
        private decimal? _pFcp;
        private decimal? _vFcp;
        private decimal? _vBcfcpst;
        private decimal? _pFcpst;
        private decimal? _vFcpst;

        /// <summary>
        ///     N11 - Origem da Mercadoria
        /// </summary>
        public string orig { get; set; }

        /// <summary>
        ///     N12- Situação Tributária
        /// </summary>
        public string CST { get; set; }

        /// <summary>
        ///     N13 - Modalidade de determinação da BC do ICMS
        /// </summary>
        public string modBC { get; set; }

        /// <summary>
        ///     N15 - Valor da BC do ICMS
        /// </summary>
        public decimal? vBC
        {
            get { return _vBc; }
            set { _vBc = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N14 - Percentual de redução da BC
        /// </summary>
        public decimal? pRedBC
        {
            get { return _pRedBc; }
            set { _pRedBc = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N16 - Alíquota do imposto
        /// </summary>
        public decimal? pICMS
        {
            get { return _pIcms; }
            set { _pIcms = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N17 - Valor do ICMS
        /// </summary>
        public decimal? vICMS
        {
            get { return _vIcms; }
            set { _vIcms = FunctionNFe.RoundDecimal(value, 2); }
        }


        /// <summary>
        /// N17a - Valor da Base de Cálculo do FCP
        /// Versão 4.00
        /// </summary>
        public decimal? vBCFCP
        {
            get { return FunctionNFe.RoundDecimal(_vBcfcp,2); }
            set { _vBcfcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vBCFCPSpecified
        {
            get { return vBCFCP.HasValue; }
        }

        /// <summary>
        /// N17b - Percentual do Fundo de Combate à Pobreza (FCP)
        /// Versão 4.00
        /// </summary>
        public decimal? pFCP
        {
            get { return FunctionNFe.RoundDecimal(_pFcp,4); }
            set { _pFcp = FunctionNFe.RoundDecimal(value,4); }
        }

        public bool pFCPSpecified
        {
            get { return pFCP.HasValue; }
        }

        /// <summary>
        /// N17c - Valor do Fundo de Combate à Pobreza (FCP)
        /// Versão 4.00
        /// </summary>
        public decimal? vFCP
        {
            get { return FunctionNFe.RoundDecimal(_vFcp,2); }
            set { _vFcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vFCPSpecified
        {
            get { return vFCP.HasValue; }
        }

        /// <summary>
        ///     N18 - Modalidade de determinação da BC do ICMS ST
        /// </summary>
        public string modBCST { get; set; }

        /// <summary>
        ///     N19 - Percentual da margem de valor Adicionado do ICMS ST
        /// </summary>
        public decimal? pMVAST
        {
            get { return _pMvast; }
            set { _pMvast = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N20 - Percentual da Redução de BC do ICMS ST
        /// </summary>
        public decimal? pRedBCST
        {
            get { return _pRedBcst; }
            set { _pRedBcst = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N21 - Valor da BC do ICMS ST
        /// </summary>
        public decimal? vBCST
        {
            get { return _vBcst; }
            set { _vBcst = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N22 - Alíquota do imposto do ICMS ST
        /// </summary>
        public decimal? pICMSST
        {
            get { return _pIcmsst; }
            set { _pIcmsst = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     N23 - Valor do ICMS ST
        /// </summary>
        public decimal? vICMSST
        {
            get { return _vIcmsst; }
            set { _vIcmsst = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        /// N23a - Valor da Base de Cálculo do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vBCFCPST
        {
            get { return FunctionNFe.RoundDecimal(_vBcfcpst,2); }
            set { _vBcfcpst = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vBCFCPSTSpecified
        {
            get { return vBCFCPST.HasValue; }
        }

        /// <summary>
        /// N23b - Percentual do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? pFCPST
        {
            get { return FunctionNFe.RoundDecimal(_pFcpst,4); }
            set { _pFcpst = FunctionNFe.RoundDecimal(value,4); }
        }

        public bool pFCPSTSpecified
        {
            get { return pFCPST.HasValue; }
        }

        /// <summary>
        /// N23d - Valor do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vFCPST
        {
            get { return _vFcpst; }
            set { _vFcpst = value; }
        }

        public bool vFCPSTSpecified
        {
            get { return vFCPST.HasValue; }
        }

        /// <summary>
        ///     N27a - Valor do ICMS desonerado
        /// </summary>
        public decimal? vICMSDeson
        {
            get { return _vIcmsDeson; }
            set { _vIcmsDeson = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     N28 - Motivo da desoneração do ICMS
        /// </summary>
        public string motDesICMS { get; set; }


        public bool ShouldSerializevBC()
        {
            return vBC.HasValue;
        }

        public bool ShouldSerializepRedBC()
        {
            return pRedBC.HasValue;
        }

        public bool ShouldSerializepICMS()
        {
            return pICMS.HasValue;
        }

        public bool ShouldSerializevICMS()
        {
            return vICMS.HasValue;
        }

        public bool ShouldSerializepMVAST()
        {
            return pMVAST.HasValue;
        }

        public bool ShouldSerializepRedBCST()
        {
            return pRedBCST.HasValue;
        }

        public bool ShouldSerializevBCST()
        {
            return vBCST.HasValue;
        }

        public bool ShouldSerializepICMSST()
        {
            return pICMSST.HasValue;
        }

        public bool ShouldSerializevICMSST()
        {
            return vICMSST.HasValue;
        }

        public bool ShouldSerializevICMSDeson()
        {
            return vICMSDeson.HasValue;
        }

	}
}
