using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao
{
	public class ICMSSN900
	{
        private decimal? _vBcfcpst;
        private decimal? _pFcpst;
        private decimal? _vFcpst;


       /// <summary>
		/// Origem da mercadoria:
		/// 0 - Nacional, exceto as indicadas nos Códigos 3 a 5;
		/// 1 - Estrangeira - Importação Direta, exceto a indicada no Código 6;
		/// 2 - Estrangeira - Adquirida no mercado interno, exceto a indicada no Código 7;
		/// 3 - Nacional, Mercadoria ou bem com conteúdo de Importação superior a 40% (Quarenta por Cento);
		/// 4 - Nacional, cuja produção tenha sido feita em conformidade com os processos produtivos básicos de que tratam o Decreto-Lei Nº 288/67, e as Leis Nºs 8.248/91, 8.387/91, 10.176/01 e 11.484/07;
		/// 5 - Nacional, Mercadoria ou bem com conteúdo de Importação inferior ou igual a 40% (Quarenta por Cento);
		/// 6 - Estrangeira - Importação Direta, sem similar Nacional, constante em lista de resolução CAMEX e gas natural;
		/// 7 - Estrangeira - Adquirida no mercado interno, sem similar Nacional, constante em lista de resolução CAMEX e gas natural.
		/// </summary>
		public string orig { get; set; }

		/// <summary>
		/// CSOSN=900
		/// </summary>
		public string CSOSN { get; set; }

		/// <summary>
		/// 0 - Margem Valor Agregado (%);
		/// 1 - Pauta (Valor);
		/// 2 - Preço Tabelado Máx. (valor);
		/// 3 - valor da operação.
		/// </summary>
		public string modBC { get; set; }

		/// <summary>
		/// Valor da BC do ICMS
		/// </summary>
        public decimal vBC { get; set; }

		/// <summary>
		/// Percentual da Redução de BC
		/// </summary>
        public decimal? pRedBC { get; set; }
        public bool ShouldSerializepRedBC()
        {
            return !(pRedBC == null);
        }

		/// <summary>
		/// Aliquota do imposto
		/// </summary>
        public decimal pICMS { get; set; }

		/// <summary>
		/// Valor do ICMS
		/// </summary>
        public decimal vICMS { get; set; }

		/// <summary>
		/// 0 – Preço tabelado ou máximo sugerido;
		/// 1 - Lista Negativa (valor);
		/// 2 - Lista Positiva (valor);
		/// 3 - Lista Neutra (valor);
		/// 4 - Margem Valor Agregado (%);
		/// 5 - Pauta (valor).
		/// </summary>
		public string modBCST { get; set; }

		/// <summary>
		/// % MVA (IVA)
		/// </summary>
        public decimal? pMVAST { get; set; }
        public bool ShouldSerializepMVAST()
        {
            return !(pMVAST == null);
        }

		/// <summary>
		/// Percentual da Redução de BC do ICMS ST
		/// </summary>
        public decimal? pRedBCST { get; set; }
        public bool ShouldSerializepRedBCST()
        {
            return !(pRedBCST == null);
        }

		/// <summary>
		/// Valor do ICMS ST
		/// </summary>
		public decimal? vBCST { get; set; }
        public bool ShouldSerializevBCST()
        {
            return !(vBCST == null);
        }

		/// <summary>
		/// Alíquota do imposto do ICMS ST
		/// </summary>
        public decimal? pICMSST { get; set; }
        public bool ShouldSerializepICMSST()
        {
            return !(pICMSST == null);
        }

		/// <summary>
		/// Valor do ICMS ST retido
		/// </summary>
        public decimal? vICMSST { get; set; }
        public bool ShouldSerializevICMSST()
        {
            return !(vICMSST == null);
        }

        /// <summary>
        /// N23a - Valor da Base de Cálculo do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vBCFCPST
        {
            get { return FunctionNFe.RoundDecimal(_vBcfcpst,2); }
            set { _vBcfcpst = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vBCFCPSTSpecified
        {
            get { return vBCFCPST.HasValue; }
        }

        /// <summary>
        /// N23b - Percentual do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? pFCPST
        {
            get { return FunctionNFe.RoundDecimal(_pFcpst,4); }
            set { _pFcpst = FunctionNFe.RoundDecimal(value,4); }
        }

        public bool pFCPSTSpecified
        {
            get { return pFCPST.HasValue; }
        }

        /// <summary>
        /// N23d - Valor do FCP retido por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vFCPST
        {
            get { return _vFcpst; }
            set { _vFcpst = value; }
        }

        public bool vFCPSTSpecified
        {
            get { return vFCPST.HasValue; }
        }

        /// <summary>
        /// Alíquota aplicável de cálculo do crédito (Simples Nacional).
        /// </summary>
        public decimal pCredSN { get; set; }

		/// <summary>
		/// Valor crédito do ICMS que pode ser aproveitado nos termos do art. 23 da LC 123 (Simples Nacional)
		/// </summary>
        public decimal vCredICMSSN { get; set; }

	}
}
