﻿namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao
{
    /// <summary>
    /// Grupo a ser informado nas vendas interestaduais para
    /// consumidor final, não contribuinte do ICMS.
    /// </summary>
    public class ICMSUFDest
    {
        /// <summary>
        /// Valor da Base de Cálculo do ICMS na UF de destino.
        /// </summary>
        public decimal vBCUFDest        { get; set; }


        /// <summary>
        /// Percentual adicional inserido na alíquota interna da UF de
        /// destino, relativo ao Fundo de Combate à Pobreza (FCP) naquela UF.
        /// Nota: Percentual máximo de 2%, conforme a legislação.
        /// </summary>
        public decimal pFCPUFDest       { get; set; }


        /// <summary>
        /// Alíquota adotada nas operações internas na UF de destino para o
        /// produto / mercadoria. A alíquota do Fundo de Combate a  
        /// Pobreza, se existente para o produto / mercadoria, deve ser
        /// informada no campo próprio (pFCPUFDest) não devendo ser
        /// somada à essa alíquota interna.
        /// </summary>
        public decimal pICMSUFDest      { get; set; }


        /// <summary>
        /// Alíquota interestadual das UF envolvidas:
        /// - 4% alíquota interestadual para produtos importados;
        /// - 7% para os Estados de origem do Sul e Sudeste (exceto ES),
        /// destinado para os Estados do Norte, Nordeste, CentroOeste e Espírito Santo;
        /// - 12% para os demais casos.
        /// </summary>
        public decimal pICMSInter       { get; set; }


        /// <summary>
        /// Percentual de ICMS Interestadual para a UF de destino:
        /// - 40% em 2016;
        /// - 60% em 2017;
        /// - 80% em 2018;
        /// - 100% a partir de 2019.
        /// </summary>
        public decimal pICMSInterPart   { get; set; }


        /// <summary>
        ///  Valor do ICMS relativo ao Fundo de Combate à Pobreza (FCP) da
        /// UF de destino
        /// </summary>
        public decimal vFCPUFDest       { get; set; }


        /// <summary>
        /// Valor do ICMS Interestadual para a UF de destino, já
        /// considerando o valor do ICMS relativo ao Fundo de Combate à
        /// Pobreza naquela UF.
        /// </summary>
        public decimal vICMSUFDest      { get; set; }


        /// <summary>
        /// Valor do ICMS Interestadual para a UF do remetente.
        /// Nota: A partir de 2019, este valor será zero.
        /// </summary>
        public decimal vICMSUFRemet     { get; set; }
       
    }
}
