using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao
{
	/// <summary>
	/// TAG do grupo de PIS Outras Operações
	/// 49=Outras Operações de Saída;
	/// 50=Operação com Direito a Crédito - Vinculada Exclusivamente a Receita Tributada no Mercado Interno;
	/// 51=Operação com Direito a Crédito - Vinculada Exclusivamente a Receita Não Tributada no Mercado Interno;
	/// 52=Operação com Direito a Crédito – Vinculada Exclusivamente a Receita de Exportação;
	/// 53=Operação com Direito a Crédito - Vinculada a Receitas Tributadas e Não-Tributadas no Mercado Interno;
	/// 54=Operação com Direito a Crédito - Vinculada a Receitas Tributadas no Mercado Interno e de Exportação;
	/// 55=Operação com Direito a Crédito - Vinculada a Receitas Não-Tributadas no Mercado Interno e de Exportação;
	/// 56=Operação com Direito a Crédito - Vinculada a Receitas Tributadas e Não-Tributadas no Mercado Interno, e de Exportação;
	/// 60=Crédito Presumido - Operação de Aquisição Vinculada Exclusivamente a Receita Tributada no Mercado Interno;
	/// 61=Crédito Presumido - Operação de Aquisição Vinculada Exclusivamente a Receita Não-Tributada no Mercado Interno;
	/// 62=Crédito Presumido - Operação de Aquisição Vinculada Exclusivamente a Receita de Exportação;
	/// 63=Crédito Presumido - Operação de Aquisição Vinculada a Receitas Tributadas e Não-Tributadas no Mercado Interno;
	/// 64=Crédito Presumido - Operação de Aquisição Vinculada a Receitas Tributadas no Mercado Interno e de Exportação;
	/// 65=Crédito Presumido - Operação de Aquisição Vinculada a Receitas Não-Tributadas no Mercado Interno e de Exportação;
	/// 66=Crédito Presumido - Operação de Aquisição Vinculada a Receitas Tributadas e Não-Tributadas no Mercado Interno, e de Exportação;
	/// 67=Crédito Presumido - Outras Operações;
	/// 70=Operação de Aquisição sem Direito a Crédito;
	/// 71=Operação de Aquisição com Isenção;
	/// 72=Operação de Aquisição com Suspensão;
	/// 73=Operação de Aquisição a Alíquota Zero;
	/// 74=Operação de Aquisição; sem Incidência da Contribuição;
	/// 75=Operação de Aquisição por Substituição Tributária;
	/// 98=Outras Operações de Entrada;
	/// 99=Outras Operações.
	/// </summary>
	public class PISOutr
	{
        private decimal? _vBc;
        private decimal? _pPis;
        private decimal? _qBcProd;
        private decimal? _vAliqProd;
        private decimal? _vPis;

        /// <summary>
        ///     Q06 - Código de Situação Tributária do PIS
        /// </summary>
        public string CST { get; set; }

        /// <summary>
        ///     Q07 - Valor da Base de Cálculo do PIS
        /// </summary>
        public decimal? vBC
        {
            get { return _vBc; }
            set { _vBc = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     Q08 - Alíquota do PIS (em percentual)
        /// </summary>
        public decimal? pPIS
        {
            get { return _pPis; }
            set { _pPis = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     Q10 - Quantidade Vendida
        /// </summary>
        public decimal? qBCProd
        {
            get { return _qBcProd; }
            set { _qBcProd = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     Q11 - Alíquota do PIS (em reais)
        /// </summary>
        public decimal? vAliqProd
        {
            get { return _vAliqProd; }
            set { _vAliqProd = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     Q09 - Valor do PIS
        /// </summary>
        public decimal? vPIS
        {
            get { return _vPis; }
            set { _vPis = FunctionNFe.RoundDecimal(value, 2); }
        }

        public bool ShouldSerializevBC()
        {
            return vBC.HasValue;
        }

        public bool ShouldSerializepPIS()
        {
            return pPIS.HasValue;
        }

        public bool ShouldSerializeqBCProd()
        {
            return qBCProd.HasValue;
        }

        public bool ShouldSerializevAliqProd()
        {
            return vAliqProd.HasValue;
        }

        public bool ShouldSerializevPIS()
        {
            return vPIS.HasValue;
        }
	}
}
