using System.Collections.Generic;
using System.Xml.Serialization;
using NFeLib.NFE.BaseNF.Informacoes.TranspVolumes;
using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Detalhes
{
	/// <summary>
	/// TAG de grupo do detalhamento de Produtos e Serviços da NF-e
	/// </summary>
	/// 

	public class prod
	{
        private decimal _qcom;
        private decimal _vUnCom;
        private decimal _vprod;
        private decimal _qtrib;
        private decimal _vUnTrib;
        private decimal _vFrete;
        private decimal _vSeg;
        private decimal _vDesc;
        private decimal _vOutro;
		/// <summary>
		/// Código de produto ou serviço
		/// Preencher com CFOP, caso se trate de itens não relacionados com mercadorias/produto e que o
		/// contribuinte não possua codificação própria.
		/// Formato ”CFOP9999”
		/// </summary>
		public string cProd { get; set; }

		/// <summary>
		/// GTIN (Global Trade Item Number) do produto, antigo código EAN ou código de barras
		///
		/// Preencher com o código GTIN-8, GTIN-12, GTIN-13 ou GTIN-14
		/// (antigos códigos EAN, UPC e DUN-14), não informar o conteúdo da TAG em caso de o produto não
		/// possuir este código.
		/// </summary>
		public string cEAN { get; set; }

		/// <summary>
		/// Descrição do produto ou serviço
		/// </summary>
		public string xProd { get; set; }

		/// <summary>
		/// Preencher de acordo com a Tabela de Capítulos da NCM. Em caso deserviço, não incluir a TAG.
		/// </summary>
		public string NCM { get; set; }


        /// <summary>
        /// Código Especificador da Substituição Tributária – CEST, que estabelece a
        /// sistemática de uniformização e identificação das mercadorias e bens passíveis de
        /// sujeição aos regimes de substituição tributária e de antecipação de recolhimento do ICMS
        /// </summary>
        public string CEST { get; set; }
        public bool ShouldSerializeCEST()
        {
            return !(CEST == null || CEST.Length == 0);
        }

		/// <summary>
		/// Preencher de acordo com o código EX da TIPI. Em caso de serviço,não incluir a TAG
		/// </summary>
		public string EXTIPI { get; set; }

		/// <summary>
		/// Gênero do produto ou serviço. Preencher de acordo com a Tabela de Capítulos da NCM. Em caso de serviço, não incluir a TAG.
		/// </summary>
		public string genero { get; set; }

		/// <summary>
		/// Utilizar Tabela de CFOP.
		/// </summary>
		public string CFOP { get; set; }

		/// <summary>
		/// Informar a unidade de comercialização do produto.
		/// </summary>
        public string uCom { get; set; }

        /// <summary>
        ///     I10 - Quantidade Comercial  do produto, alterado para aceitar de 0 a 4 casas decimais e 11 inteiros.
        /// </summary>
        public decimal qCom
        {
            get { return _qcom; }
            set { _qcom = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     I10a - Valor Unitário de Comercialização
        /// </summary>
        public decimal vUnCom
        {
            get { return _vUnCom; }
            set { _vUnCom = FunctionNFe.RoundDecimal(value, 10); }
        }

        /// <summary>
        ///     I11 - Valor Total Bruto dos Produtos ou Serviços
        /// </summary>
        public decimal vProd
        {
            get { return _vprod; }
            set { _vprod = FunctionNFe.RoundDecimal(value, 2); }
        }


		/// <summary>
		/// GTIN (Global Trade Item Number) da unidade tributável,antigo código EAN ou código de barras
		///
		/// Preencher com o código GTIN-8, GTIN-12, GTIN-13 ou GTIN-14 (antigos códigos EAN, UPC e DUN-14) da unidade tributável do
		/// produto, não informar o conteúdo da TAG em caso de o produto não possuir este código.
		/// </summary>
		public string cEANTrib { get; set; }

		/// <summary>
		/// Unidade Tributável
		/// </summary>
		public string uTrib { get; set; }

        /// <summary>
        ///     I14 - Quantidade Tributável
        /// </summary>
        public decimal qTrib
        {
            get { return _qtrib; }
            set { _qtrib = FunctionNFe.RoundDecimal(value, 4); }
        }

        /// <summary>
        ///     I14a - Valor Unitário de tributação
        /// </summary>
        public decimal vUnTrib
        {
            get { return _vUnTrib; }
            set { _vUnTrib = FunctionNFe.RoundDecimal(value, 10); }
        }

        /// <summary>
        ///     I15 - Valor Total do Frete
        /// </summary>
        public decimal vFrete
        {
            get { return _vFrete; }
            set { _vFrete = FunctionNFe.RoundDecimal(value, 2); }
        }
        public bool ShouldSerializevFrete()
        {
            return !(vFrete <= 0);
        }

		/// <summary>
		/// Valor total do seguro
		/// </summary>
        /// <summary>
        ///     I16 - Valor Total do Seguro
        /// </summary>
        public decimal vSeg
        {
            get { return _vSeg; }
            set { _vSeg = FunctionNFe.RoundDecimal(value, 2); }
        }
        public bool ShouldSerializevSeg()
        {
            return !(vSeg <= 0);
        }

        /// <summary>
        ///     I17 - Valor do Desconto
        /// </summary>
        public decimal vDesc
        {
            get { return _vDesc; }
            set { _vDesc = FunctionNFe.RoundDecimal(value, 2); }
        }
       public bool ShouldSerializevDesc()
       {
           return !(vDesc <= 0);
       }

       /// <summary>
       ///     I17a - Outras despesas acessórias
       /// </summary>
       public decimal vOutro
       {
           get { return _vOutro; }
           set { _vOutro = FunctionNFe.RoundDecimal(value, 2); }
       }
        public bool ShouldSerializevOutro()
        {
            return !(vOutro <= 0);
        }

		/// <summary>
		/// Este campo deverá ser preenchido com:
		///0 – o valor do item (vProd) não compõe o valor total da NF-e (vProd)
		///1 – o valor do item (vProd) compõe o valor total da NF-e (vProd) (v2.0)
		/// </summary>
		public string indTot { get; set; }

        // <summary>
        ///     I18 - Declaração de Importação
        /// </summary>
        [XmlElement("DI")]
        public List<DI> DI { get; set; }

        /// <summary>
        ///     I50 - Grupo de informações de exportação para o item
        /// </summary>
        [XmlElement("detExport")]
        public List<detExport> detExport { get; set; }

        /// <summary>
        ///     I60 - Número do Pedido de Compra
        /// </summary>
        public string xPed { get; set; }

        /// <summary>
        ///     I61 - Item do Pedido de Compra
        /// </summary>
        public int? nItemPed { get; set; }
        public bool ShouldSerializenItemPed()
        {
            return !(nItemPed == null || nItemPed <= 0);
        }

        /// <summary>
        ///     I70 - Número de controle da FCI - Ficha de Conteúdo de Importação
        /// </summary>
        public string nFCI { get; set; }

        /// <summary>
        /// I80 - Detalhamento de produto sujeito a rastreabilidade
        /// Versão 4.00
        /// </summary>
        [XmlElement("rastro")]
        public List<rastro> rastro { get; set; }


		public veicProd veicProd { get; set; }

		[XmlElement("")]
		public List<med> med { get; set; }

		public arma arma { get; set; }
		public comb comb { get; set; }

        public prod() 
        {
            this.med = new List<med>();
        }

	}
}
