using System.Collections.Generic;
using System.Xml.Serialization;

namespace NFeLib.NFE.BaseNF.Informacoes.Identificacao
{
    public class ide
    {
        /// <summary>
        /// Código da UF do emitente do Documento Fiscal. Utilizar a Tabela do IBGE de código de unidades da
        /// federação (Anexo IV - Tabela de UF, Município e País)
        /// </summary>
        public string cUF { get; set; }

        /// <summary>
        /// Código numérico que compõe a Chave de Acesso. Número aleatório gerado pelo emitente para
        /// cada NF-e para evitar acessos indevidos da NF-e.
        /// </summary>
        public string cNF { get; set; }

        /// <summary>
        /// Informar a natureza da operação de que decorrer a saída ou a entrada, tais como: venda, compra,
        /// transferência, devolução, importação, consignação, remessa (para fins de demonstração, de
        /// industrialização ou outra), conforme previsto na alínea 'i', inciso I, art. 19
        /// do CONVÊNIO S/Nº, de 15 de dezembro de 1970
        /// </summary>
        public string natOp { get; set; }

        /// <summary>
        /// Utilizar o código 55 para identificação da NF-e, emitida em substituição ao modelo 1 ou 1A.
        /// </summary>
        public string mod { get; set; }

        /// <summary>
        /// Série do Documento Fiscal, informar 0 (zero) para série única.
        /// </summary>
        public string serie { get; set; }

        /// <summary>
        /// Número do Documento Fiscal.
        /// </summary>
        public string nNF { get; set; }

        /// <summary>
        ///     Data de emissão do Documento Fiscal - V2.00 (Formato “AAAA-MM-DD”)
        /// </summary>
        public string dEmi { get; set; } //V2.00

        /// <summary>
        ///     Data de Saída ou da Entrada da Mercadoria/Produto - V2.00 (Formato “AAAA-MM-DD”)
        /// </summary>
        public string dSaiEnt { get; set; } //V2.00

        /// <summary>
        /// Versão 3.10 NFe  
        /// Data e hora no formato UTC (Universal Coordinated Time): AAAA-MM-DDThh:mm:ssTZD
        /// </summary>
        public string dhEmi { get; set; }
        public bool ShouldSerializedhEmi()
        {
            return !(dhEmi == null || dhEmi == string.Empty);
        }

        /// <summary>
        /// Versão 3.10 NFe  
        /// Data e hora no formato UTC (Universal Coordinated Time): AAAA-MM-DDThh:mm:ssTZD
        /// </summary>
        public string dhSaiEnt { get; set; }
        public bool ShouldSerializedhSaiEnt()
        {
            return !(dhSaiEnt == null || dhSaiEnt == string.Empty);
        }

        /// <summary>
        /// 0-entrada / 1-saída
        /// </summary>
        public string tpNF { get; set; }

        /// <summary>
        /// Versão 3.10 NFe  
        /// 1=Operação interna; 
        /// 2=Operação interestadual; 
        /// 3=Operação com exterior. 
        /// </summary>
        public string idDest { get; set; }
        public bool ShouldSerializeidDest()
        {
            return !(idDest == null || idDest == string.Empty);
        }

        /// <summary>
        /// Informar o município de ocorrência do fato gerador do ICMS. Utilizar a
        /// Tabela do IBGE (Anexo IV - Tabela de UF, Município e País).
        /// </summary>
        public string cMunFG { get; set; }

        /// <summary>
        /// Formato do DANFe
        /// 
        /// 0=Sem geração de DANFE;
        /// 1=DANFE normal, Retrato;
        /// 2=DANFE normal, Paisagem;
        /// 3=DANFE Simplificado;
        /// 4=DANFE NFC-e;
        /// 5=DANFE NFC-e em mensagem eletrônica.
        /// </summary>
        public string tpImp { get; set; }

        /// <summary>
        ///1=Emissão normal (não em contingência); 
        ///2=Contingência FS-IA, com impressão do DANFE em formulário de segurança; 
        ///3=Contingência SCAN (Sistema de Contingência do Ambiente Nacional); 
        ///4=Contingência DPEC (Declaração Prévia da Emissão em Contingência); 
        ///5=Contingência FS-DA, com impressão do DANFE em formulário de segurança; 
        ///6=Contingência SVC-AN (SEFAZ Virtual de Contingência do AN); 
        ///7=Contingência SVC-RS (SEFAZ Virtual de Contingência do RS); 
        ///9=Contingência off-line da NFC-e; 
        /// </summary>
        public string tpEmis { get; set; }

        /// <summary>
        /// Informar o DV da Chave de Acesso da NF-e, o DV será calculado com a aplicação do algoritmo módulo 11
        /// (base 2,9) da Chave de Acesso. (vide item 5 do Manual de Integração)
        /// </summary>
        public string cDV { get; set; }

        /// <summary>
        /// 1-Produção/ 2-Homologação
        /// </summary>
        public string tpAmb { get; set; }

        /// <summary>
        /// 1- NF-e normal/ 2-NF-e complementar / 3 – NF-e de ajuste / 4 - Devolução/Retorno.
        /// </summary>
        public string finNFe { get; set; }

        /// <summary>
        /// Versão 3.10 NFe
        /// 0=Normal; 
        /// 1=Consumidor final;
        /// </summary>
        public string indFinal { get; set; }
        public bool ShouldSerializeindFinal()
        {
            return !(indFinal == null || indFinal == string.Empty);
        }

        /// <summary>
        /// Versão 3.10 NFe    
        /// 0=Não se aplica (por exemplo, Nota Fiscal complementar 
        /// ou de ajuste); 
        /// 1=Operação presencial; 
        /// 2=Operação não presencial, pela Internet; 
        /// 3=Operação não presencial, Teleatendimento; 
        /// 4=NFC-e em operação com entrega a domicílio; 
        /// 9=Operação não presencial, outros. 
        /// </summary>
        public string indPres { get; set; }
        public bool ShouldSerializeindPres()
        {
            return !(indPres == null || indPres == string.Empty);
        }

        /// <summary>
        /// Identificador do processo de emissão da NF-e: 0 - emissão de NF-e com aplicativo do contribuinte;
        /// 1 - emissão de NF-e avulsa pelo Fisco;
        /// 2 - emissão de NF-e avulsa, pelo contribuinte com seu certificado digital, através do site do Fisco;
        /// 3- emissão NF-e pelo contribuinte com aplicativo fornecido pelo Fisco.
        /// </summary>
        public string procEmi { get; set; }

        /// <summary>
        /// Identificador da versão do processo de emissão (informar a versão do aplicativo emissor de NF-e).
        /// </summary>
        public string verProc { get; set; }

        /// <summary>
        /// Data e Hora da entrada em contingência 
        /// </summary>
        public string dhCont { get; set; }
        public bool ShouldSerializedhCont()
        {
            return !(dhCont == null || dhCont == string.Empty);
        }

        /// <summary>
        /// Justificativa da entrada em contingência 
        /// </summary>
        public string xJust { get; set; }
        public bool ShouldSerializexJust()
        {
            return !(xJust == null || xJust == string.Empty);
        }

        /// <summary>
        ///     BA01 - Informação de Documentos Fiscais referenciados
        /// </summary>
        [XmlElement("NFref")]
        public List<NFref> NFref { get; set; }
    }
}
