using NFeLib.NFE.Utils;

namespace NFeLib.NFE.BaseNF.Informacoes.Totais
{
	/// <summary>
	/// TAG de grupo de Valores Totais referentes ao ICMS
	/// </summary>
	public class ICMSTot
	{
        private decimal _vBc;
        private decimal _vIcms;
        private decimal? _vIcmsDeson;
        private decimal _vBcst;
        private decimal _vSt;
        private decimal _vProd;
        private decimal _vFrete;
        private decimal _vSeg;
        private decimal _vDesc;
        private decimal _vIi;
        private decimal _vIpi;
        private decimal _vPis;
        private decimal _vCofins;
        private decimal _vOutro;
        private decimal _vNf;
        private decimal _vTotTrib;
        private decimal? _vFcpufDest;
        private decimal? _vIcmsufDest;
        private decimal? _vIcmsufRemet;
        private decimal? _vFcp;
        private decimal? _vFcpst;
        private decimal? _vFcpstRet;
        private decimal? _vIpiDevol;



        //// <summary>
        ///     W03 - Base de Cálculo do ICMS
        /// </summary>
        public decimal vBC
        {
            get { return _vBc; }
            set { _vBc = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W04 - Valor Total do ICMS
        /// </summary>
        public decimal vICMS
        {
            get { return _vIcms; }
            set { _vIcms = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W04a - Valor Total do ICMS desonerado
        /// </summary>
        public decimal? vICMSDeson
        {
            get { return _vIcmsDeson; }
            set { _vIcmsDeson = FunctionNFe.RoundDecimal(value, 2); }
        } //Nulable por conta da v2.00
        public bool ShouldSerializevICMSDeson()
        {
            return !(vICMSDeson == null);
        }

        /// <summary>
        /// Valor total do ICMS relativo ao Fundo de Combate à Pobreza
        /// (FCP) para a UF de destino.
        /// </summary>
        public decimal vFCPUFDest { get; set; }
        public bool ShouldSerializevFCPUFDest()
        {
            return !(vFCPUFDest == 0);
        }

        /// <summary>
        /// Valor total do ICMS Interestadual para a UF de destino, já
        /// considerando o valor do ICMS relativo ao Fundo de Combate à 
        /// Pobreza naquela UF.
        /// </summary>
        public decimal vICMSUFDest { get; set; }
        public bool ShouldSerializevICMSUFDest()
        {
            return !(vICMSUFDest == 0);
        }

        /// <summary>
        /// Valor total do ICMS Interestadual para a UF do remetente.
        /// Nota: A partir de 2019, este valor será zero.
        /// </summary>
        public decimal vICMSUFRemet { get; set; }
        public bool ShouldSerializevICMSUFRemet()
        {
            return !(vICMSUFRemet == 0);
        }

        /// <summary>
        /// W04h - Valor Total do FCP (Fundo de Combate à Pobreza)
        /// Versão 4.00
        /// </summary>
        public decimal? vFCP
        {
            get { return FunctionNFe.RoundDecimal(_vFcp,2); }
            set { _vFcp = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vFCPSpecified
        {
            get { return vFCP.HasValue; }
        }

        /// <summary>
        ///     W05 - Base de Cálculo do ICMS ST
        /// </summary>
        public decimal vBCST
        {
            get { return _vBcst; }
            set { _vBcst = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W06 - Valor Total do ICMS ST
        /// </summary>
        public decimal vST
        {
            get { return _vSt; }
            set { _vSt = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        /// W06a - Valor Total do FCP (Vundo de Combate à Pobreza) retido por substituição tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vFCPST
        {
            get { return FunctionNFe.RoundDecimal(_vFcpst,2); }
            set { _vFcpst = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vFCPSTSpecified
        {
            get { return vFCPST.HasValue; }
        }

        /// <summary>
        /// W06b - Valor Total do FCP retido anteriormente por Substituição Tributária
        /// Versão 4.00
        /// </summary>
        public decimal? vFCPSTRet
        {
            get { return FunctionNFe.RoundDecimal(_vFcpstRet,2); }
            set { _vFcpstRet = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vFCPSTRetSpecified
        {
            get { return vFCPSTRet.HasValue; }
        }

        /// <summary>
        ///     W07 - Valor Total dos produtos e serviços
        /// </summary>
        public decimal vProd
        {
            get { return _vProd; }
            set { _vProd = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W08 - Valor Total do Frete
        /// </summary>
        public decimal vFrete
        {
            get { return _vFrete; }
            set { _vFrete = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W09 - Valor Total do Seguro
        /// </summary>
        public decimal vSeg
        {
            get { return _vSeg; }
            set { _vSeg = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W10 - Valor Total do Desconto
        /// </summary>
        public decimal vDesc
        {
            get { return _vDesc; }
            set { _vDesc = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W11 - Valor Total do II
        /// </summary>
        public decimal vII
        {
            get { return _vIi; }
            set { _vIi = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W12 - Valor Total do IPI
        /// </summary>
        public decimal vIPI
        {
            get { return _vIpi; }
            set { _vIpi = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        /// W12a - Valor Total do IPI devolvido
        /// Versão 4.00
        /// </summary>
        public decimal? vIPIDevol
        {
            get { return FunctionNFe.RoundDecimal(_vIpiDevol,2); }
            set { _vIpiDevol = FunctionNFe.RoundDecimal(value,2); }
        }

        public bool vIPIDevolSpecified
        {
            get { return vIPIDevol.HasValue; }
        }


        /// <summary>
        ///     W13 - Valor do PIS
        /// </summary>
        public decimal vPIS
        {
            get { return _vPis; }
            set { _vPis = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W14 - Valor da COFINS
        /// </summary>
        public decimal vCOFINS
        {
            get { return _vCofins; }
            set { _vCofins = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W15 - Outras Despesas acessórias
        /// </summary>
        public decimal vOutro
        {
            get { return _vOutro; }
            set { _vOutro = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     w16 - Valor Total da NF-e
        /// </summary>
        public decimal vNF
        {
            get { return _vNf; }
            set { _vNf = FunctionNFe.RoundDecimal(value, 2); }
        }

        /// <summary>
        ///     W16a - Valor aproximado total de tributos federais, estaduais e municipais.
        /// </summary>
        public decimal vTotTrib
        {
            get { return _vTotTrib; }
            set { _vTotTrib = FunctionNFe.RoundDecimal(value, 2); }
        }
        public bool ShouldSerializevTotTrib()
        {
            return !(vTotTrib == 0);
        }
	}
}
