﻿using System;
using System.Xml;
using NFeLib.NFE.BaseNF.Protocolo;
using NFeLib.NFE.BaseNF.Servicos.Autorizacao;
using NFeLib.NFE.Utils;
using NFeLib.NFE.WebServices;

namespace NFeLib.NFE.Processos
{
    public class NFeAutorizacao : BaseEnvioSefaz<retEnviNFe>
    {
        public XmlDocument XmlDocAssinado { get; set; }

        public XmlDocument XmlNFeProcessada { get; set; }

        public NFeAutorizacao()
        {
            RetornoSefaz = null;
            GetErros = string.Empty;
        }

        public  void EnviarSefaz()
        {
            //Gera o Lote para Envio
            enviNFe nfEnvio = new enviNFe()
            {
                versao = ConfigServico.Versao,
                idLote = "000000000000001",
                indSinc = "1"
            };
            XmlDocument xmlEnvLote = FunctionNFe.Serializar(nfEnvio);
            if (XmlDocAssinado.FirstChild is XmlDeclaration)
            {
                XmlDocAssinado.RemoveChild(XmlDocAssinado.FirstChild);
            }
            xmlEnvLote.DocumentElement.AppendChild(xmlEnvLote.ImportNode(XmlDocAssinado.FirstChild, true));
          
            //Envia para o Sefaz o Xml
            IWebService webServiceNFe = new WebRequestWS(ConfigServico, CertificadoDigital, "NFeAutorizacao4");
            webServiceNFe.Timeout = Timeout == 0 ? 60000 : Timeout;
            RetornoSefaz = webServiceNFe.NFeAutorizacao(xmlEnvLote);

            if (RetornoSefaz != null && webServiceNFe.GetErros.Length == 0)
            {
                XmlRetornoSefaz = webServiceNFe.XmlRetornoSefaz;

                //Status Recebimento OK
                if (RetornoSefaz.protNFe.infProt.cStat == 100)
                {
                    //Gera o Xml já Processado
                    GerarXmlProcessado();
                }
            }

            GetErros = webServiceNFe.GetErros;
        }

        private void GerarXmlProcessado()
        {
            try
            {
                protNFe nfeProt = RetornoSefaz.protNFe;
                nfeProt.infProt.Id = "ID" + nfeProt.infProt.nProt;
                XmlDocument xmlProtocolo = FunctionNFe.Serializar(nfeProt);

                XmlDocument xmlProcessado = new XmlDocument();
                xmlProcessado = FunctionNFe.GeraXmlNFeProc(ConfigServico.Versao, XmlDocAssinado, xmlProtocolo);
                XmlNFeProcessada = xmlProcessado;
            }

            catch (Exception ex)
            {
                GetErros = ex.Message;
            }
        }

    }

}
