﻿using System;
using System.Xml;
using NFeLib.NFE.BaseNF.Servicos.ConsultaCadastro;
using NFeLib.NFE.Utils;
using NFeLib.NFE.WebServices;

namespace NFeLib.NFE.Processos
{
    public class NFeConsultaCadastro : BaseEnvioSefaz<retConsCad>
    {
        private string _uf = string.Empty ;
        private string _numDoc = string.Empty;
        private TypeDoc _tipoDoc = TypeDoc.CNPJ;

        public NFeConsultaCadastro(string uf, string numDoc, TypeDoc tipoDoc) 
        {
            _uf  = uf;
            _numDoc = numDoc;
            _tipoDoc = tipoDoc;

            RetornoSefaz = null;
            GetErros = string.Empty;
        }

        public void EnviarSefaz()
        {
            try
            {
                infConsEnv consInf = new infConsEnv();
                consInf.xServ = "CONS-CAD";
                consInf.UF = _uf;
                if (_tipoDoc == TypeDoc.CNPJ) 
                {
                    consInf.CNPJ = _numDoc;
                }
                else if (_tipoDoc == TypeDoc.CPF)
                {
                    consInf.CPF = _numDoc;
                }
                else
                {
                    consInf.IE = _numDoc;
                }

                ConsCad consCad = new ConsCad()
                {
                    versao = ConfigServico.Versao,
                    infCons = consInf
                };
                XmlDocument xmlDoc = FunctionNFe.Serializar(consCad);

                IWebService webServiceNFe = new WebRequestWS(ConfigServico, CertificadoDigital, "CadConsultaCadastro4");
                webServiceNFe.Timeout = Timeout == 0 ? 60000 : Timeout; ;
                RetornoSefaz = webServiceNFe.NFeConsultaCadastro(xmlDoc);

                if (RetornoSefaz != null && webServiceNFe.GetErros.Length == 0)
                {
                    XmlRetornoSefaz = webServiceNFe.XmlRetornoSefaz;
                }

                GetErros = webServiceNFe.GetErros;
            }

            catch (Exception ex)
            {
                GetErros = ex.Message;
            }
        }
    }

}
