﻿using System;
using System.Collections.Generic;
using System.Xml;
using NFeLib.NFE.BaseNF.Servicos.DistribuicaoDFe;
using NFeLib.NFE.Utils;
using NFeLib.NFE.WebServices;
using NFeLib.Utils;

namespace NFeLib.NFE.Processos
{
    public class NFeDistribuicaoDFe : BaseEnvioSefaz<List<resConsDest>>
    {
        private string _ultimoNSUCons = "0";
        private string _cnpjEmpresa = string.Empty;
        private string _codUFEmpresa = string.Empty;

        public NFeDistribuicaoDFe(string ultimoNSUCons, string cnpjEmpresa, string codUFEmpresa) 
        {
            _ultimoNSUCons = ultimoNSUCons;
            _cnpjEmpresa = cnpjEmpresa;
            _codUFEmpresa = codUFEmpresa;
            GetErros = string.Empty;
        }

        public string UltimoNSURetSefaz { get; set; }

        /// <summary>
        /// RESUMO DO STATUS RETORNO WEBSERVICE
        /// 108 Serviço Paralisado Momentaneamente (curto prazo)
        /// 109 Serviço Paralisado sem Previsão
        /// 137 Nenhum documento localizado
        /// 138 Documento localizado
        /// 656 Rejeição: Consumo Indevido WebService,processar nova solicitação após 1 hora.
        /// </summary>
        public  void EnviarSefaz()
        {
            try
            {
                RetornoSefaz = new List<resConsDest>();
                retDistDFeInt retNFeDist = null;
                string statusWs = "138";
                string maxNSU = "0".PadLeftT(15, '0');
                UltimoNSURetSefaz = "0";

                distDFeInt consDest = new distDFeInt()
                {
                    versao = ConfigServico.Versao,
                    tpAmb = ConfigServico.TipoAmbiente,
                    cUFAutor = _codUFEmpresa,
                    CNPJ = _cnpjEmpresa,
                    distNSU = new distNSU
                    {
                        ultNSU = _ultimoNSUCons.PadLeftT(15)
                    }
                };
                XmlDocument xmlNodeConsNFeDest = FunctionNFe.Serializar(consDest);
                XmlNamespaceManager xmanager = new XmlNamespaceManager(xmlNodeConsNFeDest.NameTable);
                xmanager.AddNamespace("n", "http://www.portalfiscal.inf.br/nfe");

                int countBusca = 0;
                IWebService webService = new WebRequestWS(ConfigServico, CertificadoDigital, "NFeDistribuicaoDFe");
                webService.Timeout = Timeout == 0 ? 60000 : Timeout;
                while (statusWs == "138")
                {
                    ++countBusca;
                    retNFeDist = webService.NFeDistribuicaoDFe(xmlNodeConsNFeDest);
                    if (retNFeDist != null)
                    {
                        statusWs = retNFeDist.cStat;
                        if (statusWs != "656")
                        {
                            maxNSU = retNFeDist.maxNSU;
                        }

                        if (retNFeDist.cStat == "138")
                        {
                            this.UltimoNSURetSefaz = retNFeDist.ultNSU;
                            xmlNodeConsNFeDest.SelectSingleNode("n:distDFeInt/n:distNSU/n:ultNSU", xmanager).InnerText = this.UltimoNSURetSefaz.PadLeftT(15);
                            foreach (docZip zipText in retNFeDist.loteDistDFeInt.docZip)
                            {
                                XmlDocument xmlText = new XmlDocument();
                                xmlText.LoadXml(FunctionNFe.DecompressGZip(zipText.Value));
                                xmlText.DocumentElement.RemoveAllAttributes();

                                if (zipText.schema.Contains("resNFe"))
                                {
                                    resNFe resDoc = FunctionNFe.DeserializarNFe<resNFe>(xmlText.OuterXml);
                                    resDoc.NSU = zipText.NSU;
                                    resDoc.dEmi = resDoc.dhRecbto.ToString("dd/MM/yyyy").ToDateTime();
                                    resDoc.cSitConf = string.Empty;
                                    RetornoSefaz.Add(resDoc);
                                }
                                else if (zipText.schema.Contains("procNFe"))
                                {
                                    XmlNamespaceManager ns = new XmlNamespaceManager(xmlText.NameTable);
                                    ns.AddNamespace("n", "http://www.portalfiscal.inf.br/nfe");
                                    resNFe resDoc = new resNFe()
                                    {
                                        chNFe = xmlText.SelectSingleNode("n:nfeProc/n:protNFe/n:infProt/n:chNFe", ns).InnerText,
                                        CNPJ = xmlText.SelectSingleNode("n:nfeProc/n:NFe/n:infNFe/n:emit/n:CNPJ", ns).InnerText,
                                        cSitConf = string.Empty,
                                        cSitNFe = "1",
                                        dEmi = xmlText.SelectSingleNode("n:nfeProc/n:protNFe/n:infProt/n:dhRecbto", ns).InnerText.ToDateTime().ToString("dd/MM/yyyy").ToDateTime(),
                                        dhRecbto = xmlText.SelectSingleNode("n:nfeProc/n:protNFe/n:infProt/n:dhRecbto", ns).InnerText.ToDateTime(),
                                        digVal = xmlText.SelectSingleNode("n:nfeProc/n:protNFe/n:infProt/n:digVal", ns).InnerText,
                                        IE = xmlText.SelectSingleNode("n:nfeProc/n:NFe/n:infNFe/n:emit/n:IE", ns).InnerText ?? string.Empty,
                                        NSU = zipText.NSU,
                                        tpNF = xmlText.SelectSingleNode("n:nfeProc/n:NFe/n:infNFe/n:ide/n:tpNF", ns).InnerText,
                                        vNF = xmlText.SelectSingleNode("n:nfeProc/n:NFe/n:infNFe/n:total/n:ICMSTot/n:vNF", ns).InnerText.Replace(".", ",").ToDecimal(),
                                        xNome = xmlText.SelectSingleNode("n:nfeProc/n:NFe/n:infNFe/n:emit/n:xNome", ns).InnerText,
                                    };
                                    RetornoSefaz.Add(resDoc);
                                }
                            }
                        }

                        //656 Rejeição: Consumo Indevido WebService
                        if (statusWs == "656")
                        {
                            GetErros = retNFeDist.xMotivo;
                        }
                    }
                    // Se der erro de Conexão com o Webservice saí do Loop
                    else
                    {
                        statusWs = "0";
                    }
                }

                GetErros += webService.GetErros;
            }

            catch (Exception ex)
            {
                GetErros = ex.Message;
            }
            
        }

    }
}
