using System;
using System.Collections.Generic;
using System.Linq;
using System.Security.Cryptography.Xml;
using System.Xml;
using System.Security.Cryptography.X509Certificates;
using System.Windows.Forms;

namespace NFeLib.Utils
{

    public class CertificadoDigital
    {
        //_____________________________________________________________________________________________________________________________________________________________________________
        public bool ok { get; set; }
        public string mensagem { get; set; }
        public static bool ChecarValidadeCertificadoDigital;
        //_____________________________________________________________________________________________________________________________________________________________________________
        public CertificadoDigital()
        {
            ok = false;
            mensagem = string.Empty;
        }

        //_____________________________________________________________________________________________________________________________________________________________________________
        /// <summary>
        /// Função retirada do UNINFE - http://www.unimake.com.br/uninfe/
        /// Modificada por Giovanni - Try Ideas - www.tryideas.com.br para exemplo no Blog www.entendendo.net
        ///
        /// O método assina digitalmente o arquivo XML passado por parâmetro e
        /// grava o XML assinado com o mesmo nome, sobreponto o XML informado por parâmetro.
        /// Disponibiliza também uma propriedade com uma string do xml assinado (this.vXmlStringAssinado)
        /// </summary>
        /// <param name="docXML">Nome do arquivo XML a ser assinado</param>
        /// <param name="pUri">URI (TAG) a ser assinada</param>
        /// <param name="pCertificado">Certificado a ser utilizado na assinatura</param>
        /// <remarks>
        /// Podemos pegar como retorno do método as seguintes propriedades:
        ///
        /// - Atualiza a propriedade this.vXMLStringAssinado com a string de
        /// xml já assinada
        ///
        /// - Grava o XML sobreponto o informado para o método com o conteúdo
        /// já assinado
        ///
        /// - Atualiza as propriedades this.vResultado e
        /// this.vResultadoString com os seguintes valores:
        ///
        /// 0 - Assinatura realizada com sucesso
        /// 1 - Erro: Problema ao acessar o certificado digital - %exceção%
        /// 2 - Problemas no certificado digital
        /// 3 - XML mal formado + %exceção%
        /// 4 - A tag de assinatura %pUri% não existe
        /// 5 - A tag de assinatura %pUri% não é unica
        /// 6 - Erro ao assinar o documento - %exceção%
        /// 7 - Falha ao tentar abrir o arquivo XML - %exceção%
        /// </remarks>
        public XmlDocument Assinar(XmlDocument docXML, string pUri, X509Certificate2 pCertificado,
            out XmlElement AssinaturaDig)
        {
            XmlElement xmlDigitalSignature = null;

            // Load the certificate from the certificate store.
            X509Certificate2 cert = pCertificado;

            // Create a new XML document.
            XmlDocument doc = new XmlDocument();

            ok = true;
            try
            {
                // Format the document to ignore white spaces.
                doc.PreserveWhitespace = false;

                // Load the passed XML file using it's name.
                doc = docXML;

                // Create a SignedXml object.
                SignedXml signedXml = new SignedXml(doc);

                // Add the key to the SignedXml document.
                signedXml.SigningKey = cert.PrivateKey;

                // Create a reference to be signed.
                System.Security.Cryptography.Xml.Reference referencia = new System.Security.Cryptography.Xml.Reference();

                // pega o uri que deve ser assinada
                XmlAttributeCollection _Uri = doc.GetElementsByTagName(pUri).Item(0).Attributes;

                foreach (XmlAttribute _atributo in _Uri)
                {
                    if (_atributo.Name == "Id")
                    {
                        referencia.Uri = "#" + _atributo.InnerText;
                    }
                }

                // Add an enveloped transformation to the reference.
                XmlDsigEnvelopedSignatureTransform env = new XmlDsigEnvelopedSignatureTransform();
                referencia.AddTransform(env);

                XmlDsigC14NTransform c14 = new XmlDsigC14NTransform();
                referencia.AddTransform(c14);

                // Add the reference to the SignedXml object.
                signedXml.AddReference(referencia);

                // Create a new KeyInfo object.
                System.Security.Cryptography.Xml.KeyInfo keyInfo = new System.Security.Cryptography.Xml.KeyInfo();

                // Load the certificate into a KeyInfoX509Data object
                // and add it to the KeyInfo object.
                keyInfo.AddClause(new KeyInfoX509Data(cert));

                // Add the KeyInfo object to the SignedXml object.
                signedXml.KeyInfo = keyInfo;

                // Compute the signature.
                signedXml.ComputeSignature();

                // Get the XML representation of the signature and save
                // it to an XmlElement object.
                xmlDigitalSignature = signedXml.GetXml();

                // Append the element to the XML document.
                doc.DocumentElement.AppendChild(doc.ImportNode(xmlDigitalSignature, true));

                if (doc.FirstChild is XmlDeclaration)
                {
                    doc.RemoveChild(doc.FirstChild);
                }
                mensagem = "Certificado Digital adicionado com sucesso.";
            }
            catch (Exception ex)
            {
                //Throw New Exception("Erro ao efetuar assinatura digital, detalhes: " & ex.Message)
                mensagem += "Falha detectada ao efetuar assinatura digital, detalhes: " + ex.Message;
                ok = false;
            }

            AssinaturaDig = xmlDigitalSignature;
            return doc;
        }

        //_____________________________________________________________________________________________________________________________________________________________________________
        //BUSCA CERTIFICADOS INSTALADOS SE INFORMADO UMA SERIE BUSCA A MESMA
        //SE NÃO ABRE CAIXA DE DIALOGOS DE CERTIFICADO
        public X509Certificate2 SelecionarCertificado(string CerSerie)
        {
            X509Certificate2 certificate = new X509Certificate2();
            ok = true;
            try
            {
                X509Certificate2Collection certificatesSel = null;
                X509Store store = new X509Store("MY", StoreLocation.CurrentUser);
                store.Open(OpenFlags.OpenExistingOnly);
                X509Certificate2Collection certificates =
                    store.Certificates.Find(X509FindType.FindByTimeValid, DateTime.Now, true)
                        .Find(X509FindType.FindByKeyUsage, X509KeyUsageFlags.DigitalSignature, true);
                if ((string.IsNullOrEmpty(CerSerie)))
                {
                    certificatesSel = X509Certificate2UI.SelectFromCollection(certificates, "Certificados Digitais",
                        "Selecione o Certificado Digital para uso no aplicativo", X509SelectionFlag.SingleSelection);
                    if ((certificatesSel.Count == 0))
                    {
                        certificate.Reset();
                        //Throw New Exception("Nenhum certificado digital foi selecionado ou o certificado selecionado está com problemas.")
                        mensagem +=
                            "Nenhum certificado digital foi selecionado ou o certificado selecionado está com problemas.";
                        ok = false;
                    }
                    else
                    {
                        certificate = certificatesSel[0];
                    }
                }
                else
                {
                    certificatesSel = certificates.Find(X509FindType.FindBySerialNumber, CerSerie, true);
                    if ((certificatesSel.Count == 0))
                    {
                        certificate.Reset();
                        //Throw New Exception("Certificado digital não encontrado")
                        mensagem += "Certificado digital não encontrado";
                        ok = false;
                    }
                    else
                    {
                        certificate = certificatesSel[0];
                    }
                }
                store.Close();
            }
            catch (Exception)
            {
                //Throw New Exception(exception.Message)
                mensagem += "Falha detectada ao verificar o certificado";
                ok = false;
            }

            return certificate;
        }

        //_____________________________________________________________________________________________________________________________________________________________________________
        public static X509Certificate2 BuscaCertificado(out string msg, string serieCertificado)
        {
            try
            {
                CertificadoDigital certDigInstalado = new CertificadoDigital();
                X509Certificate2 certDig = certDigInstalado.SelecionarCertificado(serieCertificado);
                if (!certDigInstalado.ok)
                {
                    msg = "Certificado Digital configurado no Sistema não encontrado!!!";
                    return null;
                }
                else if (certDig.GetExpirationDateString().ToDateTime() <= DateTime.Now)
                {
                    msg = "Certificado Digital expirado!!! Data Certificado " +
                          certDig.GetEffectiveDateString().ToDateTime().ToString("dd/MM/yyyy") +
                          " validade " + certDig.GetExpirationDateString().ToDateTime().ToString("dd/MM/yyyy");
                    return null;
                }
                else
                {
                    msg = string.Empty;
                    return certDig;
                }
            }

            catch (Exception)
            {
                msg = string.Empty;
                return null;
            }
        }

        //_____________________________________________________________________________________________________________________________________________________________________________
        public static X509Certificate2 BuscaCertificado(string serieCertificado)
        {
            try
            {
                CertificadoDigital certDigInstalado = new CertificadoDigital();
                X509Certificate2 certDig = ListaCertificado().OfType<X509Certificate2>().ToList().Find(l =>
                    l.SerialNumber == serieCertificado);
                return certDig;
            }

            catch (Exception)
            {
                return null;
            }
        }

        //_____________________________________________________________________________________________________________________________________________________________________________
        /// CARREGA OS CERTIFICADOS INSTALADOS        
        public static List<X509Certificate2> ListaCertificado()
        {
            X509Store store = new X509Store();
            store.Open(OpenFlags.OpenExistingOnly);
            X509Certificate2Collection certificates = store.Certificates;

            List<X509Certificate2> lstCertDig = (from X509Certificate2 certificate in certificates
                                                 let dataVenc = certificate.GetExpirationDateString()
                                                 where Convert.ToDateTime(dataVenc) > DateTime.Now
                                                 select certificate).ToList();



            return lstCertDig;
        }

        public static void ValidarValidadeCertificadoDigital(X509Certificate2 certificadoDigital, int diasMensagemExpirar = 15)
        {
            if (ChecarValidadeCertificadoDigital) return;

            string mensagem = "";
            DateTime dataExpirar = certificadoDigital.GetExpirationDateString().ToDateTime();

            if (dataExpirar <= DateTime.Now)
            {
                mensagem = "Certificado digital expirado em " + dataExpirar.ToString("dd/MM/yyyy");
                MessageBox.Show(mensagem, "Atenção", MessageBoxButtons.OK, MessageBoxIcon.Warning);
                return;
            }

            int quantidadeDiasExpirar = (dataExpirar - DateTime.Now).Days;
            if (quantidadeDiasExpirar <= diasMensagemExpirar)
            {
                ChecarValidadeCertificadoDigital = true;
                mensagem = "Faltam " + quantidadeDiasExpirar + " dia(s) para seu Certificado Digital expirar!";
                MessageBox.Show(mensagem, "Atenção", MessageBoxButtons.OK, MessageBoxIcon.Warning);

            }
        }


    }
}
