﻿using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using NFeLib.NFE.BaseNF.Informacoes.Identificacao;
using NFeLib.NFE.WebServices;

namespace NFeLib.NFE.Utils
{
    public class EnderecoConsultaPublicaNfce
    {
        public TipoAmbiente TipoAmbiente { get; protected set; }
        public Estado Estado { get; protected set; }
        public TipoUrlConsultaPublica TipoUrlConsultaPublica { get; protected set; }
        public string Url { get; protected set; }

        private readonly List<EnderecoConsultaPublicaNfce> _endQrCodeNfce;

        public EnderecoConsultaPublicaNfce()
        {
            _endQrCodeNfce = CarregarUrls();
        }

        public EnderecoConsultaPublicaNfce(Estado estado, TipoAmbiente tipoAmbiente, TipoUrlConsultaPublica tipoUrlConsultaPublica, string url)
        {
            TipoAmbiente = tipoAmbiente;
            Estado = estado;
            TipoUrlConsultaPublica = tipoUrlConsultaPublica;
            Url = url;
        }


        public string ObterUrl(TipoAmbiente tipoAmbiente, Estado estado, TipoUrlConsultaPublica tipoUrlConsultaPublica)
        {
            return _endQrCodeNfce.FirstOrDefault(qr =>
                qr.TipoAmbiente == tipoAmbiente && qr.Estado == estado &&
                qr.TipoUrlConsultaPublica == tipoUrlConsultaPublica).Url;

        }

        private static List<EnderecoConsultaPublicaNfce> CarregarUrls()
        {
            var endQrCodeNfce = new List<EnderecoConsultaPublicaNfce>
            {
                new EnderecoConsultaPublicaNfce(Estado.AC, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://hml.sefaznet.ac.gov.br/nfce/qrcode"),
                new EnderecoConsultaPublicaNfce(Estado.AC, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://www.sefaznet.ac.gov.br/nfce/"),
                new EnderecoConsultaPublicaNfce(Estado.AC, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://hml.sefaznet.ac.gov.br/nfce/qrcode"),
                new EnderecoConsultaPublicaNfce(Estado.AC, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://hml.sefaznet.ac.gov.br/nfce/"),

                new EnderecoConsultaPublicaNfce(Estado.AL, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://nfce.sefaz.al.gov.br/QRCode/consultarNFCe.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.AL, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://nfce.sefaz.al.gov.br/consultaNFCe.htm"),
                new EnderecoConsultaPublicaNfce(Estado.AL, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://nfce.sefaz.al.gov.br/QRCode/consultarNFCe.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.AL, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://nfce.sefaz.al.gov.br/consultaNFCe.htm"),

                new EnderecoConsultaPublicaNfce(Estado.AM, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://sistemas.sefaz.am.gov.br/nfceweb/consultarNFCe.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.AM, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://sistemas.sefaz.am.gov.br/nfceweb/formConsulta.do"),
                new EnderecoConsultaPublicaNfce(Estado.AM, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://homnfce.sefaz.am.gov.br/nfceweb/consultarNFCe.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.AM, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://homnfce.sefaz.am.gov.br/nfceweb/formConsulta.do"),

                new EnderecoConsultaPublicaNfce(Estado.AP, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "https://www.sefaz.ap.gov.br/nfce/nfcep.php"),
                new EnderecoConsultaPublicaNfce(Estado.AP, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "https://www.sefaz.ap.gov.br/sate/seg/SEGf_AcessarFuncao.jsp?cdFuncao=FIS_1261"),
                new EnderecoConsultaPublicaNfce(Estado.AP, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "https://www.sefaz.ap.gov.br/nfcehml/nfce.php"),
                new EnderecoConsultaPublicaNfce(Estado.AP, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "https://www.sefaz.ap.gov.br/sate1/seg/SEGf_AcessarFuncao.jsp?cdFuncao=FIS_1261"),

                new EnderecoConsultaPublicaNfce(Estado.BA, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://nfe.sefaz.ba.gov.br/servicos/nfce/modulos/geral/NFCEC_consulta_chave_acesso.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.BA, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://nfe.sefaz.ba.gov.br/servicos/nfce/default.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.BA, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://hnfe.sefaz.ba.gov.br/servicos/nfce/modulos/geral/NFCEC_consulta_chave_acesso.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.BA, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://nfe.sefaz.ba.gov.br/servicos/nfce/default.aspx"),

                new EnderecoConsultaPublicaNfce(Estado.DF, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://dec.fazenda.df.gov.br/ConsultarNFCe.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.DF, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://dec.fazenda.df.gov.br/nfce"),
                new EnderecoConsultaPublicaNfce(Estado.DF, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://dec.fazenda.df.gov.br/ConsultarNFCe.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.DF, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://dec.fazenda.df.gov.br/nfce"),

                new EnderecoConsultaPublicaNfce(Estado.GO, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://nfe.sefaz.go.gov.br/nfeweb/sites/nfce/danfeNFCe"),
                new EnderecoConsultaPublicaNfce(Estado.GO, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://www.nfce.go.gov.br/post/ver/214344/consulta-nfce"),
                new EnderecoConsultaPublicaNfce(Estado.GO, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://homolog.sefaz.go.gov.br/nfeweb/sites/nfce/danfeNFCe"),
                new EnderecoConsultaPublicaNfce(Estado.GO, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://www.nfce.go.gov.br/post/ver/214413/consulta-nfc-e-homologacao"),

                new EnderecoConsultaPublicaNfce(Estado.ES, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://app.sefaz.es.gov.br/ConsultaNFCe/qrcode.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.ES, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://app.sefaz.es.gov.br/ConsultaNFCe"),
                new EnderecoConsultaPublicaNfce(Estado.ES, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://homologacao.sefaz.es.gov.br/ConsultaNFCe/qrcode.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.ES, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://homologacao.sefaz.es.gov.br/ConsultaNFCe"),

                new EnderecoConsultaPublicaNfce(Estado.MA, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://www.nfce.sefaz.ma.gov.br/portal/consultarNFCe.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.MA, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://www.nfce.sefaz.ma.gov.br/portal/consultaNFe.do"),
                new EnderecoConsultaPublicaNfce(Estado.MA, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://www.hom.nfce.sefaz.ma.gov.br/portal/consultarNFCe.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.MA, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://www.hom.nfce.sefaz.ma.gov.br/portal/consultaNFe.do"),

                new EnderecoConsultaPublicaNfce(Estado.MS, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://www.dfe.ms.gov.br/nfce/qrcode"),
                new EnderecoConsultaPublicaNfce(Estado.MS, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://www.dfe.ms.gov.br/nfce/chavedeacesso"),
                new EnderecoConsultaPublicaNfce(Estado.MS, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://www.dfe.ms.gov.br/nfce/qrcode"),
                new EnderecoConsultaPublicaNfce(Estado.MS, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://www.dfe.ms.gov.br/nfce/chavedeacesso"),

                new EnderecoConsultaPublicaNfce(Estado.MT, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://www.sefaz.mt.gov.br/nfce/consultanfce"),
                new EnderecoConsultaPublicaNfce(Estado.MT, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://www.sefaz.mt.gov.br/nfce/consultanfce"),
                new EnderecoConsultaPublicaNfce(Estado.MT, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://homologacao.sefaz.mt.gov.br/nfce/consultanfce"),
                new EnderecoConsultaPublicaNfce(Estado.MT, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://homologacao.sefaz.mt.gov.br/nfce/consultanfce"),

                new EnderecoConsultaPublicaNfce(Estado.PA, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "https://appnfc.sefa.pa.gov.br/portal-homologacao/view/consultas/nfce/nfceForm.seam"),
                new EnderecoConsultaPublicaNfce(Estado.PA, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "https://appnfc.sefa.pa.gov.br/portal/view/consultas/nfce/consultanfce.seam"),
                new EnderecoConsultaPublicaNfce(Estado.PA, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "https://appnfc.sefa.pa.gov.br/portal-homologacao/view/consultas/nfce/nfceForm.seam"),
                new EnderecoConsultaPublicaNfce(Estado.PA, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "https://appnfc.sefa.pa.gov.br/portal-homologacao/view/consultas/nfce/consultanfce.seam"),

                new EnderecoConsultaPublicaNfce(Estado.PB, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "https://www5.receita.pb.gov.br/atf/seg/SEGf_AcessarFuncao.jsp?cdFuncao=FIS_1410"),
                new EnderecoConsultaPublicaNfce(Estado.PB, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "https://www5.receita.pb.gov.br/atf/seg/SEGf_AcessarFuncao.jsp?cdFuncao=FIS_1410"),
                new EnderecoConsultaPublicaNfce(Estado.PB, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "https://www6.receita.pb.gov.br/atf/seg/SEGf_AcessarFuncao.jsp?cdFuncao=FIS_1410"),
                new EnderecoConsultaPublicaNfce(Estado.PB, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "https://www6.receita.pb.gov.br/atf/seg/SEGf_AcessarFuncao.jsp?cdFuncao=FIS_1410"),

                new EnderecoConsultaPublicaNfce(Estado.PE, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://nfce.sefaz.pe.gov.br/nfce-web/consultarNFCe"),
                new EnderecoConsultaPublicaNfce(Estado.PE, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://nfce.sefaz.pe.gov.br/nfce-web/entradaConsNfce"),
                new EnderecoConsultaPublicaNfce(Estado.PE, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://nfcehomolog.sefaz.pe.gov.br/nfce-web/consultarNFCe"),
                new EnderecoConsultaPublicaNfce(Estado.PE, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://nfcehomolog.sefaz.pe.gov.br/nfce-web/entradaConsNfce"),

                new EnderecoConsultaPublicaNfce(Estado.PI, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://webas.sefaz.pi.gov.br/nfceweb/consultarNFCe.jsf"),
                new EnderecoConsultaPublicaNfce(Estado.PI, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://webas.sefaz.pi.gov.br/nfceweb/consultarNFCe.jsf"),
                new EnderecoConsultaPublicaNfce(Estado.PI, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://webas.sefaz.pi.gov.br/nfceweb-homologacao/consultarNFCe.jsf"),
                new EnderecoConsultaPublicaNfce(Estado.PI, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://webas.sefaz.pi.gov.br/nfceweb-homologacao/consultarNFCe.jsf"),

                new EnderecoConsultaPublicaNfce(Estado.PR, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://www.dfeportal.fazenda.pr.gov.br/dfe-portal/rest/servico/consultaNFCe"),
                new EnderecoConsultaPublicaNfce(Estado.PR, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://www.fazenda.pr.gov.br/"),
                new EnderecoConsultaPublicaNfce(Estado.PR, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://www.dfeportal.fazenda.pr.gov.br/dfe-portal/rest/servico/consultaNFCe"),
                new EnderecoConsultaPublicaNfce(Estado.PR, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://www.fazenda.pr.gov.br/"),

                new EnderecoConsultaPublicaNfce(Estado.RJ, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://www4.fazenda.rj.gov.br/consultaNFCe/QRCode"),
                new EnderecoConsultaPublicaNfce(Estado.RJ, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://nfce.fazenda.rj.gov.br/consulta"),
                new EnderecoConsultaPublicaNfce(Estado.RJ, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://www4.fazenda.rj.gov.br/consultaNFCe/QRCode"),
                new EnderecoConsultaPublicaNfce(Estado.RJ, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://nfce.fazenda.rj.gov.br/consulta"),

                new EnderecoConsultaPublicaNfce(Estado.RN, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://nfce.set.rn.gov.br/consultarNFCe.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.RN, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://nfce.set.rn.gov.br/portalDFE/NFCe/ConsultaNFCe.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.RN, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://hom.nfce.set.rn.gov.br/consultarNFCe.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.RN, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://nfce.set.rn.gov.br/portalDFE/NFCe/ConsultaNFCe.aspx"),

                new EnderecoConsultaPublicaNfce(Estado.RO, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://www.nfce.sefin.ro.gov.br/consultanfce/consulta.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.RO, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://www.nfce.sefin.ro.gov.br"),
                new EnderecoConsultaPublicaNfce(Estado.RO, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://www.nfce.sefin.ro.gov.br/consultanfce/consulta.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.RO, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://www.nfce.sefin.ro.gov.br/consultaAmbHomologacao.jsp"),

                new EnderecoConsultaPublicaNfce(Estado.RR, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "https://www.sefaz.rr.gov.br/nfce/servlet/qrcode"),
                new EnderecoConsultaPublicaNfce(Estado.RR, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "https://www.sefaz.rr.gov.br/nfce/servlet/wp_consulta_nfce"),
                new EnderecoConsultaPublicaNfce(Estado.RR, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://200.174.88.103:8080/nfce/servlet/qrcode"),
                new EnderecoConsultaPublicaNfce(Estado.RR, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://200.174.88.103:8080/nfce/servlet/wp_consulta_nfce"),

                new EnderecoConsultaPublicaNfce(Estado.RS, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "https://www.sefaz.rs.gov.br/NFCE/NFCE-COM.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.RS, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "https://www.sefaz.rs.gov.br/NFE/NFE-NFC.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.RS, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "https://www.sefaz.rs.gov.br/NFCE/NFCE-COM.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.RS, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "https://www.sefaz.rs.gov.br/NFE/NFE-NFC.aspx"),

                new EnderecoConsultaPublicaNfce(Estado.SE, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "http://www.nfce.se.gov.br/portal/consultarNFCe.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.SE, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "http://www.nfce.se.gov.br/portal"),
                new EnderecoConsultaPublicaNfce(Estado.SE, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "http://www.hom.nfe.se.gov.br/portal/consultarNFCe.jsp"),
                new EnderecoConsultaPublicaNfce(Estado.SE, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "http://www.hom.nfe.se.gov.br/portal"),

                new EnderecoConsultaPublicaNfce(Estado.SP, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlQrCode, "https://www.nfce.fazenda.sp.gov.br/NFCeConsultaPublica/Paginas/ConsultaQRCode.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.SP, TipoAmbiente.Producao, TipoUrlConsultaPublica.UrlConsulta, "https://www.nfce.fazenda.sp.gov.br/NFCeConsultaPublica/Paginas/ConsultaPublica.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.SP, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlQrCode, "https://www.homologacao.nfce.fazenda.sp.gov.br/NFCeConsultaPublica/Paginas/ConsultaQRCode.aspx"),
                new EnderecoConsultaPublicaNfce(Estado.SP, TipoAmbiente.Homologacao, TipoUrlConsultaPublica.UrlConsulta, "https://www.homologacao.nfce.fazenda.sp.gov.br/NFCeConsultaPublica/Paginas/ConsultaPublica.aspx"),

            };

            return endQrCodeNfce;
        }

    }


    public enum TipoUrlConsultaPublica
    {
        [Description("Endereço para consulta da NFCe através do site")]
        UrlConsulta,

        [Description("Endereço para consulta da NFCe através do QR-Code")]
        UrlQrCode
    }
}
