﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Data;
using System.IO;
using System.Globalization;
using System.Windows.Forms;
using System.Reflection;
using System.Runtime.Serialization.Formatters.Binary;
using System.Text.RegularExpressions;

namespace NFeLib.Utils
{
    public static class Extension
    {
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string LimparTexto(this string strTexto)
        {
            strTexto = Regex.Replace(strTexto, "[ÁÀÂÃ]", "A");
            strTexto = Regex.Replace(strTexto, "[ÉÈÊ]", "E");
            strTexto = Regex.Replace(strTexto, "[Í]", "I");
            strTexto = Regex.Replace(strTexto, "[ÓÒÔÕ]", "O");
            strTexto = Regex.Replace(strTexto, "[ÚÙÛÜ]", "U");
            strTexto = Regex.Replace(strTexto, "[Ç]", "C");
            strTexto = Regex.Replace(strTexto, "[áàâã]", "a");
            strTexto = Regex.Replace(strTexto, "[éèê]", "e");
            strTexto = Regex.Replace(strTexto, "[í]", "i");
            strTexto = Regex.Replace(strTexto, "[óòôõ]", "o");
            strTexto = Regex.Replace(strTexto, "[úùûü]", "u");
            strTexto = Regex.Replace(strTexto, "[ç]", "c");
            strTexto = Regex.Replace(strTexto, "[ª]", "");
            strTexto = Regex.Replace(strTexto, "[º]", "");
            return Regex.Replace(strTexto, @"[,%'*]", "");

        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static int ToInt16(this string value)
        {
            int resultado = 0;
            int.TryParse(value, out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static double ToObjectDouble(this object value)
        {
            double resultado = 0;
            Double.TryParse(value.ToString(), out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static Int32 ToObjectInt32(this object value)
        {
            Int32 resultado = 0;
            Int32.TryParse(value.ToString(), out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static Int64 ToObjectInt64(this object value)
        {
            Int64 resultado = 0;
            Int64.TryParse(value.ToString(), out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static Int32 ToInt32(this string value)
        {
            Int32 resultado = 0;
            Int32.TryParse(value, out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static Int64 ToInt64(this string value)
        {
            Int64 resultado = 0;
            Int64.TryParse(value, out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static decimal ToDecimal(this string value)
        {
            decimal resultado = 0;
            decimal.TryParse(value, out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static bool ToBool(this string value)
        {
            bool resultado = false;
            bool.TryParse(value, out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static DateTime ToDate(this DateTime value)
        {
            return value.ToString("dd/MM/yyyy").ToDateTime();
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static DateTime ToDateTime(this string value)
        {
            DateTime resultado;
            DateTime.TryParse(value, out resultado);
            return resultado;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static bool IsBetween<T>(this T item, T start, T end) where T : IComparable
        {
            return item.CompareTo(start) >= 0 && item.CompareTo(end) <= 0;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static bool IsDate(this string value)
        {
            DateTime resultado = DateTime.MinValue;
            if (DateTime.TryParse(value.Trim(), out resultado))
            {
                return true;
            }
            else
            {
                return false;
            }
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static DateTime UltimoDiaMes(this DateTime value)
        {
            return new DateTime(
                value.Year,
                value.Month,
                DateTime.DaysInMonth(value.Year, value.Month));
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static bool IsNumeric(this string value)
        {
            double Dummy = new double();
            string inputValue = Convert.ToString(value);
            return double.TryParse(inputValue, System.Globalization.NumberStyles.Any, null, out Dummy);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string ValuesNumeric(this string value)
        {
            string retorno = string.Empty;
            foreach (char c in value)
            {
                if (Char.IsNumber(c) == true)
                {
                    retorno += c;
                }
            }
            return retorno;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string Left(this string value, int length)
        {
            if (value.Length < length)
            {
                return value;
            }
            else
            {
                string result = value.Substring(0, length);
                return result;
            }
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string Right(this string value, int length)
        {
            return value.Substring(value.Length - length, length);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static decimal RoundDecimalLow(this decimal value)
        {
            return Math.Truncate(value * 100) / 100;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static Int32 RoundDecimalToIntHigh(this decimal value)
        {
            return (Int32)Math.Ceiling(value);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static Int32 RoundDecimalToIntLow(this decimal value)
        {
            return (Int32)Math.Floor(value);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static decimal RoundDecimal(this decimal value, int tamanho = 2)
        {
            return Math.Round(value, tamanho);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string ChaveNfe(this string chave)
        {
            int soma = 0;
            int resto = 0;
            int[] peso = { 4, 3, 2, 9, 8, 7, 6, 5 };
            long digito = 0;

            for (int i = 0; i < chave.Length; i++)
            {
                soma += peso[i % 8] * (int.Parse(chave.Substring(i, 1)));
            }

            resto = soma % 11;
            if (resto == 0 || resto == 1)
            {
                digito = 0;
            }
            else
            {
                digito = 11 - resto;
            }

            return chave + digito.ToString();
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static bool ValidadeCnpj(this string value)
        {
            int[] multiplicador1 = new int[12] { 5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2 };

            int[] multiplicador2 = new int[13] { 6, 5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2 };

            int soma;

            int resto;

            string digito;

            string tempCnpj;

            value = value.Trim();

            value = value.Replace(".", "").Replace("-", "").Replace("/", "");

            if (value.Length != 14)

                return false;

            tempCnpj = value.Substring(0, 12);

            soma = 0;

            for (int i = 0; i < 12; i++)

                soma += int.Parse(tempCnpj[i].ToString()) * multiplicador1[i];

            resto = (soma % 11);

            if (resto < 2)

                resto = 0;

            else

                resto = 11 - resto;

            digito = resto.ToString();

            tempCnpj = tempCnpj + digito;

            soma = 0;

            for (int i = 0; i < 13; i++)

                soma += int.Parse(tempCnpj[i].ToString()) * multiplicador2[i];

            resto = (soma % 11);

            if (resto < 2)

                resto = 0;

            else

                resto = 11 - resto;

            digito = digito + resto;

            return value.EndsWith(digito);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static bool ValidadeCpf(this string value)
        {
            // Pré-Verificação do Tamanho da String (Apenas para Performance)
            if (value.Length != 11)
            {
                return false;
            }
            // Cria Objetos
            string clearCPF;
            int[] cpfArray;
            int totalDigitoI = 0;
            int totalDigitoII = 0;
            int modI;
            int modII;
            // Limpa o CPF
            clearCPF = value.Trim(); // Elimina Espaços em Branco
            clearCPF = clearCPF.Replace("-", ""); // Remove Separador de Dígito Verificador
            clearCPF = clearCPF.Replace(".", ""); // Remove os Separadores das Casas
            // Verifica o Tamanho do Texto de Input
            if (clearCPF.Length != 11)
            {
                return false;
            }
            // Verifica os Patterns mais Comuns para CPF's Inválidos
            if (clearCPF.Equals("00000000000") ||
                clearCPF.Equals("11111111111") ||
                clearCPF.Equals("22222222222") ||
                clearCPF.Equals("33333333333") ||
                clearCPF.Equals("44444444444") ||
                clearCPF.Equals("55555555555") ||
                clearCPF.Equals("66666666666") ||
                clearCPF.Equals("77777777777") ||
                clearCPF.Equals("88888888888") ||
                clearCPF.Equals("99999999999"))
            {
                return false;
            }
            // Verifica se no Array Existe Apenas Números
            foreach (char c in clearCPF)
            {
                if (!char.IsNumber(c))
                {
                    return false;
                }
            }
            // Converte o CPF em Array Numérico para Validar
            cpfArray = new int[11];
            for (int i = 0; i < clearCPF.Length; i++)
            {
                cpfArray[i] = int.Parse(clearCPF[i].ToString());
            }
            // Computa os Totais para os 2 Dígitos Verificadores
            for (int position = 0; position < cpfArray.Length - 2; position++)
            {
                totalDigitoI += cpfArray[position] * (10 - position);
                totalDigitoII += cpfArray[position] * (11 - position);
            }
            // Aplica Regras do Dígito 1
            modI = totalDigitoI % 11;
            if (modI < 2) { modI = 0; }
            else { modI = 11 - modI; }
            // Verifica o Digito 1
            if (cpfArray[9] != modI)
            {
                return false;
            }
            // Aplica o Peso para o Digito Verificador 2
            totalDigitoII += modI * 2;
            // Aplica Regras do Dígito Verificador 2
            modII = totalDigitoII % 11;
            if (modII < 2) { modII = 0; }
            else { modII = 11 - modII; }
            // Verifica o Digito 2
            if (cpfArray[10] != modII)
            {
                return false;
            }
            // CPF Válido!
            return true;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static bool ValidadeCodeEan(this string value)
        {
            {
                //empezamos suponiendo que el codigo no
                //es correcto
                bool resultado = false;
                //Sólo comprobabos si la cadena está formada por
                //dígitos y su longitud es 8 o 13
                if (IsNumeric(value) && (value.Length == 8 || value.Length == 13))
                {
                    //Sumaremos los lugares pares por un lado y los
                    //impares por otro
                    int pares = 0;
                    int impares = 0;
                    //Recorrer toda la cadena excluyendo el último lugar
                    for (int i = 0; i <= (value.Length - 2); i++)
                    {
                        if (i % 2 == 0) //Si lugar impar (empezamos por 0)
                            impares += int.Parse(value.Substring(i, 1));
                        else
                            pares += int.Parse(value.Substring(i, 1));
                    }
                    //En EAN13, los pares se multiplican por 3
                    //En EAN8, son los impares
                    if (value.Length == 13)
                        pares *= 3;
                    else
                        impares *= 3;
                    int checksum = pares + impares;
                    int digitoControl = 10 - (checksum % 10);
                    //Si el digito de control es 10, entendemos 0
                    if (digitoControl == 10)
                        digitoControl = 0;
                    //Comprobar que el digito de control obtenido y el
                    //de la cadena ean sean el mismo.
                    resultado = (digitoControl ==
                                int.Parse(value.Substring(value.Length - 1, 1)));
                } //fin if
                return resultado;
            }
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        private static string DigitValidadorEan13(this string value)
        {
            int[] vSequen = new int[] { 1, 3, 1, 3, 1, 3, 1, 3, 1, 3, 1, 3 };
            int[] vResult = new int[] { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
            int iDigito = 0;
            int iSoma = 0;
            int iMultiplo = 0;

            for (int i = 0; i < value.Length; i++)
            {
                vResult[i] = vSequen[i] * (Convert.ToInt16(value[i]) - 48);
            }

            iSoma = vResult.Sum();
            if (iSoma % 10 != 0 && iSoma > 10)
            {
                iMultiplo = ((iSoma / 10) + 1);
            }
            else
            {
                if (iSoma < 10)
                {
                    iMultiplo = 1;
                }
                else
                {
                    iMultiplo = iSoma / 10;
                }
            }

            iDigito = (iMultiplo * 10) - iSoma;
            return iDigito.ToString();
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static int DigitoModule11(this Int32 value)
        {
            int[] intPesos = { 2, 3, 4, 5, 6, 7, 8, 9, 2, 3, 4, 5, 6, 7, 8, 9 };
            string strText = value.ToString();

            if (strText.Length > 16)
            {
                throw new Exception("Número não suportado pela função!");
            }

            int intSoma = 0;
            int intIdx = 0;
            for (int intPos = strText.Length - 1; intPos >= 0; intPos--)
            {
                intSoma += Convert.ToInt32(strText[intPos].ToString()) * intPesos[intIdx];
                intIdx++;
            }

            int intResto = (intSoma * 10) % 11;
            int intDigito = intResto;
            if (intDigito >= 10)
            {
                intDigito = 0;
            }

            return intDigito;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string DigitoModulo11(this string value)
        {
            int[] intPesos = { 2, 3, 4, 5, 6, 7, 8, 9 };
            string strText = value.ToString();

            int intSoma = 0;
            int intIdx = 0;
            for (int intPos = strText.Length - 1; intPos >= 0; intPos--)
            {
                intSoma += Convert.ToInt32(strText[intPos].ToString()) * intPesos[intIdx];
                intIdx++;
            }

            int intResto = (intSoma * 10) % 11;
            int intDigito = intResto;
            if (intDigito >= 10)
            {
                intDigito = 0;
            }

            return intDigito.ToString();
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static int DigitoModule10(this string strText)
        {
            int i = 2;
            int sum = 0;

            foreach (char c in strText.ToCharArray())
            {
                int res = Convert.ToInt32(c.ToString()) * i;
                sum += res > 9 ? (res - 9) : res;
                i = i == 2 ? 1 : 2;
            }
            return 10 - (sum % 10);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static int Modulo10(this string valor)
        {

            if (valor.Length == 0)
                return -1;

            int ret = 0;
            int Soma = 0;
            int Total = 0;
            int Contador = 0;
            int Peso = 0;
            int Digito = 0;

            Peso = 2;
            Soma = 0;
            Contador = valor.Length;

            while ((Contador >= 1))
            {
                Soma = int.Parse(valor.Substring(Contador - 1, 1)) * Peso;
                if ((Soma <= 9))
                {
                    Total += Soma;
                }
                else
                {
                    Total += int.Parse(Soma.ToString()) + int.Parse(Soma.ToString());
                }

                Peso = (Peso == 2 ? 1 : 2);
                Contador -= 1;
            }

            Digito = 10 - (Total % 10);
            if (Digito > 9)
                Digito = 0;
            ret = Digito;

            return ret;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string CalculoDV10(this string strNumero)
        {
            string functionReturnValue = null;
            //declara As variáveis
            int intContador = 0;

            int intNumero = 0;

            int intTotalNumero = 0;

            int intMultiplicador = 0;

            int intResto = 0;

            // se nao for um valor numerico sai da função
            if (strNumero.IsNumeric() == false)
            {
                functionReturnValue = string.Empty;
                return functionReturnValue;
            }

            //inicia o multiplicador
            intMultiplicador = 2;

            //pega cada caracter do numero a partir da direita

            for (intContador = strNumero.Length - 1; intContador >= 1; intContador += -1)
            {
                //extrai o caracter e multiplica pelo multiplicador
                intNumero = strNumero.Substring(intContador, 1).ToInt32() * intMultiplicador;

                // se o resultado for maior que nove soma os algarismos do resultado
                if (intNumero > 9)
                {
                    intNumero = intNumero.ToString().Left(1).ToInt32() + intNumero.ToString().Right(1).ToInt32();
                }

                //soma o resultado para totalização
                intTotalNumero = intTotalNumero + intNumero;

                //se o multiplicador for igual a 2 atribuir valor 1 se for 1 atribui 2
                intMultiplicador = (intMultiplicador == 2 ? 1 : 2);

            }

            int DezenaSuperior = 0;
            if (intTotalNumero < 10)
            {
                DezenaSuperior = 10;
            }
            else
            {
                DezenaSuperior = 10 * (intTotalNumero.ToString().Left(1).ToInt32() + 1);
            }
            intResto = DezenaSuperior - intTotalNumero;

            //verifica as exceções ( 0 -> DV=0 )
            switch (intResto)
            {
                case 0:
                    functionReturnValue = "0";
                    break;
                default:
                    functionReturnValue = intResto.ToString();
                    break;
            }
            return functionReturnValue;

        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static int CalculaDVCodBarras(this string sequencia)
        {
            int functionReturnValue = 0;

            int intContador = 0;
            int intNumero = 0;
            int intTotalNumero = 0;
            int intMultiplicador = 0;
            int intResto = 0;
            int intresultado = 0;
            string caracter = null;

            intMultiplicador = 2;

            for (intContador = 1; intContador <= 43; intContador++)
            {
                //caracter = Strings.Mid(Strings.Right(sequencia, intContador), 1, 1);
                caracter = sequencia.Right(intContador).Substring(1, 1);
                if (intMultiplicador > 9)
                {
                    intMultiplicador = 2;
                    intNumero = 0;
                }
                intNumero = caracter.ToInt32() * intMultiplicador;
                intTotalNumero = intTotalNumero + intNumero;
                intMultiplicador = intMultiplicador + 1;
            }

            intResto = intTotalNumero % 11;

            intresultado = 11 - intResto;

            if (intresultado == 10 | intresultado == 11)
            {
                functionReturnValue = 1;
            }
            else
            {
                functionReturnValue = intresultado;
            }
            return functionReturnValue;

        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static DateTime DateNow(this DateTime value)
        {
            return Convert.ToDateTime(DateTime.Now.ToString("d"));

        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string ComputerName(this string value)
        {
            return System.Windows.Forms.SystemInformation.ComputerName;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string PadLeftT<T>(this T value, int length, Char padChar = '0', bool decimalFormat = false) where T : IConvertible
        {
            Type type = value.GetType();
            if (type == typeof(Int16) || type == typeof(Int32) || type == typeof(Int64))
            {
                return value.ToString().PadLeft(length, padChar);
            }
            else if (type == typeof(Decimal))
            {
                decimal valueDecimal;
                if (decimalFormat == true)
                {
                    valueDecimal = value.ToDecimal(CultureInfo.InvariantCulture.NumberFormat);
                    return valueDecimal.ToString().PadLeft(length, padChar);
                }
                else
                {
                    valueDecimal = value.ToDecimal(CultureInfo.InvariantCulture.NumberFormat) * (100);
                    return ((Int64)valueDecimal).ToString().PadLeft(length, padChar);
                }
            }
            else
            {
                return value.ToString().PadLeft(length, padChar);
            }
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static string PadRightT<T>(this T value, int length, Char padChar = ' ')
        {
            return value.ToString().PadRight(length, padChar);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static Int32 NumberPagesListT<T>(this IEnumerable<T> lstPagina, int itensPagina)
        {
            return ((decimal)(lstPagina.Count() / (decimal)itensPagina)).RoundDecimalToIntHigh();
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static List<T> PagesListT<T>(this IEnumerable<T> lstPagina, int itensPagina, int page)
        {
            return lstPagina.Skip((page - 1) * (itensPagina)).Take(itensPagina).ToList();
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static List<T> PagesListT<T>(this List<T> lstT, int itensPagina, int page) where T : class
        {
            return lstT.Skip((page - 1) * (itensPagina)).Take(itensPagina).ToList();
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static Int32 NumberPagesListT<T>(this List<T> lstT, int itensPagina) where T : class
        {
            return ((decimal)(lstT.Count() / (decimal)itensPagina)).RoundDecimalToIntHigh();
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static List<T> CastList<T>(this object obj, T type)
        {
            return (List<T>)obj;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static T Cast<T>(this object obj, T type)
        {
            return (T)obj;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static void OpenForm(this Form frm)
        {
            Form frmTemp = frm;
            frmTemp = (Form)Application.OpenForms[frm.Name];

            if (frmTemp == null)
            {
                frm.Show();
            }
            else
            {
                frm.Dispose();
                frm = null;
                frmTemp.Show();
                frmTemp.Activate();
                frmTemp.Focus();
            }
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static object ConvertToNull(this object obj, Type objType)
        {

            if (obj == null)
            {
                if (objType == typeof(decimal) ||
                    objType == typeof(float) ||
                    objType == typeof(double) ||
                    objType == typeof(Single) ||
                    objType == typeof(Int64) ||
                    objType == typeof(Int32) ||
                    objType == typeof(Int16) ||
                    objType == typeof(byte))
                {
                    return 0;
                }
                else if (objType == typeof(bool))
                {
                    return false;
                }
                else if (objType == typeof(DateTime))
                {
                    return new DateTime(1900, 1, 1);
                }
                else if (objType == typeof(string))
                {
                    return string.Empty;
                }
                else if (objType == typeof(char))
                {
                    return ' ';
                }
                else
                {
                    return obj;
                }
            }
            else
            {
                return obj;
            }

        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static bool IsNullableType(Type valueType)
        {
            return (valueType.IsGenericType &&
                valueType.GetGenericTypeDefinition().Equals(typeof(Nullable<>)));
        }
        //______________________________________________________________________________________________________________________________________________________________________________
        public static T GetValueNull<T>(this IDataReader reader, int columnIndex)
        {
            object value = reader[columnIndex];
            Type valueType = typeof(T);
            if (value != DBNull.Value)
            {
                if (!IsNullableType(valueType))
                {
                    return (T)Convert.ChangeType(value, valueType);
                }
                else
                {
                    return (T)value;
                }
            }
            return default(T);
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static T ConvertTo<T>(this object text)
        {
            return (T)Convert.ChangeType(text, typeof(T));
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static T ObjectDerived<T, F>(this F classBase) where T : class, new()
        {
            T classDerived = new T();
            List<PropertyInfo> lstPropertyInfo = classBase.GetType().GetProperties().ToList();
            foreach (PropertyInfo property in lstPropertyInfo)
            {
                PropertyInfo propertyDerived = typeof(T).GetProperty(property.Name, property.PropertyType);
                if (propertyDerived != null)
                {
                    propertyDerived.SetValue(classDerived, property.GetValue(classBase, null), null);
                }
            }
            return classDerived;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static List<T> ListObjectDerived<T, F>(this List<F> lstBase) where T : class, new()
        {
            List<T> lstT = new List<T>();
            foreach (F item in lstBase)
            {
                T classDerived = new T();
                List<PropertyInfo> lstPropertyInfo = item.GetType().GetProperties().ToList();
                foreach (PropertyInfo property in lstPropertyInfo)
                {
                    PropertyInfo propertyDerived = typeof(T).GetProperty(property.Name, property.PropertyType);
                    if (propertyDerived != null)
                    {
                        propertyDerived.SetValue(classDerived, property.GetValue(item, null), null);
                    }
                }
                lstT.Add(classDerived);
            }
            return lstT;
        }
        //_______________________________________________________________________________________________________________________________________________________________________________
        public static T CloneObject<T>(this T classBase) where T : class, new()
        {
            T cloneClass = new T();
            List<PropertyInfo> lstPropertyInfo = classBase.GetType().GetProperties().ToList();
            foreach (PropertyInfo property in lstPropertyInfo)
            {
                PropertyInfo propertyClone = typeof(T).GetProperty(property.Name, property.PropertyType);
                if (propertyClone != null)
                {
                    propertyClone.SetValue(cloneClass, property.GetValue(classBase, null), null);
                }
            }
            return cloneClass;
        }
        //_________________________________________________________________________________________________________________________________________________________________________________________________________________________
        public static string QuebrarString(this string strTexto, int tamanhoLinha)
        {
            List<string> lstPalavras = strTexto.Split(' ').ToList();
            string strRetorno = string.Empty;
            string texto = string.Empty;

            if (lstPalavras.Count > 0)
            {
                lstPalavras.ForEach(l =>
                {
                    if (l.Length == 0)
                    {
                        lstPalavras.Remove(l);
                    }
                });
            }

            foreach (string palavra in lstPalavras)
            {
                texto += palavra;
                if ((texto).Length < tamanhoLinha)
                {
                    strRetorno += palavra + " ";
                }
                else if (((texto).Length == tamanhoLinha))
                {
                    strRetorno += System.Environment.NewLine + palavra + " ";
                    texto = string.Empty;
                }
                else if (((texto).Length > tamanhoLinha))
                {
                    strRetorno += System.Environment.NewLine + palavra.Trim() + " ";
                    texto = string.Empty;
                }
            }
            return strRetorno;
        }
    }
}
