using System;
using System.Collections.Generic;
using System.Globalization;
using System.IO;
using System.IO.Compression;
using System.Linq;
using System.Reflection;
using System.Runtime.CompilerServices;
using System.Text;
using System.Text.RegularExpressions;
using System.Xml;
using System.Xml.Linq;
using System.Xml.Serialization;
using System.Xml.XPath;
using NFeLib.NFE.BaseNF;
using NFeLib.NFE.BaseNF.Informacoes.Detalhes;
using NFeLib.NFE.BaseNF.Informacoes.Detalhes.Tributacao;
using NFeLib.NFE.BaseNF.Servicos.RecepcaoEvento;

namespace NFeLib.NFE.Utils
{
    public static class FunctionNFe
    {
        public static CultureInfo CulturaPtBr = new CultureInfo("pt-BR");

        public static void GetIcms(string crt, det detItem, ref string cst, ref string baseIcms, ref string valorIcms, ref string aliquotaIcms, ref string baseIcmsSt, ref string valorIcmsSt)
        {

            ICMS icms = detItem.imposto.ICMS;
            // Simples Nacional
            if (crt == "1")
            {
                if (icms.ICMSSN101 != null)
                {
                    cst = icms.ICMSSN101.orig + icms.ICMSSN101.CSOSN;
                }
                else if (icms.ICMSSN102 != null)
                {
                    cst = icms.ICMSSN102.orig + icms.ICMSSN102.CSOSN;
                }
                else if (icms.ICMSSN201 != null)
                {
                    cst = icms.ICMSSN201.orig + icms.ICMSSN201.CSOSN;
                }
                else if (icms.ICMSSN202 != null)
                {
                    cst = icms.ICMSSN202.orig + icms.ICMSSN202.CSOSN;
                }
                else if (icms.ICMSSN500 != null)
                {
                    cst = icms.ICMSSN500.orig + icms.ICMSSN500.CSOSN;
                }
                else if (icms.ICMSSN900 != null)
                {
                    cst = icms.ICMSSN900.orig + icms.ICMSSN900.CSOSN;
                }
                // 2 - Simples Nacional c/ excesso de sublimite da receita bruta | 3 - Regime Normal
            }
            else
            {
                if (icms.ICMS00 != null)
                {
                    cst = icms.ICMS00.orig + icms.ICMS00.CST;
                    baseIcms = icms.ICMS00.vBC.ToString("N", CulturaPtBr);
                    valorIcms = icms.ICMS00.vICMS.ToString("N", CulturaPtBr);
                    aliquotaIcms = icms.ICMS00.pICMS.ToString("N", CulturaPtBr);
                }
                else if (icms.ICMS10 != null)
                {
                    cst = icms.ICMS10.orig + icms.ICMS10.CST;
                    baseIcms = icms.ICMS10.vBC.ToString("N", CulturaPtBr);
                    valorIcms = icms.ICMS10.vICMS.ToString("N", CulturaPtBr);
                    aliquotaIcms = icms.ICMS10.pICMS.ToString("N", CulturaPtBr);
                    baseIcmsSt = icms.ICMS10.vBCST.ToString("N", CulturaPtBr);
                    valorIcmsSt = icms.ICMS10.vICMSST.ToString("N", CulturaPtBr);
                }
                else if (icms.ICMS20 != null)
                {
                    cst = icms.ICMS20.orig + icms.ICMS20.CST;
                    baseIcms = icms.ICMS20.vBC.ToString("N", CulturaPtBr);
                    valorIcms = icms.ICMS20.vICMS.ToString("N", CulturaPtBr);
                    aliquotaIcms = icms.ICMS20.pICMS.ToString("N", CulturaPtBr);
                }
                else if (icms.ICMS30 != null)
                {
                    var _with11 = icms.ICMS30;
                    cst = icms.ICMS30.orig + icms.ICMS30.CST;
                    baseIcmsSt = icms.ICMS30.vBCST.ToString("N", CulturaPtBr);
                    valorIcmsSt = icms.ICMS30.vICMSST.ToString("N", CulturaPtBr);
                }
                else if (icms.ICMS40 != null)
                {
                    cst = icms.ICMS40.orig + icms.ICMS40.CST;
                }
                else if (icms.ICMS51 != null)
                {
                    cst = icms.ICMS51.orig + icms.ICMS51.CST;
                    baseIcms = icms.ICMS51.vBC.Value.ToString("N", CulturaPtBr);
                    valorIcms = icms.ICMS51.vICMS.Value.ToString("N", CulturaPtBr);
                    aliquotaIcms = icms.ICMS51.pICMS.Value.ToString("N", CulturaPtBr);
                }
                else if (icms.ICMS60 != null)
                {
                    cst = icms.ICMS60.orig + icms.ICMS60.CST;
                }
                else if (icms.ICMS70 != null)
                {
                    cst = icms.ICMS70.orig + icms.ICMS70.CST;
                    baseIcms = icms.ICMS70.vBC.ToString("N", CulturaPtBr);
                    valorIcms = icms.ICMS70.vICMS.ToString("N", CulturaPtBr);
                    aliquotaIcms = icms.ICMS70.pICMS.ToString("N", CulturaPtBr);
                    baseIcmsSt = icms.ICMS70.vBCST.ToString("N", CulturaPtBr);
                    valorIcmsSt = icms.ICMS70.vICMSST.ToString("N", CulturaPtBr);
                }
                else if (icms.ICMS90 != null)
                {
                    cst = icms.ICMS90.orig + icms.ICMS90.CST;
                    baseIcms = icms.ICMS90.vBC.Value.ToString("N", CulturaPtBr);
                    valorIcms = icms.ICMS90.vICMS.Value.ToString("N", CulturaPtBr);
                    aliquotaIcms = icms.ICMS90.pICMS.Value.ToString("N", CulturaPtBr);
                    baseIcmsSt = icms.ICMS90.vBCST.Value.ToString("N", CulturaPtBr);
                    valorIcmsSt = icms.ICMS90.vICMSST.Value.ToString("N", CulturaPtBr);
                }
            }

        }

        public static string QuebrarString(string strTexto, int tamanhoLinha)
        {
            List<string> lstPalavras = strTexto.Split(' ').ToList();
            string strRetorno = string.Empty;
            string texto = string.Empty;

            foreach (string palavra in lstPalavras)
            {
                texto += palavra;
                if ((texto).Length < tamanhoLinha)
                {
                    strRetorno += palavra + " ";
                }
                else if (((texto).Length == tamanhoLinha))
                {
                    strRetorno += palavra + " " + System.Environment.NewLine;
                    texto = string.Empty;
                }
                else if (((texto).Length > tamanhoLinha))
                {
                    strRetorno += System.Environment.NewLine + palavra.Trim() + " ";
                    texto = string.Empty;
                }
            }
            return strRetorno;

        }

        public static bool ValidarXml(string strXml)
        {
            try
            {
                XDocument xDoc = XDocument.Parse(strXml);
                return true;
            }
            catch (XmlException e)
            {
                return false;
            }
        }

        public static bool ValidarXmlNFe(XmlDocument xmlDoc)
        {
            try
            {
                XDocument XmlDocument = XDocument.Parse(xmlDoc.OuterXml);
                XDocument xml = XDocument.Parse(Regex.Replace(XmlDocument.ToString(), "xmlns=\".+\"", String.Empty));
                int countNoDet = xml.XPathSelectElements("nfeProc/NFe/infNFe/det").Count();
                int countNoEmit = xml.XPathSelectElements("nfeProc/NFe/infNFe/emit").Count();
                int countNoNF = xml.XPathSelectElements("nfeProc/NFe/infNFe/ide/nNF").Count();
                int countNoChave = xml.XPathSelectElements("nfeProc/protNFe/infProt/chNFe").Count();

                return countNoDet == 0 || countNoEmit == 0 || countNoNF == 0 || countNoChave == 0 ? false : true;

            }
            catch (XmlException e)
            {
                return false;
            }
        }
        public static bool ValidarXmlNFe(string pathXml)
        {
            try
            {
                XDocument XmlDocument = XDocument.Load(pathXml);
                XDocument xml = XDocument.Parse(Regex.Replace(XmlDocument.ToString(), "xmlns=\".+\"", String.Empty));
                int countNoDet = xml.XPathSelectElements("nfeProc/NFe/infNFe/det").Count();
                int countNoEmit = xml.XPathSelectElements("nfeProc/NFe/infNFe/emit").Count();
                int countNoNF = xml.XPathSelectElements("nfeProc/NFe/infNFe/ide/nNF").Count();
                int countNoChave = xml.XPathSelectElements("nfeProc/protNFe/infProt/chNFe").Count();

                return countNoDet == 0 || countNoEmit == 0  || countNoNF == 0 || countNoChave == 0 ? false : true;
            }

            catch (XmlException ex)
            {
                string erro = ex.Message;
                return false;
            }
        }
        public static XmlDocument Serializar(object objectToSerialize, string strUrl = null)
        {
            XmlSerializerNamespaces ns = new XmlSerializerNamespaces();
            if(strUrl == null)
            {
                strUrl = "http://www.portalfiscal.inf.br/nfe";
            }
            ns.Add("", strUrl);

            Stream mStream = new MemoryStream();
            XmlDocument doc = new XmlDocument();
            XmlWriter writer = XmlWriter.Create(mStream);
            XmlSerializer serializer = new XmlSerializer(objectToSerialize.GetType());
            serializer.Serialize(writer, RuntimeHelpers.GetObjectValue(objectToSerialize), ns);

            writer.Flush();
            mStream.Flush();
            mStream.Position = 0L;
            doc.Load(mStream);
            return doc;
        }

        public static T DeserializarNFe<T>(string xml) where T : class, new()
        {
            XmlSerializer serializer = default(XmlSerializer);
            XmlDocument doc = new XmlDocument();
            T objectNFe = null;

            objectNFe = new T();
            StringReader reader = new StringReader(xml);
            serializer = new XmlSerializer(objectNFe.GetType());
            objectNFe = (T)serializer.Deserialize(reader);
            return objectNFe;
         
        }
      
        public static XmlDocument GeraXmlNFeProc(string versao,XmlDocument xmlAssinado,XmlDocument xmlProtocolo)
        {

            if (xmlAssinado.FirstChild is XmlDeclaration)
            {
                xmlAssinado.RemoveChild(xmlAssinado.FirstChild);
            }

            if (xmlProtocolo.FirstChild is XmlDeclaration)
            {
                xmlProtocolo.RemoveChild(xmlProtocolo.FirstChild);
            }

            string strXml = xmlAssinado.OuterXml + xmlProtocolo.OuterXml;

            StringBuilder sbXmlProc = new StringBuilder();
            sbXmlProc.Append("<?xml version=\"1.0\" encoding=\"UTF-8\"?>");
            sbXmlProc.Append("<nfeProc versao =\"" + versao + "\" xmlns=\"http://www.portalfiscal.inf.br/nfe\">");
            sbXmlProc.Append(strXml);
            sbXmlProc.Append("</nfeProc>");

            XmlDocument xmlDoc = new XmlDocument();
            xmlDoc.LoadXml(sbXmlProc.ToString());

            //xmlDoc.DocumentElement["NFe"].SetAttribute("xmlns", "http://www.portalfiscal.inf.br/nfe");
            xmlDoc.DocumentElement.SetAttribute("xmlns:ds", "http://www.w3.org/2000/09/xmldsig#");
            xmlDoc.DocumentElement.SetAttribute("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance");
            return xmlDoc;
        }
       
        public static XmlDocument GerarLoteEventoNFe(XmlDocument xmlEventos, int numLote,string versao)
        {
            evento eventoNfe  = DeserializeXml<evento>(xmlEventos.OuterXml);
            envEvento envioEvento = new envEvento
            {
                versao = versao,
                idLote = numLote.ToString("000000000000000"),
                evento = eventoNfe
            };
            XmlDocument xmlEnvioEvento = Serializar(envioEvento);
            return xmlEnvioEvento;
    
        }
        
        public static XmlDocument XmlEventoProcessado(string versao, XmlDocument xmlDocAssinado,retEvento retornoEvento)
        {
            procEventoNFe eventoProc = new procEventoNFe();
            eventoProc.versao = versao;
            XmlDocument xmlEventoProc = FunctionNFe.Serializar(eventoProc);

            if (xmlDocAssinado.FirstChild is XmlDeclaration)
            {
                xmlDocAssinado.RemoveChild(xmlDocAssinado.FirstChild);
            }
            xmlEventoProc.DocumentElement.AppendChild(xmlEventoProc.ImportNode(xmlDocAssinado.FirstChild, true));

            XmlDocument xmlProtAut = FunctionNFe.Serializar(retornoEvento);
            if (xmlProtAut.FirstChild is XmlDeclaration)
            {
                xmlProtAut.RemoveChild(xmlProtAut.FirstChild);
            }
            xmlEventoProc.DocumentElement.AppendChild(xmlEventoProc.ImportNode(xmlProtAut.FirstChild, true));

            return xmlEventoProc;
        }

        public static decimal RoundDecimal(decimal valor, int casasDecimais)
        {
            var valorNovo = decimal.Round(valor, casasDecimais);
            var valorNovoStr = valorNovo.ToString("F" + casasDecimais, CultureInfo.CurrentCulture);
            return decimal.Parse(valorNovoStr);
        }
        public static decimal? RoundDecimal(decimal? valor, int casasDecimais)
        {
            if (valor == null) return null;
            return RoundDecimal(valor.Value, casasDecimais);
        }

        public static void SalvarXml(XmlDocument xmlDoc, string pathDir, string nameFile)
        {
            if (!Directory.Exists(pathDir))
            {
                Directory.CreateDirectory(pathDir);
            }
            using (XmlTextWriter xmlWriter = new XmlTextWriter(pathDir + @"\" + nameFile, Encoding.UTF8))
            {
                xmlWriter.Formatting = Formatting.None;
                xmlDoc.Save(xmlWriter);
            }
        }
        public static evento GerarEventoNFe(string versao, string tipoAmbiente, string seqEvento, string chaveNFe, string codigoUF, string cnpjEmpresa, string descricaoEvento, TipoEvento tipoEvento, string dataFormatoUTC)
        {
            string tpEvento = ((int)tipoEvento).ToString();
            evento itemEvento = new evento();
            itemEvento.infEvento = new infEventoEnv();
            itemEvento.infEvento.nSeqEvento = seqEvento;
            itemEvento.versao = versao;
            itemEvento.infEvento.Id = "ID" + tpEvento + chaveNFe + itemEvento.infEvento.nSeqEvento.PadLeft(2, '0');
            itemEvento.infEvento.cOrgao = codigoUF;
            itemEvento.infEvento.tpAmb = tipoAmbiente;
            itemEvento.infEvento.CNPJ = cnpjEmpresa;
            itemEvento.infEvento.chNFe = chaveNFe;
            itemEvento.infEvento.dhEvento = dataFormatoUTC;
            itemEvento.infEvento.tpEvento = tpEvento;
            itemEvento.infEvento.verEvento = versao;
            itemEvento.infEvento.detEvento.versao = versao;
            itemEvento.infEvento.detEvento.descEvento = descricaoEvento;
            itemEvento.infEvento.detEvento.xCorrecao = null;
            itemEvento.infEvento.detEvento.xCondUso = null;
            itemEvento.infEvento.detEvento.nProt = null;
            itemEvento.infEvento.detEvento.xJust = null;
            itemEvento.infEvento.detEvento.xCorrecao = null;
            itemEvento.infEvento.detEvento.xCondUso = null;
            return itemEvento;
        }

        public static XmlDocument GeraLoteEventoNFe(int numLote)
        {
            StringBuilder sbLoteEvent = new StringBuilder();
            sbLoteEvent.Append("<?xml version=\"1.0\" encoding=\"utf-8\"?>");
            sbLoteEvent.Append("<envEvento versao =\"1.00\" xmlns=\"http://www.portalfiscal.inf.br/nfe\">");
            sbLoteEvent.AppendFormat("<idLote>{0}</idLote>", numLote.ToString("000000000000000"));
            sbLoteEvent.Append("</envEvento>");

            XmlDocument doc = new XmlDocument();
            doc.LoadXml(sbLoteEvent.ToString());
            return doc;
        }

        public static T DeserializeXml<T>(string xml) where T : class, new()
        {
            XmlSerializer serializer = default(XmlSerializer);
            XmlDocument doc = new XmlDocument();
            T objectNFe = null;

            try
            {
                objectNFe = new T();
                StringReader reader = new StringReader(xml);
                serializer = new XmlSerializer(objectNFe.GetType());
                objectNFe = (T)serializer.Deserialize(reader);
                return objectNFe;
            }
            catch (Exception)
            {
                return objectNFe;
            }
        }

        // decompressor
        public static string DecompressGZip(string textBase64)
        {
            byte[] result;
            byte[] bytes = Convert.FromBase64String(textBase64);

            using (MemoryStream ms = new MemoryStream())
            {
                ms.Write(bytes, 0, bytes.Length);
                using (GZipStream gs = new GZipStream(ms,
                CompressionMode.Decompress, true))
                {
                    ms.Position = 0L;
                    result = ToByteArray(gs);
                }
            }
            return Encoding.UTF8.GetString(result);
        }
        // decompressor
        public static string DecompressGZip(byte[] bytes)
        {
            byte[] result;

            using (MemoryStream ms = new MemoryStream())
            {
                ms.Write(bytes, 0, bytes.Length);
                using (GZipStream gs = new GZipStream(ms,
                CompressionMode.Decompress, true))
                {
                    ms.Position = 0L;
                    result = ToByteArray(gs);
                }
            }
            return Encoding.UTF8.GetString(result);
        }
        // compressor
        public static string CompresGZip(string texto)
        {
            byte[] bytes = Encoding.UTF8.GetBytes(texto);
            byte[] bytesResult;

            using (MemoryStream ms = new MemoryStream())
            {
                using (GZipStream gs = new GZipStream(ms,
                CompressionMode.Compress, true))
                {
                    gs.Write(bytes, 0, bytes.Length);
                }
                ms.Position = 0L;
                bytesResult = ToByteArray(ms);
            }

            return Convert.ToBase64String(bytesResult);
        }
        // streaming to byte array
        private static byte[] ToByteArray(Stream stream)
        {
            int count = 0;
            List<byte> result = new List<byte>();
            byte[] buffer = new byte[0x20000];
            int bytes = 0;
            while ((bytes = stream.Read(buffer, 0, 0x20000)) > 0)
            {
                count += bytes;
                for (int i = 0; i < bytes; i++)
                {
                    result.Add(buffer[i]);
                }
            }
            return result.ToArray();
        }
    }

}
