﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using System.Globalization;
using System.Security.Cryptography.X509Certificates;
using System.Security.Cryptography;
using System.Text.RegularExpressions;
using NFeLib.NFE.BaseNF.Informacoes.Identificacao;
using NFeLib.NFE.WebServices;

namespace NFeLib.NFE.Utils
{
    public class QRCode
    {
        public string CNPJ { get; set; }
        public string CPF { get; set; }
        public string IdEstrangeiro { get; set; }
        public string ChaveAcesso { get; set; }
        public string TipoAmbiente { get; set; }
        public string DataHoraEmissao { get; set; }
        public string ValorNota { get; set; }
        public string ValorIcms { get; set; }
        public string DigestValue { get; set; }
        public string IdentificadorCSC { get; set; }
        public string TokenCSC { get; set; }
        public string UrlConsultaChave { get; set; }

        public string UrlConsultaQrcode { get; set; }

        private XmlDocument _xmlDocAssinado = null;
        private XmlNamespaceManager _ns = null;
        private string _nsUrlNFe = "http://www.portalfiscal.inf.br/nfe";
        private StringBuilder parametrosQR = null;
        private string _hashQRCode = string.Empty;
        private string _parametrosLinkConsulta = string.Empty;

        /// <summary>
        /// Metodos Publico
        /// </summary>
        /// <param name="identificadorCSC">Codigo de identificação no banco de dados do SEFAZ</param>
        /// <param name="tokenCSC">Codigo de identificação do Contribuinte (antigo Token)</param>
        /// <param name="arquivoXML">Arquivo XML com as informações para calculo</param>
        public void GerarQRCodeXml(string identificadorCSC, string tokenCSC, XmlDocument XmlDocAssinado)
        {

            this._xmlDocAssinado = XmlDocAssinado;
            _ns = new XmlNamespaceManager(_xmlDocAssinado.NameTable);
            _ns.AddNamespace("n", "http://www.portalfiscal.inf.br/nfe");
            _ns.AddNamespace("s", "http://www.w3.org/2000/09/xmldsig#");

            string cUF = GetValueXML("n:NFe/n:infNFe/n:ide/n:cUF");
            string tpAmb = GetValueXML("n:NFe/n:infNFe/n:ide/n:tpAmb");
            TipoAmbiente tipoAmbiente = ((TipoAmbiente)Enum.Parse(typeof(TipoAmbiente), tpAmb));
            Estado estado = ((Estado)Enum.Parse(typeof(Estado), cUF));
            string urlQrCode = new EnderecoConsultaPublicaNfce().ObterUrl(tipoAmbiente, estado, TipoUrlConsultaPublica.UrlQrCode);
            string urlConsultaChave = new EnderecoConsultaPublicaNfce().ObterUrl(tipoAmbiente, estado, TipoUrlConsultaPublica.UrlConsulta);

            this.UrlConsultaQrcode = urlQrCode;
            this.UrlConsultaChave = urlConsultaChave;
            this.IdentificadorCSC = identificadorCSC.Trim();
            this.TokenCSC = tokenCSC.Trim();

            this.Populate();
            this.GerarLinkConsulta();
            this.AddLinkQRCode();
        }

        /// <summary>
        /// Metodos Publico
        /// </summary>
        /// <param name="identificadorCSC">Codigo de identificação no banco de dados do SEFAZ</param>
        /// <param name="tokenCSC">Codigo de identificação do Contribuinte (antigo Token)</param>
        /// <param name="arquivoXML">Arquivo XML com as informações para calculo</param>
        public string GerarQRCodeTexto(QRCode qrcode)
        {

            this.CNPJ = qrcode.CNPJ;
            this.CPF = qrcode.CPF;
            this.IdEstrangeiro = qrcode.IdEstrangeiro;
            this.ChaveAcesso = qrcode.ChaveAcesso;
            this.TipoAmbiente = qrcode.TipoAmbiente;
            this.DataHoraEmissao = qrcode.DataHoraEmissao;
            this.ValorNota = qrcode.ValorNota;
            this.ValorIcms = qrcode.ValorIcms;
            this.DigestValue = qrcode.DigestValue;
            this.IdentificadorCSC = qrcode.IdentificadorCSC;
            this.TokenCSC = qrcode.TokenCSC;
            this.UrlConsultaChave = qrcode.UrlConsultaChave;
            this.UrlConsultaQrcode = qrcode.UrlConsultaQrcode;

            this.GerarLinkConsulta();
            return _parametrosLinkConsulta;
        }

        /// <summary>
        /// Recuperar informações do XML
        /// </summary>
        private void Populate()
        {
            this.CNPJ = GetValueXML("n:NFe/n:infNFe/n:dest/n:CNPJ");
            this.CPF = GetValueXML("n:NFe/n:infNFe/n:dest/n:CPF");
            this.IdEstrangeiro = GetValueXML("n:NFe/n:infNFe/n:dest/n:idEstrangeiro");
            this.ChaveAcesso = ValuesNumeric( GetValueXML("n:NFe/n:infNFe", "Id"));
            this.TipoAmbiente = GetValueXML("n:NFe/n:infNFe/n:ide/n:tpAmb");
            this.DataHoraEmissao = GetValueXML("n:NFe/n:infNFe/n:ide/n:dhEmi");
            this.ValorNota = GetValueXML("n:NFe/n:infNFe/n:total/n:ICMSTot/n:vNF");
            this.ValorIcms = GetValueXML("n:NFe/n:infNFe/n:total/n:ICMSTot/n:vICMS");
            this.DigestValue = GetValueXML("n:NFe/s:Signature/s:SignedInfo/s:Reference/s:DigestValue");
        }
        public static string ValuesNumeric(string value)
        {
            if (string.IsNullOrEmpty(value)) return value;
            return Regex.Replace(value, @"[^0-9]", "");
        }

        /// <summary>
        /// Gerar o Hash do QRCode e montar o Link para inseri-lo no XML
        /// </summary>
        /// <param name="linkUF">Link de consulta da UF</param>
        private void GerarLinkConsulta()
        {
            parametrosQR = new StringBuilder();
            parametrosQR.Append("chNFe=" + this.ChaveAcesso);
            parametrosQR.Append("&nVersao=100");
            parametrosQR.Append("&tpAmb=" + this.TipoAmbiente);
            parametrosQR.Append((String.IsNullOrEmpty(this.CNPJ) ? (String.IsNullOrEmpty(this.CPF) ? (String.IsNullOrEmpty(this.IdEstrangeiro) ? "" : "&cDest=" + this.IdEstrangeiro) : "&cDest=" + this.CPF) : "&cDest=" + this.CNPJ));
            parametrosQR.Append("&dhEmi=" + ComputeHexadecimal(this.DataHoraEmissao));
            parametrosQR.Append("&vNF=" + this.ValorNota);
            parametrosQR.Append("&vICMS=" + this.ValorIcms);
            parametrosQR.Append("&digVal=" + ComputeHexadecimal(this.DigestValue));
            parametrosQR.Append("&cIdToken=" + this.TokenCSC);

            this._hashQRCode = GetSHA1HashData(this.parametrosQR.ToString() + this.IdentificadorCSC, true);
            this._parametrosLinkConsulta = UrlConsultaQrcode + "?" + this.parametrosQR.ToString().Trim() + "&cHashQRCode=" + this._hashQRCode.Trim();
        }

        /// <summary>
        /// Adicionar link gerado ao XML
        /// </summary>
        public void AddLinkQRCode()
        {
            XmlDocument xmlQrCode = new XmlDocument();
            XmlElement infNFeSupl = xmlQrCode.CreateElement("infNFeSupl", _nsUrlNFe);

            XmlElement qrCode = xmlQrCode.CreateElement("qrCode", _nsUrlNFe);
            qrCode.InnerXml = "<![CDATA[" + this._parametrosLinkConsulta.Trim() + "]]>";
            infNFeSupl.AppendChild(qrCode);

            XmlElement urlChave = xmlQrCode.CreateElement("urlChave", _nsUrlNFe);
            urlChave.InnerXml = UrlConsultaChave;
            infNFeSupl.AppendChild(urlChave);

            xmlQrCode.AppendChild(infNFeSupl);

            XmlNode newNode = _xmlDocAssinado.ImportNode(xmlQrCode.DocumentElement, true);
            XmlNode nodeInf = _xmlDocAssinado.SelectSingleNode("n:NFe/n:infNFe", _ns);
            _xmlDocAssinado.DocumentElement.InsertAfter(newNode, nodeInf);

        }

        /// <summary>
        /// Recupera as informações no XML
        /// </summary>
        /// <param name="elementTag">Grupo de tag</param>
        /// <param name="valueTag">Elmento que deseja retornar o valor</param>
        /// <returns>Valor do elemento</returns>
        private string GetValueXML(string path, string attribute = "")
        {
            string value = "";
            XmlNode node = null;
            if (attribute.Length == 0)
            {
                node = _xmlDocAssinado.SelectSingleNode(path, _ns);
            }
            else
            {
                node = _xmlDocAssinado.SelectSingleNode(path, _ns).Attributes.OfType<XmlAttribute>().ToList().Find(l => l.Name == attribute);
            }

            if (node != null)
            {
                value = node.InnerText;
            }
            return value;
        }

        #region Funções
        private string ComputeHexadecimal(string input)
        {
            string hexOutput = "";
            char[] values = input.ToCharArray();
            foreach (char letter in values)
            {
                // Get the integral value of the character.
                int value = Convert.ToInt32(letter);
                // Convert the decimal value to a hexadecimal value in string form.
                hexOutput += String.Format("{0:x}", value);
            }

            return hexOutput;
        }

        private string GetSHA1HashData(string data, bool toUpper)
        {
            HashAlgorithm algorithm = new SHA1CryptoServiceProvider();
            byte[] buffer = algorithm.ComputeHash(System.Text.Encoding.ASCII.GetBytes(data));
            System.Text.StringBuilder builder = new System.Text.StringBuilder(buffer.Length);
            foreach (byte num in buffer)
            {
                if (toUpper)
                    builder.Append(num.ToString("X2"));
                else
                    builder.Append(num.ToString("x2"));
            }

            return builder.ToString();
        }
        #endregion
    }
}
