﻿using System.Collections.Generic;
using System.Linq;

namespace NFeLib.NFE.WebServices
{

    public class UrlsServWeb : ConfigWsUrls
    {

        #region Variaveis privadas
        //private List<ConfigWsUrls> lstConfigWsUrls = new List<ConfigWsUrls>();

        private List<UrlsServWeb> _lstConfigWsUrls = new List<UrlsServWeb>();
        private readonly List<string> _lstNfeUFsSefVirtRs = new List<string> { "AC", "AL", "AP", "DF", "ES", "PB", "RO", "RJ", "RN", "RR", "SC", "SE", "TO" };
        private readonly List<string> _lstNfeUFsSefVirtNa = new List<string> { "MA", "PA", "PI" };
        private readonly List<string> _lstNfeUFsSefContSvcAn = new List<string> { "AC", "AL", "AP", "DF", "ES", "MG", "PB", "RO", "RJ", "RN", "RR", "SC", "SP", "SE", "TO" };
        private readonly List<string> _lstNfeUFsSefContSvcRs = new List<string> { "AM", "BA", "CE", "GO", "MA", "MS", "MT", "PA", "PR", "PE", "PI" };

        private readonly List<string> _lstNfceUFsSefVirtRs = new List<string> { "AC", "AL", "AP", "BA", "DF", "ES", "MA", "PA", "PB", "PE", "PI", "RJ", "RN", "RO", "RR", "SE", "TO"};
        private string _modeloDoc;

        #endregion

        public UrlsServWeb(string tipoAmb, string modeloDoc)
        {
            _modeloDoc = modeloDoc;
            GerarUrls(tipoAmb, modeloDoc);
        }

        public UrlsServWeb()
        {
        }

        #region Metodos Privados
        private void GerarUrls(string tipoAmb, string modeloDoc)
        {
            switch (modeloDoc)
            {
                // NFe
                case "55":
                    switch (tipoAmb)
                    {
                        case "1": //Produção
                            UrlsAmbProdNFe();
                            break;
                        default: //Homologação
                            UrlsAmbHomNFe();
                            break;
                    }
                    break;

                    default:
                    switch (tipoAmb)
                    {
                        case "1": //Produção
                            UrlsAmbProdNfce();
                            break;
                        default: //Homologação
                            UrlsAmbHomNfce();
                            break;
                    }
                    break;
            }

        }

        private string SefazAutorizador(string uf, string tipoEmissao)
        {
            string sefazAut = string.Empty;

            // Documento NF-e
            if (_modeloDoc == "55")
            {
                // Tipo Emissão Normal
                if (tipoEmissao == "1")
                {
                    // UFs Sefaz Virtual Rio Grande do Sul - (SVRS)
                    if (_lstNfeUFsSefVirtRs.Contains(uf))
                    {
                        sefazAut = "SVRS";
                    }
                    // UFs Sefaz Virtual Ambiente Nacional - (SVAN)
                    else if (_lstNfeUFsSefVirtNa.Contains(uf))
                    {
                        sefazAut = "SVAN";
                    }
                    // Demais UFs
                    else
                    {
                        sefazAut = uf;
                    }
                }
                // Tipo Emissão Contigência
                else
                {
                    // UFs Sefaz Virtual de Contingência Rio Grande do Sul - (SVC-RS)
                    if (_lstNfeUFsSefContSvcRs.Contains(uf))
                    {
                        sefazAut = "SVC-RS";
                    }
                    // UFs Sefaz Virtual de Contingência Ambiente Nacional - (SVC-AN)
                    else if (_lstNfeUFsSefContSvcAn.Contains(uf))
                    {
                        sefazAut = "SVC-AN";
                    }

                }
            }

            // Documento NFC-e
            // UFs que utilizando esse Servidor:
            // AC, AL, AP, BA, DF, ES, MA, PA, PB, PE, PI, RJ, RN, RO, RR, SE, TO
            if (_modeloDoc == "65")
            {
                // UFs Sefaz Virtual Rio Grande do Sul - (SVRS)
                if (_lstNfceUFsSefVirtRs.Contains(uf))
                {
                    sefazAut = "SVRS";
                }
                else
                {
                    sefazAut = uf;
                }
                
            }

            return sefazAut;

        }

        #endregion

        #region Métodos Publicos
        public ConfigWsUrls UrlServico(string uf, string tipoEmissao, string servico)
        {
            string sefazAut = uf;
            if (sefazAut != "AN")
            {
                sefazAut = SefazAutorizador(uf, tipoEmissao);
            }

            ConfigWsUrls ConfigWsUrls = _lstConfigWsUrls.Find(l => l.SefazAut == sefazAut && l.Servico == servico);
            return ConfigWsUrls;
        }

        public List<ConfigWsUrls> ListaUrlServico(string uf, string tipoEmissao, string servico)
        {
            string sefazAut = SefazAutorizador(uf, tipoEmissao);
            List<ConfigWsUrls> lstUrls = _lstConfigWsUrls.Where(l => l.Servico == servico).Select(x => (ConfigWsUrls)x).ToList();
            return lstUrls;
        }
        #endregion

        #region Urls NF-e

        #region Homologação
        private void UrlsAmbHomNFe()
        {
            // Sefaz Amazonas
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homnfe.sefaz.am.gov.br/services2/services/NfeInutilizacao4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homnfe.sefaz.am.gov.br/services2/services/NfeConsulta4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homnfe.sefaz.am.gov.br/services2/services/NfeStatusServico4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homnfe.sefaz.am.gov.br/services2/services/RecepcaoEvento4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homnfe.sefaz.am.gov.br/services2/services/NfeAutorizacao4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homnfe.sefaz.am.gov.br/services2/services/NfeRetAutorizacao4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz Bahia
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://hnfe.sefaz.ba.gov.br/webservices/NFeInutilizacao4/NFeInutilizacao4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://hnfe.sefaz.ba.gov.br/webservices/NFeConsultaProtocolo4/NFeConsultaProtocolo4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://hnfe.sefaz.ba.gov.br/webservices/NFeStatusServico4/NFeStatusServico4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://hnfe.sefaz.ba.gov.br/webservices/CadConsultaCadastro4/CadConsultaCadastro4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://hnfe.sefaz.ba.gov.br/webservices/NFeRecepcaoEvento4/NFeRecepcaoEvento4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://hnfe.sefaz.ba.gov.br/webservices/NFeAutorizacao4/NFeAutorizacao4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://hnfe.sefaz.ba.gov.br/webservices/NFeRetAutorizacao4/NFeRetAutorizacao4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz Ceara
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfeh.sefaz.ce.gov.br/nfe4/services/NFeInutilizacao4?WSDL", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfeh.sefaz.ce.gov.br/nfe4/services/NFeConsultaProtocolo4?WSDL", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfeh.sefaz.ce.gov.br/nfe4/services/NFeStatusServico4?WSDL", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfeh.sefaz.ce.gov.br/nfe4/services/NFeAutorizacao4?WSDL", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfeh.sefaz.ce.gov.br/nfe4/services/NFeRetAutorizacao4?WSDL", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfeh.sefaz.ce.gov.br/nfe4/services/NFeRecepcaoEvento4?WSDL", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz Goiás
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeInutilizacao4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeConsultaProtocolo4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeStatusServico4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/CadConsultaCadastro4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeRecepcaoEvento4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeAutorizacao4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeRetAutorizacao4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz Minas Gerais
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://hnfe.fazenda.mg.gov.br/nfe2/services/NFeInutilizacao4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://hnfe.fazenda.mg.gov.br/nfe2/services/NFeConsulta4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://hnfe.fazenda.mg.gov.br/nfe2/services/NFeStatusServico4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://hnfe.fazenda.mg.gov.br/nfe2/services/NFeRecepcaoEvento4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://hnfe.fazenda.mg.gov.br/nfe2/services/NFeAutorizacao4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://hnfe.fazenda.mg.gov.br/nfe2/services/NFeRetAutorizacao4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz Mato Grosso do Sul
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homologacao.nfe.ms.gov.br/ws/NFeInutilizacao4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homologacao.nfe.ms.gov.br/ws/NFeConsultaProtocolo4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homologacao.nfe.ms.gov.br/ws/NFeStatusServico4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://homologacao.nfe.ms.gov.br/ws/CadConsultaCadastro4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homologacao.nfe.ms.gov.br/ws/NFeRecepcaoEvento4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homologacao.nfe.ms.gov.br/ws/NFeAutorizacao4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homologacao.nfe.ms.gov.br/ws/NFeRetAutorizacao4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz Mato Grosso
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfews/v2/services/NfeInutilizacao4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfews/v2/services/NfeConsulta4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfews/v2/services/NfeStatusServico4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://homologacao.sefaz.mt.gov.br/nfews/v2/services/CadConsultaCadastro4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homologacao.sefaz.mt.gov.br/nfews/v2/services/RecepcaoEvento4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfews/v2/services/NfeAutorizacao4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfews/v2/services/NfeRetAutorizacao4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz Parana
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homologacao.nfe.sefa.pr.gov.br/nfe/NFeInutilizacao4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homologacao.nfe.sefa.pr.gov.br/nfe/NFeConsultaProtocolo4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homologacao.nfe.sefa.pr.gov.br/nfe/NFeStatusServico4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://homologacao.nfe.sefa.pr.gov.br/nfe/CadConsultaCadastro4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homologacao.nfe.sefa.pr.gov.br/nfe/NFeRecepcaoEvento4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homologacao.nfe.sefa.pr.gov.br/nfe/NFeAutorizacao4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homologacao.nfe.sefa.pr.gov.br/nfe/NFeRetAutorizacao4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz Rio Grande do Sul
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe-homologacao.sefazrs.rs.gov.br/ws/nfeinutilizacao/nfeinutilizacao4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe-homologacao.sefazrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe-homologacao.sefazrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe-homologacao.sefazrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe-homologacao.sefazrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe-homologacao.sefazrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "2" });

            // Sefaz São Paulo
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homologacao.nfe.fazenda.sp.gov.br/ws/nfeinutilizacao4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homologacao.nfe.fazenda.sp.gov.br/ws/nfeconsultaprotocolo4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homologacao.nfe.fazenda.sp.gov.br/ws/nfestatusservico4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://homologacao.nfe.fazenda.sp.gov.br/ws/cadconsultacadastro4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homologacao.nfe.fazenda.sp.gov.br/ws/nferecepcaoevento4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homologacao.nfe.fazenda.sp.gov.br/ws/nfeautorizacao4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homologacao.nfe.fazenda.sp.gov.br/ws/nferetautorizacao4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "2" });

            // SVAN(Servidor Nacional Emissão NFe)
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://hom.sefazvirtual.fazenda.gov.br/NFeInutilizacao4/NFeInutilizacao4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://hom.sefazvirtual.fazenda.gov.br/NFeConsultaProtocolo4/NFeConsultaProtocolo4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://hom.sefazvirtual.fazenda.gov.br/NFeStatusServico4/NFeStatusServico4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://hom.sefazvirtual.fazenda.gov.br/NFeRecepcaoEvento4/NFeRecepcaoEvento4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://hom.sefazvirtual.fazenda.gov.br/NFeAutorizacao4/NFeAutorizacao4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://hom.sefazvirtual.fazenda.gov.br/NFeRetAutorizacao4/NFeRetAutorizacao4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "2" });

            // SVRS (Servidor Virtual Rio Grande do Sul)
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/nfeinutilizacao/nfeinutilizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "2" });

            // SVC-AN (Servidor Virtual Nacional de Emissão em Contigência)
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://hom.svc.fazenda.gov.br/NFeConsultaProtocolo4/NFeConsultaProtocolo4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://hom.svc.fazenda.gov.br/NFeStatusServico4/NFeStatusServico4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://hom.svc.fazenda.gov.br/NFeRecepcaoEvento4/NFeRecepcaoEvento4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://hom.svc.fazenda.gov.br/NFeAutorizacao4/NFeAutorizacao4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://hom.svc.fazenda.gov.br/NFeRetAutorizacao4/NFeRetAutorizacao4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "2" });

            // SVC-RS (Servidor Virtual Rio Grande do Sul de Emissão em Contigência)
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe-homologacao.svrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "2" });

            // AN (Servidor Nacional de Manifestação Destinatario(Recepção Evento) e Serviço de Distribuição NFe
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeDistribuicaoDFe", Versao = "1.01", Url = "https://hom.nfe.fazenda.gov.br/NFeDistribuicaoDFe/NFeDistribuicaoDFe.asmx", SefazAut = "AN", ModeloDoc = "55", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://hom.nfe.fazenda.gov.br/NFeRecepcaoEvento4/NFeRecepcaoEvento4.asmx", SefazAut = "AN", ModeloDoc = "55", TipoAmbiente = "2" });


        }
        #endregion

        #region Produção
        private void UrlsAmbProdNFe()
        {
            // Sefaz Amazonas
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.sefaz.am.gov.br/services2/services/NfeStatusServico4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.sefaz.am.gov.br/services2/services/NfeInutilizacao4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.am.gov.br/services2/services/NfeAutorizacao4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.am.gov.br/services2/services/NfeRetAutorizacao4", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.sefaz.am.gov.br/services2/services/RecepcaoEvento4 ", SefazAut = "AM", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz Bahia
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.sefaz.ba.gov.br/webservices/NFeInutilizacao4/NFeInutilizacao4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.sefaz.ba.gov.br/webservices/NFeConsultaProtocolo4/NFeConsultaProtocolo4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.sefaz.ba.gov.br/webservices/NFeStatusServico4/NFeStatusServico4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://nfe.sefaz.ba.gov.br/webservices/CadConsultaCadastro4/CadConsultaCadastro4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.sefaz.ba.gov.br/webservices/NFeRecepcaoEvento4/NFeRecepcaoEvento4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.ba.gov.br/webservices/NFeAutorizacao4/NFeAutorizacao4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.ba.gov.br/webservices/NFeRetAutorizacao4/NFeRetAutorizacao4.asmx", SefazAut = "BA", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz Ceara
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.sefaz.ce.gov.br/nfe4/services/NFeInutilizacao4?wsdl", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.sefaz.ce.gov.br/nfe4/services/NFeConsultaProtocolo4?wsdl", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.sefaz.ce.gov.br/nfe4/services/NFeStatusServico4?wsdl", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://nfe.sefaz.ce.gov.br/nfe4/services/CadConsultaCadastro4?wsdl", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.sefaz.ce.gov.br/nfe4/services/NFeRecepcaoEvento4?wsdl", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.ce.gov.br/nfe4/services/NFeAutorizacao4?wsdl", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.ce.gov.br/nfe4/services/NFeRetAutorizacao4?wsdl", SefazAut = "CE", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz Goiás
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeInutilizacao4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeConsultaProtocolo4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeStatusServico4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/CadConsultaCadastro4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeRecepcaoEvento4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeAutorizacao4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeRetAutorizacao4?wsdl", SefazAut = "GO", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz Minas Gerais
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.fazenda.mg.gov.br/nfe2/services/NFeInutilizacao4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.fazenda.mg.gov.br/nfe2/services/NFeConsultaProtocolo4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.fazenda.mg.gov.br/nfe2/services/NFeStatusServico4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.fazenda.mg.gov.br/nfe2/services/NFeRecepcaoEvento4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.fazenda.mg.gov.br/nfe2/services/NFeAutorizacao4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.fazenda.mg.gov.br/nfe2/services/NFeRetAutorizacao4", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://nfe.fazenda.mg.gov.br/nfe2/services/cadconsultacadastro2", SefazAut = "MG", ModeloDoc = "55", TipoAmbiente = "1" });


            // Sefaz Mato Grosso do Sul
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.fazenda.ms.gov.br/ws/NFeInutilizacao4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.fazenda.ms.gov.br/ws/NFeConsultaProtocolo4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.fazenda.ms.gov.br/ws/NFeStatusServico4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://nfe.fazenda.ms.gov.br/ws/CadConsultaCadastro4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.fazenda.ms.gov.br/ws/NFeRecepcaoEvento4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.fazenda.ms.gov.br/ws/NFeAutorizacao4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.fazenda.ms.gov.br/ws/NFeRetAutorizacao4", SefazAut = "MS", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz Mato Grosso
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.sefaz.mt.gov.br/nfews/v2/services/NfeInutilizacao4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.sefaz.mt.gov.br/nfews/v2/services/NfeConsulta4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.sefaz.mt.gov.br/nfews/v2/services/NfeStatusServico4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://nfe.sefaz.mt.gov.br/nfews/v2/services/CadConsultaCadastro4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.sefaz.mt.gov.br/nfews/v2/services/RecepcaoEvento4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.mt.gov.br/nfews/v2/services/NfeAutorizacao4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.mt.gov.br/nfews/v2/services/NfeRetAutorizacao4?wsdl", SefazAut = "MT", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz Pernambuco
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeAutorizacao", Versao = "4.0", Url = "https://nfe.sefaz.pe.gov.br/nfe-service/services/NFeAutorizacao4", SefazAut = "PE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeRetAutorizacao", Versao = "4.0", Url = "https://nfe.sefaz.pe.gov.br/nfe-service/services/NFeRetAutorizacao4", SefazAut = "PE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.0", Url = "https://nfe.sefaz.pe.gov.br/nfe-service/services/NFeInutilizacao4", SefazAut = "PE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.0", Url = "https://nfe.sefaz.pe.gov.br/nfe-service/services/NFeStatusServico4", SefazAut = "PE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.0", Url = "https://nfe.sefaz.pe.gov.br/nfe-service/services/NFeConsultaProtocolo4", SefazAut = "PE", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "4.0", Url = "https://nfe.sefaz.pe.gov.br/nfe-service/services/NFeRecepcaoEvento4", SefazAut = "PE", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz Parana
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.sefa.pr.gov.br/nfe/NFeInutilizacao4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.sefa.pr.gov.br/nfe/NFeConsultaProtocolo4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.sefa.pr.gov.br/nfe/NFeStatusServico4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://nfe.sefa.pr.gov.br/nfe/CadConsultaCadastro4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.sefa.pr.gov.br/nfe/NFeRecepcaoEvento4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.sefa.pr.gov.br/nfe/NFeAutorizacao4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.sefa.pr.gov.br/nfe/NFeRetAutorizacao4?wsdl", SefazAut = "PR", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz Rio Grande Do Sul
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.sefazrs.rs.gov.br/ws/nfeinutilizacao/nfeinutilizacao4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.sefazrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.sefazrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://cad.sefazrs.rs.gov.br/ws/cadconsultacadastro/cadconsultacadastro4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.sefazrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.sefazrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.sefazrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "55", TipoAmbiente = "1" });

            // Sefaz São Paulo
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.fazenda.sp.gov.br/ws/nfeinutilizacao4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.fazenda.sp.gov.br/ws/nfeconsultaprotocolo4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.fazenda.sp.gov.br/ws/nfestatusservico4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://nfe.fazenda.sp.gov.br/ws/cadconsultacadastro4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.fazenda.sp.gov.br/ws/nferecepcaoevento4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.fazenda.sp.gov.br/ws/nfeautorizacao4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.fazenda.sp.gov.br/ws/nferetautorizacao4.asmx", SefazAut = "SP", ModeloDoc = "55", TipoAmbiente = "1" });

            // SVAN(Servidor Nacional Emissão NFe)
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://www.sefazvirtual.fazenda.gov.br/NFeInutilizacao4/NFeInutilizacao4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://www.sefazvirtual.fazenda.gov.br/NFeConsultaProtocolo4/NFeConsultaProtocolo4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://www.sefazvirtual.fazenda.gov.br/NFeStatusServico4/NFeStatusServico4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://www.sefazvirtual.fazenda.gov.br/NFeRecepcaoEvento4/NFeRecepcaoEvento4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://www.sefazvirtual.fazenda.gov.br/NFeAutorizacao4/NFeAutorizacao4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://www.sefazvirtual.fazenda.gov.br/NFeRetAutorizacao4/NFeRetAutorizacao4.asmx", SefazAut = "SVAN", ModeloDoc = "55", TipoAmbiente = "1" });

            // SVRS (Servidor Virtual Rio Grande do Sul)
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/nfeinutilizacao/nfeinutilizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaCadastro", Versao = "2.00", Url = "https://cad.svrs.rs.gov.br/ws/cadconsultacadastro/cadconsultacadastro4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.svrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "55", TipoAmbiente = "1" });

            // SVC-AN (Servidor Virtual Nacional de Emissão em Contigência)
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://www.svc.fazenda.gov.br/NFeConsultaProtocolo4/NFeConsultaProtocolo4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://www.svc.fazenda.gov.br/NFeStatusServico4/NFeStatusServico4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://www.svc.fazenda.gov.br/NFeRecepcaoEvento4/NFeRecepcaoEvento4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://www.svc.fazenda.gov.br/NFeAutorizacao4/NFeAutorizacao4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://www.svc.fazenda.gov.br/NFeRetAutorizacao4/NFeRetAutorizacao4.asmx", SefazAut = "SVC-AN", ModeloDoc = "55", TipoAmbiente = "1" });

            // SVC-RS (Servidor Virtual Rio Grande do Sul de Emissão em Contigência)
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.svrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.svrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "SVC-RS", ModeloDoc = "55", TipoAmbiente = "1" });

            // AN (Servidor Nacional de Manifestação Destinatario(Recepção Evento) e Serviço de Distribuição NFe
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeDistribuicaoDFe", Versao = "1.00", Url = "https://www1.nfe.fazenda.gov.br/NFeDistribuicaoDFe/NFeDistribuicaoDFe.asmx", SefazAut = "AN", ModeloDoc = "55", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://www.nfe.fazenda.gov.br/NFeRecepcaoEvento4/NFeRecepcaoEvento4.asmx", SefazAut = "AN", ModeloDoc = "55", TipoAmbiente = "1" });


        }
        #endregion


        #endregion

        #region Urls NFC-e

        #region Homogação
        private void UrlsAmbHomNfce()
        {
            // Sefaz Amazonas
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homnfce.sefaz.am.gov.br/nfce-services/services/NfeConsulta4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homnfce.sefaz.am.gov.br/nfce-services/services/NfeStatusServico4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homnfce.sefaz.am.gov.br/nfce-services/services/NfeInutilizacao4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homnfce.sefaz.am.gov.br/nfce-services/services/NfeAutorizacao4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homnfce.sefaz.am.gov.br/nfce-services/services/NfeRetAutorizacao4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homnfce.sefaz.am.gov.br/nfce-services/services/RecepcaoEvento4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "2" });

            // Sefaz Goiás
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeInutilizacao4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeConsultaProtocolo4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeStatusServico4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeRecepcaoEvento4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeAutorizacao4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homolog.sefaz.go.gov.br/nfe/services/NFeRetAutorizacao4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "2" });

            // Sefaz Mato Grosso do Sul
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.ms.gov.br/ws/NFeAutorizacao4 ", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.ms.gov.br/ws/NFeRetAutorizacao4 ", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.ms.gov.br/ws/NFeInutilizacao4 ", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.ms.gov.br/ws/NFeConsultaProtocolo4 ", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.ms.gov.br/ws/NFeStatusServico4 ", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homologacao.nfce.fazenda.ms.gov.br/ws/NFeRecepcaoEvento4", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "2" });

            // Sefaz Mato Grosso
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfcews/v2/services/NfeAutorizacao4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfcews/v2/services/NfeRetAutorizacao4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfcews/v2/services/NfeInutilizacao4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfcews/v2/services/NfeConsulta4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homologacao.sefaz.mt.gov.br/nfcews/v2/services/NfeStatusServico4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homologacao.sefaz.mt.gov.br/nfcews/v2/services/RecepcaoEvento4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "2" });

            // Sefaz Parana
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homologacao.nfce.sefa.pr.gov.br/nfce/NFeAutorizacao4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homologacao.nfce.sefa.pr.gov.br/nfce/NFeRetAutorizacao4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homologacao.nfce.sefa.pr.gov.br/nfce/NFeInutilizacao4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homologacao.nfce.sefa.pr.gov.br/nfce/NFeConsultaProtocolo4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homologacao.nfce.sefa.pr.gov.br/nfce/NFeStatusServico4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homologacao.nfce.sefa.pr.gov.br/nfce/NFeRecepcaoEvento4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "2" });

            // Sefaz Rio Grande do Sul
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce-homologacao.sefazrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce-homologacao.sefazrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce-homologacao.sefazrs.rs.gov.br/ws/nfeinutilizacao/nfeinutilizacao4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce-homologacao.sefazrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce-homologacao.sefazrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce-homologacao.sefazrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "2" });

            // Sefaz São Paulo
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.sp.gov.br/ws/NFeAutorizacao4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.sp.gov.br/ws/NFeRetAutorizacao4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.sp.gov.br/ws/NFeInutilizacao4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.sp.gov.br/ws/NFeConsultaProtocolo4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://homologacao.nfce.fazenda.sp.gov.br/ws/NFeStatusServico4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://homologacao.nfce.fazenda.sp.gov.br/ws/NFeRecepcaoEvento4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "2" });

            // Servidor Virtual Rio Grande Do Sul(NFC-e)
            // UFs que utilizando esse Servidor:
            // AC, AL, AP, BA, DF, ES, MA, PA, PB, PE, PI, RJ, RN, RO, RR, SE, TO
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce-homologacao.svrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce-homologacao.svrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce-homologacao.svrs.rs.gov.br/ws/nfeinutilizacao/nfeinutilizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce-homologacao.svrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce-homologacao.svrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "2" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce-homologacao.svrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "2" });


        }
        #endregion

        #region Produção
        private void UrlsAmbProdNfce()
        {
            // Sefaz Amazonas
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce.sefaz.am.gov.br/nfce-services/services/NfeConsulta4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce.sefaz.am.gov.br/nfce-services/services/NfeStatusServico4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce.sefaz.am.gov.br/nfce-services/services/NfeInutilizacao4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce.sefaz.am.gov.br/nfce-services/services/NfeAutorizacao4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce.sefaz.am.gov.br/nfce-services/services/NfeRetAutorizacao4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce.sefaz.am.gov.br/nfce-services/services/RecepcaoEvento4", SefazAut = "AM", ModeloDoc = "65", TipoAmbiente = "1" });

            // Sefaz Goiás
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeInutilizacao4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeConsultaProtocolo4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeStatusServico4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeRecepcaoEvento4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeAutorizacao4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfe.sefaz.go.gov.br/nfe/services/NFeRetAutorizacao4?wsdl", SefazAut = "GO", ModeloDoc = "65", TipoAmbiente = "1" });

            // Sefaz Mato Grosso do Sul
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce.fazenda.ms.gov.br/ws/NFeAutorizacao4", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce.fazenda.ms.gov.br/ws/NFeRetAutorizacao4", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce.fazenda.ms.gov.br/ws/NFeInutilizacao4", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce.fazenda.ms.gov.br/ws/NFeConsultaProtocolo4", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce.fazenda.ms.gov.br/ws/NFeStatusServico4", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce.fazenda.ms.gov.br/ws/NFeRecepcaoEvento4", SefazAut = "MS", ModeloDoc = "65", TipoAmbiente = "1" });

            // Sefaz Mato Grosso
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce.sefaz.mt.gov.br/nfcews/v2/services/NfeAutorizacao4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce.sefaz.mt.gov.br/nfcews/v2/services/NfeRetAutorizacao4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce.sefaz.mt.gov.br/nfcews/v2/services/NfeInutilizacao4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce.sefaz.mt.gov.br/nfcews/v2/services/NfeConsulta4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce.sefaz.mt.gov.br/nfcews/v2/services/NfeStatusServico4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce.sefaz.mt.gov.br/nfcews/v2/services/RecepcaoEvento4", SefazAut = "MT", ModeloDoc = "65", TipoAmbiente = "1" });

            // Sefaz Parana
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce.sefa.pr.gov.br/nfce/NFeAutorizacao4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce.sefa.pr.gov.br/nfce/NFeRetAutorizacao4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce.sefa.pr.gov.br/nfce/NFeInutilizacao4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce.sefa.pr.gov.br/nfce/NFeConsultaProtocolo4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce.sefa.pr.gov.br/nfce/NFeStatusServico4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce.sefa.pr.gov.br/nfce/NFeRecepcaoEvento4", SefazAut = "PR", ModeloDoc = "65", TipoAmbiente = "1" });

            // Sefaz Rio Grande do Sul
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce.sefazrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce.sefazrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce.sefazrs.rs.gov.br/ws/nfeinutilizacao/nfeinutilizacao4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce.sefazrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce.sefazrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce.sefazrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "1" });

            // Sefaz São Paulo
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce.fazenda.sp.gov.br/ws/NFeAutorizacao4.asmx", SefazAut = "RS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce.fazenda.sp.gov.br/ws/NFeRetAutorizacao4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce.fazenda.sp.gov.br/ws/NFeInutilizacao4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce.fazenda.sp.gov.br/ws/NFeConsultaProtocolo4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce.fazenda.sp.gov.br/ws/NFeStatusServico4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce.fazenda.sp.gov.br/ws/NFeRecepcaoEvento4.asmx", SefazAut = "SP", ModeloDoc = "65", TipoAmbiente = "1" });

            // Servidor Virtual Rio Grande Do Sul(NFC-e)
            // UFs que utilizando esse Servidor:
            // AC, AL, AP, BA, DF, ES, MA, PA, PB, PE, PI, RJ, RN, RO, RR, SE, TO
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeAutorizacao", Versao = "4.00", Url = "https://nfce.svrs.rs.gov.br/ws/NfeAutorizacao/NFeAutorizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NFeRetAutorizacao", Versao = "4.00", Url = "https://nfce.svrs.rs.gov.br/ws/NfeRetAutorizacao/NFeRetAutorizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeInutilizacao", Versao = "4.00", Url = "https://nfce.svrs.rs.gov.br/ws/nfeinutilizacao/nfeinutilizacao4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeConsultaProtocolo", Versao = "4.00", Url = "https://nfce.svrs.rs.gov.br/ws/NfeConsulta/NfeConsulta4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "NfeStatusServico", Versao = "4.00", Url = "https://nfce.svrs.rs.gov.br/ws/NfeStatusServico/NfeStatusServico4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "RecepcaoEvento", Versao = "1.00", Url = "https://nfce.svrs.rs.gov.br/ws/recepcaoevento/recepcaoevento4.asmx", SefazAut = "SVRS", ModeloDoc = "65", TipoAmbiente = "1" });
            _lstConfigWsUrls.Add(new UrlsServWeb { Servico = "", Versao = "", Url = "", SefazAut = "", ModeloDoc = "", TipoAmbiente = "" });

        }
        #endregion



        #endregion
    }


    public enum Estado
    {
        AC = 12,
        AL = 27,
        AM = 13,
        AP = 16,
        BA = 29,
        CE = 23,
        DF = 53,
        ES = 32,
        GO = 52,
        MA = 21,
        MG = 31,
        MS = 50,
        MT = 51,
        PA = 15,
        PB = 25,
        PE = 26,
        PI = 22,
        PR = 41,
        RJ = 33,
        RN = 24,
        RO = 11,
        RR = 14,
        RS = 43,
        SC = 42,
        SE = 28,
        SP = 35,
        TO = 17,
        AN = 91
    }
}
